@@ -1,8 +1,6 @@
-{-# OPTIONS -fffi -cpp #-}
+{-# OPTIONS -cpp #-}
 
 ------------------------------------------------------------------------
--- $Id: Main.hs,v 1.72 2005/03/10 17:58:42 malcolm Exp $
---
 -- Program for converting .hsc files to .hs files, by converting the
 -- file into a C program which is run to generate the Haskell source.
 -- Certain items known only to the C compiler can then be used in
@@ -11,43 +9,84 @@
 --
 -- See the documentation in the Users' Guide for more details.
 
-#if defined(__GLASGOW_HASKELL__) && !defined(BUILD_NHC)
-#include "../../includes/ghcconfig.h"
-#endif
-
-#if __GLASGOW_HASKELL__ >= 504 || __NHC__ >= 114 || __HUGS__
+import Control.Monad		( MonadPlus(..), liftM, liftM2, when )
+import Data.Char		( isAlpha, isAlphaNum, isSpace, isDigit,
+				  toUpper, intToDigit, ord )
+import Data.List		( intersperse, isSuffixOf )
+import System.Cmd		( system, rawSystem )
 import System.Console.GetOpt
+import System.Directory		( removeFile, doesFileExist )
+import System.Environment	( getProgName, getArgs )
+import System.Exit		( ExitCode(..), exitWith )
+import System.IO		( hPutStr, hPutStrLn, stderr )
+
+#if __GLASGOW_HASKELL__ >= 604 || defined(__NHC__) || defined(__HUGS__)
+import System.Directory		( findExecutable )
 #else
-import GetOpt
+import System.Directory		( getPermissions, executable )
+import System.Environment	( getEnv )
+import Control.Monad		( foldM )
 #endif
 
-import System        (getProgName, getArgs, ExitCode(..), exitWith, system)
-import Directory     (removeFile,doesFileExist)
-import Monad         (MonadPlus(..), liftM, liftM2, when)
-import Char          (isAlpha, isAlphaNum, isSpace, isDigit, toUpper, intToDigit, ord)
-import List          (intersperse, isSuffixOf)
-import IO            (hPutStr, hPutStrLn, stderr)
+#if __GLASGOW_HASKELL__ >= 604
+import System.Process           ( runProcess, waitForProcess )
+import System.IO                ( openFile, IOMode(..), hClose )
+#define HAVE_runProcess
+#endif
 
-#if defined(mingw32_HOST_OS) && !__HUGS__
-import Foreign
-#if __GLASGOW_HASKELL__ >= 504 || __NHC__ >= 114
-import Foreign.C.String
+#if ! BUILD_NHC
+import Paths_hsc2hs		( getDataFileName, version )
+import Data.Version		( showVersion )
 #else
-import CString
-#endif
+import System.Directory		( getCurrentDirectory )
+getDataFileName s = do here <- getCurrentDirectory
+                       return (here++"/"++s)
+version = "0.67" -- TODO!!!
+showVersion = id
 #endif
 
-
-#if defined(__GLASGOW_HASKELL__) && !defined(BUILD_NHC)
-import Compat.RawSystem 	( rawSystem )
-#elif __HUGS__ || __NHC__ >= 117 || __GLASGOW_HASKELL__ >= 600
-import System.Cmd	 	( rawSystem )
+#ifdef __GLASGOW_HASKELL__
+default_compiler = "ghc"
 #else
-rawSystem prog args = system (prog++" "++unwords args)
+default_compiler = "gcc"
 #endif
 
-version :: String
-version = "hsc2hs version 0.66\n"
+#if defined(__GLASGOW_HASKELL__) && (__GLASGOW_HASKELL__ < 604)
+findExecutable :: String -> IO (Maybe FilePath)
+findExecutable cmd =
+  let dir = dirname cmd
+  in case dir of
+    "" -> do -- search the shell environment PATH variable for candidates
+             val <- getEnv "PATH"
+             let psep = pathSep val
+                 dirs = splitPath psep "" val
+             foldM (\a dir-> testFile a (dir++'/':cmd)) Nothing dirs
+    _  -> do testFile Nothing cmd
+  where
+    splitPath :: Char -> String -> String -> [String]
+    splitPath sep acc []                 = [reverse acc]
+    splitPath sep acc (c:path) | c==sep  = reverse acc : splitPath sep "" path
+    splitPath sep acc (c:path)           = splitPath sep (c:acc) path
+
+    pathSep s = if length (filter (==';') s) >0 then ';' else ':'
+
+    testFile :: Maybe String -> String -> IO (Maybe String)
+    testFile gotit@(Just _) path = return gotit
+    testFile Nothing path = do
+        ok <- doesFileExist path
+        if ok then perms path else return Nothing
+
+    perms file = do
+        p <- getPermissions file
+        return (if executable p then Just file else Nothing)
+
+    dirname  = reverse . safetail . dropWhile (not.(`elem`"\\/")) . reverse
+      where safetail [] = []
+            safetail (_:x) = x
+#endif
+
+versionString :: String
+versionString = "hsc2hs version " ++ showVersion version ++ "\n"
 
 data Flag
     = Help
@@ -105,7 +144,6 @@ options = [
         "display this help and exit",
     Option ['V'] ["version"]    (NoArg  Version)
         "output version information and exit" ]
-    
 
 main :: IO ()
 main = do
@@ -114,32 +152,18 @@ main = do
     args <- getArgs
     let (flags, files, errs) = getOpt Permute options args
 
-	-- If there is no Template flag explicitly specified, try
-	-- to find one by looking near the executable.  This only
-	-- works on Win32 or Hugs (getExecDir). On Unix, there's a wrapper 
-	-- script which specifies an explicit template flag.
-    flags_w_tpl <- if any template_flag flags then
-			return flags
-		   else	
-#ifdef __HUGS__
-			do mb_path <- getExecDir "/Main.hs"
-#else
-			do mb_path <- getExecDir "/bin/hsc2hs.exe"
-#endif
-			   add_opt <-
-			    case mb_path of
-			      Nothing   -> return id
-			      Just path -> do
-				let templ = path ++ "/template-hsc.h"
-				flg <- doesFileExist templ
-				if flg 
-				 then return ((Template templ):)
-				 else return id
-		           return (add_opt flags) 
+	-- If there is no Template flag explicitly specified,
+	-- use the file placed by the Cabal installation.
+    flags_w_tpl <-
+	if any template_flag flags then
+	    return flags
+	  else do
+	    templ <- getDataFileName "template-hsc.h"
+	    return (Template templ : flags)
     case (files, errs) of
         (_, _)
             | any isHelp    flags_w_tpl -> bye (usageInfo header options)
-            | any isVersion flags_w_tpl -> bye version
+            | any isVersion flags_w_tpl -> bye versionString
             where
             isHelp    Help    = True; isHelp    _ = False
             isVersion Version = True; isVersion _ = False
@@ -159,7 +183,7 @@ die :: String -> IO a
 die s = hPutStr stderr s >> exitWith (ExitFailure 1)
 
 processFile :: [Flag] -> String -> IO ()
-processFile flags name 
+processFile flags name
   = do let file_name = dosifyPath name
        s <- readFile file_name
        case parser of
@@ -492,7 +516,7 @@ splitExt name =
 
 output :: [Flag] -> String -> [Token] -> IO ()
 output flags name toks = do
-    
+
     (outName, outDir, outBase) <- case [f | Output f <- flags] of
         [] -> if not (null ext) && last ext == 'c'
                  then return (dir++base++init ext,  dir, base)
@@ -508,7 +532,7 @@ output flags name toks = do
             (base, _)    = splitExt file
             in return (f, dir, base)
         _ -> onlyOne "output file"
-    
+
     let cProgName    = outDir++outBase++"_hsc_make.c"
         oProgName    = outDir++outBase++"_hsc_make.o"
         progName     = outDir++outBase++"_hsc_make"
@@ -520,67 +544,36 @@ output flags name toks = do
 	outHFile     = outBase++"_hsc.h"
         outHName     = outDir++outHFile
         outCName     = outDir++outBase++"_hsc.c"
-	
+
 	beVerbose    = any (\ x -> case x of { Verbose -> True; _ -> False}) flags
 
     let execProgName
             | null outDir = dosifyPath ("./" ++ progName)
             | otherwise   = progName
-    
+
     let specials = [(pos, key, arg) | Special pos key arg <- toks]
-    
+
     let needsC = any (\(_, key, _) -> key == "def") specials
         needsH = needsC
-    
+
     let includeGuard = map fixChar outHName
             where
             fixChar c | isAlphaNum c = toUpper c
                       | otherwise    = '_'
 
-#ifdef __HUGS__
     compiler <- case [c | Compiler c <- flags] of
-        []  -> return "gcc"
+        []  -> do
+	    mb_path <- findExecutable default_compiler
+	    case mb_path of
+		Nothing -> die ("Can't find "++default_compiler++"\n")
+		Just path -> return path
         [c] -> return c
         _   -> onlyOne "compiler"
-    
+
     linker <- case [l | Linker l <- flags] of
         []  -> return compiler
         [l] -> return l
         _   -> onlyOne "linker"
-#else
-        -- Try locating GHC..on Win32, look in the vicinity of hsc2hs.
-	-- Returns a native-format path
-        locateGhc def = do
-	    mb <- getExecDir "bin/hsc2hs.exe"
-	    case mb of
-	      Nothing -> return def
-	      Just x  -> do
-	         let ghc_path = dosifyPath (x ++ "bin/ghc.exe")
-	         flg <- doesFileExist ghc_path
-		 if flg 
-		  then return ghc_path
-		  else return def
-    
-	-- On a Win32 installation we execute the hsc2hs binary directly, 
-	-- with no --cc flags, so we'll call locateGhc here, which will
-	-- succeed, via getExecDir.
-	--
-	-- On a Unix installation, we'll run the wrapper script hsc2hs.sh 
-	-- (called plain hsc2hs in the installed tree), which will pass
-	-- a suitable C compiler via --cc
-	--
-	-- The in-place installation always uses the wrapper script,
-	-- (called hsc2hs-inplace, generated from hsc2hs.sh)
-    compiler <- case [c | Compiler c <- flags] of
-        []  -> locateGhc "ghc"
-        [c] -> return c
-        _   -> onlyOne "compiler"
-    
-    linker <- case [l | Linker l <- flags] of
-        []  -> locateGhc compiler
-        [l] -> return l
-        _   -> onlyOne "linker"
-#endif
 
     writeFile cProgName $
         concatMap outFlagHeaderCProg flags++
@@ -590,43 +583,30 @@ output flags name toks = do
         outHsLine (SourcePos name 0)++
         concatMap outTokenHs toks++
         "    return 0;\n}\n"
-    
+
     -- NOTE: hbc compiles "[() | NoCompile <- flags]" into wrong code,
     -- so we use something slightly more complicated.   :-P
     when (any (\x -> case x of NoCompile -> True; _ -> False) flags) $
        exitWith ExitSuccess
 
-
-    
-    compilerStatus <- rawSystemL beVerbose compiler
+    rawSystemL ("compiling " ++ cProgName) beVerbose compiler
 	(  ["-c"]
         ++ [f | CompFlag f <- flags]
         ++ [cProgName]
         ++ ["-o", oProgName]
 	)
-
-    case compilerStatus of
-        e@(ExitFailure _) -> exitWith e
-        _                 -> return ()
     removeFile cProgName
-    
-    linkerStatus <- rawSystemL beVerbose linker
+
+    rawSystemL ("linking " ++ oProgName) beVerbose linker
         (  [f | LinkFlag f <- flags]
         ++ [oProgName]
         ++ ["-o", progName]
 	)
-
-    case linkerStatus of
-        e@(ExitFailure _) -> exitWith e
-        _                 -> return ()
     removeFile oProgName
-    
-    progStatus <- systemL beVerbose (execProgName++" >"++outName)
+
+    rawSystemWithStdOutL ("running " ++ execProgName) beVerbose execProgName [] outName
     removeFile progName
-    case progStatus of
-        e@(ExitFailure _) -> exitWith e
-        _                 -> return ()
-    
+
     when needsH $ writeFile outHName $
         "#ifndef "++includeGuard++"\n" ++
         "#define "++includeGuard++"\n" ++
@@ -641,22 +621,41 @@ output flags name toks = do
         concatMap outFlagH flags++
         concatMap outTokenH specials++
         "#endif\n"
-    
+
     when needsC $ writeFile outCName $
         "#include \""++outHFile++"\"\n"++
         concatMap outTokenC specials
 	-- NB. outHFile not outHName; works better when processed
 	-- by gcc or mkdependC.
 
-rawSystemL :: Bool -> String -> [String] -> IO ExitCode
-rawSystemL flg prog args = do
-  when flg $ hPutStrLn stderr ("Executing: " ++ prog ++ concat (map (' ':) args))
-  rawSystem prog args
+rawSystemL :: String -> Bool -> FilePath -> [String] -> IO ()
+rawSystemL action flg prog args = do
+  let cmdLine = prog++" "++unwords args
+  when flg $ hPutStrLn stderr ("Executing: " ++ cmdLine)
+#ifndef HAVE_rawSystem
+  exitStatus <- system cmdLine
+#else
+  exitStatus <- rawSystem prog args
+#endif
+  case exitStatus of
+    ExitFailure _ -> die $ action ++ " failed\ncommand was: " ++ cmdLine ++ "\n"
+    _             -> return ()
 
-systemL :: Bool -> String -> IO ExitCode
-systemL flg s = do
-  when flg (hPutStrLn stderr ("Executing: " ++ s))
-  system s
+rawSystemWithStdOutL :: String -> Bool -> FilePath -> [String] -> FilePath -> IO ()
+rawSystemWithStdOutL action flg prog args outFile = do
+  let cmdLine = prog++" "++unwords args++" >"++outFile
+  when flg (hPutStrLn stderr ("Executing: " ++ cmdLine))
+#ifndef HAVE_runProcess
+  exitStatus <- system cmdLine
+#else
+  hOut <- openFile outFile WriteMode
+  process <- runProcess prog args Nothing Nothing Nothing (Just hOut) Nothing
+  exitStatus <- waitForProcess process
+  hClose hOut
+#endif
+  case exitStatus of
+    ExitFailure _ -> die $ action ++ " failed\ncommand was: " ++ cmdLine ++ "\n"
+    _             -> return ()
 
 onlyOne :: String -> IO a
 onlyOne what = die ("Only one "++what++" may be specified\n")
@@ -844,7 +843,7 @@ outCLine (SourcePos name line) =
 outHsLine :: SourcePos -> String
 outHsLine (SourcePos name line) =
     "    hsc_line ("++show (line + 1)++", \""++
-    showCString (snd (splitName name))++"\");\n"
+    showCString name++"\");\n"
 
 showCString :: String -> String
 showCString = concatMap showCChar
@@ -866,48 +865,16 @@ showCString = concatMap showCChar
                       intToDigit (ord c `quot` 8 `mod` 8),
                       intToDigit (ord c          `mod` 8)]
 
-
-
 -----------------------------------------
---	Cut and pasted from ghc/compiler/SysTools
+-- Modified version from ghc/compiler/SysTools
 -- Convert paths foo/baz to foo\baz on Windows
 
-dosifyPath, unDosifyPath :: String -> String
+subst :: Char -> Char -> String -> String
 #if defined(mingw32_HOST_OS) || defined(__CYGWIN32__)
-dosifyPath xs = subst '/' '\\' xs
-unDosifyPath xs = subst '\\' '/' xs
-
-subst :: Eq a => a -> a -> [a] -> [a]
-subst a b ls = map (\ x -> if x == a then b else x) ls
+subst a b = map (\x -> if x == a then b else x)
 #else
-dosifyPath xs = xs
-unDosifyPath xs = xs
+subst _ _ = id
 #endif
 
-getExecDir :: String -> IO (Maybe String)
--- (getExecDir cmd) returns the directory in which the current
---	  	    executable, which should be called 'cmd', is running
--- So if the full path is /a/b/c/d/e, and you pass "d/e" as cmd,
--- you'll get "/a/b/c" back as the result
-#ifdef __HUGS__
-getExecDir cmd
-  = do
-	s <- getProgName
-	return (Just (reverse (drop (length cmd) (reverse (unDosifyPath s)))))
-#elif defined(mingw32_HOST_OS)
-getExecDir cmd
-  = allocaArray len $ \buf -> do
-	ret <- getModuleFileName nullPtr buf len
-	if ret == 0 then return Nothing
-	            else do s <- peekCString buf
-			    return (Just (reverse (drop (length cmd) 
-							(reverse (unDosifyPath s)))))
-  where
-    len = 2048::Int -- Plenty, PATH_MAX is 512 under Win32.
-
-foreign import stdcall unsafe "GetModuleFileNameA"
-  getModuleFileName :: Ptr () -> CString -> Int -> IO Int32
-
-#else
-getExecDir _ = return Nothing
-#endif
+dosifyPath :: String -> String
+dosifyPath = subst '/' '\\'
