@@ -1,81 +1,81 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v598	((void*)startLabel+36)
-#define CT_v600	((void*)startLabel+84)
-#define CT_v602	((void*)startLabel+140)
-#define CT_v604	((void*)startLabel+188)
-#define CT_v606	((void*)startLabel+236)
-#define CT_v608	((void*)startLabel+300)
-#define CT_v610	((void*)startLabel+368)
-#define FN_LAMBDA594	((void*)startLabel+404)
-#define CT_v612	((void*)startLabel+432)
-#define F0_LAMBDA594	((void*)startLabel+440)
-#define CT_v614	((void*)startLabel+488)
-#define CT_v616	((void*)startLabel+540)
-#define CT_v618	((void*)startLabel+588)
-#define CT_v620	((void*)startLabel+648)
-#define CT_v622	((void*)startLabel+704)
-#define CT_v624	((void*)startLabel+764)
-#define CT_v626	((void*)startLabel+820)
+#define CT_v603	((void*)startLabel+36)
+#define CT_v605	((void*)startLabel+84)
+#define CT_v607	((void*)startLabel+140)
+#define CT_v609	((void*)startLabel+188)
+#define CT_v611	((void*)startLabel+236)
+#define CT_v613	((void*)startLabel+300)
+#define CT_v615	((void*)startLabel+368)
+#define FN_LAMBDA599	((void*)startLabel+404)
+#define CT_v617	((void*)startLabel+432)
+#define F0_LAMBDA599	((void*)startLabel+440)
+#define CT_v619	((void*)startLabel+488)
+#define CT_v621	((void*)startLabel+540)
+#define CT_v623	((void*)startLabel+588)
+#define CT_v625	((void*)startLabel+648)
+#define CT_v627	((void*)startLabel+704)
+#define CT_v629	((void*)startLabel+764)
+#define CT_v631	((void*)startLabel+820)
 #define FN_NHC_46FFI_46funPtrToInt	((void*)startLabel+848)
-#define CT_v628	((void*)startLabel+876)
+#define CT_v633	((void*)startLabel+876)
 #define F0_NHC_46FFI_46funPtrToInt	((void*)startLabel+884)
-#define CT_v630	((void*)startLabel+948)
-#define FN_LAMBDA595	((void*)startLabel+996)
-#define CT_v633	((void*)startLabel+1028)
-#define CF_LAMBDA595	((void*)startLabel+1036)
-#define CT_v635	((void*)startLabel+1072)
-#define CT_v637	((void*)startLabel+1124)
-#define CT_v639	((void*)startLabel+1176)
-#define CT_v641	((void*)startLabel+1240)
-#define CT_v643	((void*)startLabel+1296)
-#define CT_v645	((void*)startLabel+1352)
-#define CT_v647	((void*)startLabel+1408)
-#define CT_v649	((void*)startLabel+1464)
-#define CT_v651	((void*)startLabel+1520)
-#define CT_v653	((void*)startLabel+1576)
-#define CT_v655	((void*)startLabel+1644)
-#define CT_v657	((void*)startLabel+1696)
-#define CT_v659	((void*)startLabel+1756)
-#define CT_v661	((void*)startLabel+1828)
-#define CT_v663	((void*)startLabel+1916)
-#define CT_v665	((void*)startLabel+1996)
-#define ST_v632	((void*)startLabel+2044)
-#define ST_v664	((void*)startLabel+2047)
-#define ST_v613	((void*)startLabel+2079)
-#define ST_v617	((void*)startLabel+2121)
-#define ST_v609	((void*)startLabel+2162)
-#define ST_v611	((void*)startLabel+2199)
-#define ST_v621	((void*)startLabel+2248)
-#define ST_v625	((void*)startLabel+2292)
-#define ST_v607	((void*)startLabel+2336)
-#define ST_v619	((void*)startLabel+2373)
-#define ST_v623	((void*)startLabel+2417)
-#define ST_v615	((void*)startLabel+2461)
-#define ST_v603	((void*)startLabel+2500)
-#define ST_v599	((void*)startLabel+2519)
-#define ST_v597	((void*)startLabel+2543)
-#define ST_v601	((void*)startLabel+2567)
-#define ST_v627	((void*)startLabel+2593)
-#define ST_v605	((void*)startLabel+2613)
-#define ST_v658	((void*)startLabel+2632)
-#define ST_v656	((void*)startLabel+2658)
-#define ST_v654	((void*)startLabel+2687)
-#define ST_v660	((void*)startLabel+2716)
-#define ST_v650	((void*)startLabel+2743)
-#define ST_v652	((void*)startLabel+2772)
-#define ST_v646	((void*)startLabel+2802)
-#define ST_v648	((void*)startLabel+2831)
-#define ST_v640	((void*)startLabel+2861)
-#define ST_v644	((void*)startLabel+2896)
-#define ST_v642	((void*)startLabel+2927)
-#define ST_v662	((void*)startLabel+2958)
-#define ST_v634	((void*)startLabel+2986)
-#define ST_v638	((void*)startLabel+3019)
-#define ST_v629	((void*)startLabel+3056)
-#define ST_v631	((void*)startLabel+3094)
-#define ST_v636	((void*)startLabel+3144)
+#define CT_v635	((void*)startLabel+948)
+#define FN_LAMBDA600	((void*)startLabel+996)
+#define CT_v638	((void*)startLabel+1028)
+#define CF_LAMBDA600	((void*)startLabel+1036)
+#define CT_v640	((void*)startLabel+1072)
+#define CT_v642	((void*)startLabel+1124)
+#define CT_v644	((void*)startLabel+1176)
+#define CT_v646	((void*)startLabel+1240)
+#define CT_v648	((void*)startLabel+1296)
+#define CT_v650	((void*)startLabel+1352)
+#define CT_v652	((void*)startLabel+1408)
+#define CT_v654	((void*)startLabel+1464)
+#define CT_v656	((void*)startLabel+1520)
+#define CT_v658	((void*)startLabel+1576)
+#define CT_v660	((void*)startLabel+1644)
+#define CT_v662	((void*)startLabel+1696)
+#define CT_v664	((void*)startLabel+1756)
+#define CT_v666	((void*)startLabel+1828)
+#define CT_v668	((void*)startLabel+1916)
+#define CT_v670	((void*)startLabel+1996)
+#define ST_v637	((void*)startLabel+2044)
+#define ST_v669	((void*)startLabel+2047)
+#define ST_v618	((void*)startLabel+2079)
+#define ST_v622	((void*)startLabel+2121)
+#define ST_v614	((void*)startLabel+2162)
+#define ST_v616	((void*)startLabel+2199)
+#define ST_v626	((void*)startLabel+2248)
+#define ST_v630	((void*)startLabel+2292)
+#define ST_v612	((void*)startLabel+2336)
+#define ST_v624	((void*)startLabel+2373)
+#define ST_v628	((void*)startLabel+2417)
+#define ST_v620	((void*)startLabel+2461)
+#define ST_v608	((void*)startLabel+2500)
+#define ST_v604	((void*)startLabel+2519)
+#define ST_v602	((void*)startLabel+2543)
+#define ST_v606	((void*)startLabel+2567)
+#define ST_v632	((void*)startLabel+2593)
+#define ST_v610	((void*)startLabel+2613)
+#define ST_v663	((void*)startLabel+2632)
+#define ST_v661	((void*)startLabel+2658)
+#define ST_v659	((void*)startLabel+2687)
+#define ST_v665	((void*)startLabel+2716)
+#define ST_v655	((void*)startLabel+2743)
+#define ST_v657	((void*)startLabel+2772)
+#define ST_v651	((void*)startLabel+2802)
+#define ST_v653	((void*)startLabel+2831)
+#define ST_v645	((void*)startLabel+2861)
+#define ST_v649	((void*)startLabel+2896)
+#define ST_v647	((void*)startLabel+2927)
+#define ST_v667	((void*)startLabel+2958)
+#define ST_v639	((void*)startLabel+2986)
+#define ST_v643	((void*)startLabel+3019)
+#define ST_v634	((void*)startLabel+3056)
+#define ST_v636	((void*)startLabel+3094)
+#define ST_v641	((void*)startLabel+3144)
 extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46castPtrToFunPtr(void);
 void FR_NHC_46FFI_46castFunPtrToPtr(void);
@@ -117,7 +117,7 @@ extern Node CF_Prelude_46Eq_46NHC_46FFI_46FunPtr[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v598)
+, useLabel(CT_v603)
 ,};
 Node FN_NHC_46FFI_46castPtrToFunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -126,15 +126,15 @@ Node FN_NHC_46FFI_46castPtrToFunPtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 640001
-, useLabel(ST_v597)
-,	/* CT_v598: (byte 0) */
+, useLabel(ST_v602)
+,	/* CT_v603: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46castPtrToFunPtr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46castPtrToFunPtr),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v600)
+, useLabel(CT_v605)
 ,};
 Node FN_NHC_46FFI_46castFunPtrToPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -143,15 +143,15 @@ Node FN_NHC_46FFI_46castFunPtrToPtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 630001
-, useLabel(ST_v599)
-,	/* CT_v600: (byte 0) */
+, useLabel(ST_v604)
+,	/* CT_v605: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46castFunPtrToPtr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46castFunPtrToPtr),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v602)
+, useLabel(CT_v607)
 ,};
 Node FN_NHC_46FFI_46freeHaskellFunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -162,8 +162,8 @@ Node FN_NHC_46FFI_46freeHaskellFunPtr[] = {
 , 0
 , CONSTR(0,0,0)
 , 610001
-, useLabel(ST_v601)
-,	/* CT_v602: (byte 0) */
+, useLabel(ST_v606)
+,	/* CT_v607: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -171,7 +171,7 @@ Node F0_NHC_46FFI_46freeHaskellFunPtr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46freeHaskellFunPtr),1)
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v604)
+, useLabel(CT_v609)
 ,};
 Node FN_NHC_46FFI_46castFunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -179,8 +179,8 @@ Node FN_NHC_46FFI_46castFunPtr[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 580001
-, useLabel(ST_v603)
-,	/* CT_v604: (byte 0) */
+, useLabel(ST_v608)
+,	/* CT_v609: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -188,7 +188,7 @@ Node F0_NHC_46FFI_46castFunPtr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46castFunPtr),1)
 , VAPTAG(useLabel(FN_NonStdUnsafeCoerce_46unsafeCoerce))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v606)
+, useLabel(CT_v611)
 ,};
 Node FN_NHC_46FFI_46nullFunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -196,8 +196,8 @@ Node FN_NHC_46FFI_46nullFunPtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 550001
-, useLabel(ST_v605)
-,	/* CT_v606: (byte 0) */
+, useLabel(ST_v610)
+,	/* CT_v611: (byte 0) */
   HW(2,0)
 , 0
 ,};
@@ -207,7 +207,7 @@ Node CF_NHC_46FFI_46nullFunPtr[] = {
 , useLabel(CF_NHC_46FFI_46nullPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v608)
+, useLabel(CT_v613)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46poke[] = {
   useLabel(TM_NHC_46FFI)
@@ -217,8 +217,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46poke[] = {
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 520003
-, useLabel(ST_v607)
-,	/* CT_v608: (byte 0) */
+, useLabel(ST_v612)
+,	/* CT_v613: (byte 0) */
   HW(3,2)
 , 0
 ,};
@@ -228,7 +228,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46poke[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46castFunPtrToPtr))
 , VAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46Ptr_46poke))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v610)
+, useLabel(CT_v615)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peek[] = {
   useLabel(TM_NHC_46FFI)
@@ -239,8 +239,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peek[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 510003
-, useLabel(ST_v609)
-,	/* CT_v610: (byte 0) */
+, useLabel(ST_v614)
+,	/* CT_v615: (byte 0) */
   HW(4,1)
 , 0
 ,};
@@ -248,27 +248,27 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peek[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peek),1)
 , VAPTAG(useLabel(FN_NHC_46FFI_46castPtr))
 , VAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46Ptr_46peek))
-, CAPTAG(useLabel(FN_LAMBDA594),1)
+, CAPTAG(useLabel(FN_LAMBDA599),1)
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v612)
-,	/* FN_LAMBDA594: (byte 0) */
+, useLabel(CT_v617)
+,	/* FN_LAMBDA599: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 510023
-, useLabel(ST_v611)
-,	/* CT_v612: (byte 0) */
+, useLabel(ST_v616)
+,	/* CT_v617: (byte 0) */
   HW(2,1)
 , 0
-,	/* F0_LAMBDA594: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA594),1)
+,	/* F0_LAMBDA599: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA599),1)
 , VAPTAG(useLabel(FN_NHC_46FFI_46castPtrToFunPtr))
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v614)
+, useLabel(CT_v619)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46alignment[] = {
   useLabel(TM_NHC_46FFI)
@@ -277,8 +277,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46alignment[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 500003
-, useLabel(ST_v613)
-,	/* CT_v614: (byte 0) */
+, useLabel(ST_v618)
+,	/* CT_v619: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -286,7 +286,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46alignment[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46alignment),1)
 , VAPTAG(useLabel(FN_Prelude_46const))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v616)
+, useLabel(CT_v621)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46sizeOf[] = {
   useLabel(TM_NHC_46FFI)
@@ -295,8 +295,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46sizeOf[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 490003
-, useLabel(ST_v615)
-,	/* CT_v616: (byte 0) */
+, useLabel(ST_v620)
+,	/* CT_v621: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -304,7 +304,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46sizeOf[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46sizeOf),1)
 , VAPTAG(useLabel(FN_Prelude_46const))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v618)
+, useLabel(CT_v623)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46destruct[] = {
   useLabel(TM_NHC_46FFI)
@@ -312,8 +312,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46destruct[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 480010
-, useLabel(ST_v617)
-,	/* CT_v618: (byte 0) */
+, useLabel(ST_v622)
+,	/* CT_v623: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -323,7 +323,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46destruct[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr)
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v620)
+, useLabel(CT_v625)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46pokeByteOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -332,8 +332,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46pokeByteOff[] = {
 , bytes2word(3,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 480010
-, useLabel(ST_v619)
-,	/* CT_v620: (byte 0) */
+, useLabel(ST_v624)
+,	/* CT_v625: (byte 0) */
   HW(2,3)
 , 0
 ,};
@@ -343,7 +343,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46pokeByteOff[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v622)
+, useLabel(CT_v627)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekByteOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -351,8 +351,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekByteOff[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 480010
-, useLabel(ST_v621)
-,	/* CT_v622: (byte 0) */
+, useLabel(ST_v626)
+,	/* CT_v627: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -362,7 +362,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekByteOff[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr)
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v624)
+, useLabel(CT_v629)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46pokeElemOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -371,8 +371,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46pokeElemOff[] = {
 , bytes2word(3,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 480010
-, useLabel(ST_v623)
-,	/* CT_v624: (byte 0) */
+, useLabel(ST_v628)
+,	/* CT_v629: (byte 0) */
   HW(2,3)
 , 0
 ,};
@@ -382,7 +382,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46pokeElemOff[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v626)
+, useLabel(CT_v631)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekElemOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -390,8 +390,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekElemOff[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 480010
-, useLabel(ST_v625)
-,	/* CT_v626: (byte 0) */
+, useLabel(ST_v630)
+,	/* CT_v631: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -400,7 +400,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekElemOff[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46_95_46peekElemOff))
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v628)
+, useLabel(CT_v633)
 ,	/* FN_NHC_46FFI_46funPtrToInt: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
@@ -408,15 +408,15 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peekElemOff[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 410001
-, useLabel(ST_v627)
-,	/* CT_v628: (byte 0) */
+, useLabel(ST_v632)
+,	/* CT_v633: (byte 0) */
   HW(0,1)
 , 0
 ,	/* F0_NHC_46FFI_46funPtrToInt: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46funPtrToInt),1)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v630)
+, useLabel(CT_v635)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsPrec[] = {
   useLabel(TM_NHC_46FFI)
@@ -430,38 +430,38 @@ Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsPrec[] = {
 , bytes2word(5,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 470003
-, useLabel(ST_v629)
-,	/* CT_v630: (byte 0) */
+, useLabel(ST_v634)
+,	/* CT_v635: (byte 0) */
   HW(7,2)
 , 0
 ,};
 Node F0_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsPrec[] = {
   CAPTAG(useLabel(FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsPrec),2)
 , VAPTAG(useLabel(FN_Prelude_46showString))
-, VAPTAG(useLabel(FN_LAMBDA595))
+, VAPTAG(useLabel(FN_LAMBDA600))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
 , VAPTAG(useLabel(FN_Numeric_46showHex))
 , useLabel(CF_Prelude_46Integral_46Prelude_46Int)
 , VAPTAG(useLabel(FN_NHC_46FFI_46funPtrToInt))
 , VAPTAG(useLabel(FN_Prelude_46_46))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v633)
-,	/* FN_LAMBDA595: (byte 0) */
+, useLabel(CT_v638)
+,	/* FN_LAMBDA600: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v632)
+, useLabel(ST_v637)
 , 470030
-, useLabel(ST_v631)
-,	/* CT_v633: (byte 0) */
+, useLabel(ST_v636)
+,	/* CT_v638: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA595: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA595))
+,	/* CF_LAMBDA600: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA600))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v635)
+, useLabel(CT_v640)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46show[] = {
   useLabel(TM_NHC_46FFI)
@@ -469,8 +469,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46show[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 460010
-, useLabel(ST_v634)
-,	/* CT_v635: (byte 0) */
+, useLabel(ST_v639)
+,	/* CT_v640: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -479,7 +479,7 @@ Node F0_Prelude_46Show_46NHC_46FFI_46FunPtr_46show[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46show))
 , useLabel(CF_Prelude_46Show_46NHC_46FFI_46FunPtr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v637)
+, useLabel(CT_v642)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsType[] = {
   useLabel(TM_NHC_46FFI)
@@ -487,8 +487,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsType[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 460010
-, useLabel(ST_v636)
-,	/* CT_v637: (byte 0) */
+, useLabel(ST_v641)
+,	/* CT_v642: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -497,7 +497,7 @@ Node F0_Prelude_46Show_46NHC_46FFI_46FunPtr_46showsType[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46showsType))
 , useLabel(CF_Prelude_46Show_46NHC_46FFI_46FunPtr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v639)
+, useLabel(CT_v644)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showList[] = {
   useLabel(TM_NHC_46FFI)
@@ -505,8 +505,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr_46showList[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 460010
-, useLabel(ST_v638)
-,	/* CT_v639: (byte 0) */
+, useLabel(ST_v643)
+,	/* CT_v644: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -516,7 +516,7 @@ Node F0_Prelude_46Show_46NHC_46FFI_46FunPtr_46showList[] = {
 , useLabel(CF_Prelude_46Show_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v641)
+, useLabel(CT_v646)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46compare[] = {
   useLabel(TM_NHC_46FFI)
@@ -526,8 +526,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46compare[] = {
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 450003
-, useLabel(ST_v640)
-,	/* CT_v641: (byte 0) */
+, useLabel(ST_v645)
+,	/* CT_v646: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -537,7 +537,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46compare[] = {
 , VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Int_46compare))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v643)
+, useLabel(CT_v648)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46min[] = {
   useLabel(TM_NHC_46FFI)
@@ -545,8 +545,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46min[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 440010
-, useLabel(ST_v642)
-,	/* CT_v643: (byte 0) */
+, useLabel(ST_v647)
+,	/* CT_v648: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -556,7 +556,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46min[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v645)
+, useLabel(CT_v650)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46max[] = {
   useLabel(TM_NHC_46FFI)
@@ -564,8 +564,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46max[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 440010
-, useLabel(ST_v644)
-,	/* CT_v645: (byte 0) */
+, useLabel(ST_v649)
+,	/* CT_v650: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -575,7 +575,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46max[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v647)
+, useLabel(CT_v652)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_62[] = {
   useLabel(TM_NHC_46FFI)
@@ -583,8 +583,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_62[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 440010
-, useLabel(ST_v646)
-,	/* CT_v647: (byte 0) */
+, useLabel(ST_v651)
+,	/* CT_v652: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -594,7 +594,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_62[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v649)
+, useLabel(CT_v654)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_62_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -602,8 +602,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_62_61[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 440010
-, useLabel(ST_v648)
-,	/* CT_v649: (byte 0) */
+, useLabel(ST_v653)
+,	/* CT_v654: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -613,7 +613,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_62_61[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v651)
+, useLabel(CT_v656)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_60[] = {
   useLabel(TM_NHC_46FFI)
@@ -621,8 +621,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_60[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 440010
-, useLabel(ST_v650)
-,	/* CT_v651: (byte 0) */
+, useLabel(ST_v655)
+,	/* CT_v656: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -632,7 +632,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_60[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v653)
+, useLabel(CT_v658)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_60_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -640,8 +640,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_60_61[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 440010
-, useLabel(ST_v652)
-,	/* CT_v653: (byte 0) */
+, useLabel(ST_v657)
+,	/* CT_v658: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -651,7 +651,7 @@ Node F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46_60_61[] = {
 , useLabel(CF_Prelude_46Ord_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v655)
+, useLabel(CT_v660)
 ,};
 Node FN_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_61_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -662,8 +662,8 @@ Node FN_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_61_61[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 430003
-, useLabel(ST_v654)
-,	/* CT_v655: (byte 0) */
+, useLabel(ST_v659)
+,	/* CT_v660: (byte 0) */
   HW(1,2)
 , 0
 ,};
@@ -672,7 +672,7 @@ Node F0_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_61_61[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46funPtrToInt))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v657)
+, useLabel(CT_v662)
 ,};
 Node FN_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_47_61[] = {
   useLabel(TM_NHC_46FFI)
@@ -680,8 +680,8 @@ Node FN_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_47_61[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 420010
-, useLabel(ST_v656)
-,	/* CT_v657: (byte 0) */
+, useLabel(ST_v661)
+,	/* CT_v662: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -690,7 +690,7 @@ Node F0_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_47_61[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46_47_61))
 , useLabel(CF_Prelude_46Eq_46NHC_46FFI_46FunPtr)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v659)
+, useLabel(CT_v664)
 ,};
 Node FN_Prelude_46Eq_46NHC_46FFI_46FunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -700,8 +700,8 @@ Node FN_Prelude_46Eq_46NHC_46FFI_46FunPtr[] = {
 , 0
 , CONSTR(0,2,0)
 , 420010
-, useLabel(ST_v658)
-,	/* CT_v659: (byte 0) */
+, useLabel(ST_v663)
+,	/* CT_v664: (byte 0) */
   HW(2,0)
 , 0
 ,};
@@ -710,7 +710,7 @@ Node CF_Prelude_46Eq_46NHC_46FFI_46FunPtr[] = {
 , useLabel(F0_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_47_61)
 , useLabel(F0_Prelude_46Eq_46NHC_46FFI_46FunPtr_46_61_61)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v661)
+, useLabel(CT_v666)
 ,};
 Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -723,8 +723,8 @@ Node FN_Prelude_46Ord_46NHC_46FFI_46FunPtr[] = {
 , 0
 , CONSTR(0,8,0)
 , 440010
-, useLabel(ST_v660)
-,	/* CT_v661: (byte 0) */
+, useLabel(ST_v665)
+,	/* CT_v666: (byte 0) */
   HW(8,0)
 , 0
 ,};
@@ -739,7 +739,7 @@ Node CF_Prelude_46Ord_46NHC_46FFI_46FunPtr[] = {
 , useLabel(F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46min)
 , useLabel(F0_Prelude_46Ord_46NHC_46FFI_46FunPtr_46max)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v663)
+, useLabel(CT_v668)
 ,};
 Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -750,8 +750,8 @@ Node FN_Prelude_46Show_46NHC_46FFI_46FunPtr[] = {
 , 0
 , CONSTR(0,4,0)
 , 460010
-, useLabel(ST_v662)
-,	/* CT_v663: (byte 0) */
+, useLabel(ST_v667)
+,	/* CT_v668: (byte 0) */
   HW(4,0)
 , 0
 ,};
@@ -762,7 +762,7 @@ Node CF_Prelude_46Show_46NHC_46FFI_46FunPtr[] = {
 , useLabel(F0_Prelude_46Show_46NHC_46FFI_46FunPtr_46showList)
 , useLabel(F0_Prelude_46Show_46NHC_46FFI_46FunPtr_46show)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v665)
+, useLabel(CT_v670)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -775,8 +775,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , 0
 , CONSTR(0,9,0)
 , 480010
-, useLabel(ST_v664)
-,	/* CT_v665: (byte 0) */
+, useLabel(ST_v669)
+,	/* CT_v670: (byte 0) */
   HW(9,0)
 , 0
 ,};
@@ -791,8 +791,8 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , useLabel(F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46peek)
 , useLabel(F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46destruct)
 , useLabel(F0_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr_46alignment)
-,	/* ST_v632: (byte 0) */
- 	/* ST_v664: (byte 3) */
+,	/* ST_v637: (byte 0) */
+ 	/* ST_v669: (byte 3) */
   bytes2word(48,120,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,83)
@@ -801,7 +801,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(70,117,110,80)
-,	/* ST_v613: (byte 3) */
+,	/* ST_v618: (byte 3) */
   bytes2word(116,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,83)
@@ -813,7 +813,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(116,114,46,97)
 , bytes2word(108,105,103,110)
 , bytes2word(109,101,110,116)
-,	/* ST_v617: (byte 1) */
+,	/* ST_v622: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,83,116,111)
@@ -824,7 +824,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(110,80,116,114)
 , bytes2word(46,100,101,115)
 , bytes2word(116,114,117,99)
-,	/* ST_v609: (byte 2) */
+,	/* ST_v614: (byte 2) */
   bytes2word(116,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,83,116)
@@ -834,7 +834,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
 , bytes2word(114,46,112,101)
-,	/* ST_v611: (byte 3) */
+,	/* ST_v616: (byte 3) */
   bytes2word(101,107,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,83)
@@ -847,8 +847,8 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(101,101,107,58)
 , bytes2word(53,49,58,50)
 , bytes2word(51,45,53,49)
-,	/* ST_v621: (byte 4) */
-  bytes2word(58,51,55,0)
+,	/* ST_v626: (byte 4) */
+  bytes2word(58,51,56,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(83,116,111,114)
@@ -859,7 +859,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(80,116,114,46)
 , bytes2word(112,101,101,107)
 , bytes2word(66,121,116,101)
-,	/* ST_v625: (byte 4) */
+,	/* ST_v630: (byte 4) */
   bytes2word(79,102,102,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
@@ -871,7 +871,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(80,116,114,46)
 , bytes2word(112,101,101,107)
 , bytes2word(69,108,101,109)
-,	/* ST_v607: (byte 4) */
+,	/* ST_v612: (byte 4) */
   bytes2word(79,102,102,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
@@ -882,7 +882,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(46,70,117,110)
 , bytes2word(80,116,114,46)
 , bytes2word(112,111,107,101)
-,	/* ST_v619: (byte 1) */
+,	/* ST_v624: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,83,116,111)
@@ -894,7 +894,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(46,112,111,107)
 , bytes2word(101,66,121,116)
 , bytes2word(101,79,102,102)
-,	/* ST_v623: (byte 1) */
+,	/* ST_v628: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,83,116,111)
@@ -906,7 +906,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(46,112,111,107)
 , bytes2word(101,69,108,101)
 , bytes2word(109,79,102,102)
-,	/* ST_v615: (byte 1) */
+,	/* ST_v620: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,83,116,111)
@@ -916,27 +916,27 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(73,46,70,117)
 , bytes2word(110,80,116,114)
 , bytes2word(46,115,105,122)
-,	/* ST_v603: (byte 4) */
+,	/* ST_v608: (byte 4) */
   bytes2word(101,79,102,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(99,97,115,116)
 , bytes2word(70,117,110,80)
-,	/* ST_v599: (byte 3) */
+,	/* ST_v604: (byte 3) */
   bytes2word(116,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,99)
 , bytes2word(97,115,116,70)
 , bytes2word(117,110,80,116)
 , bytes2word(114,84,111,80)
-,	/* ST_v597: (byte 3) */
+,	/* ST_v602: (byte 3) */
   bytes2word(116,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,99)
 , bytes2word(97,115,116,80)
 , bytes2word(116,114,84,111)
 , bytes2word(70,117,110,80)
-,	/* ST_v601: (byte 3) */
+,	/* ST_v606: (byte 3) */
   bytes2word(116,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,102)
@@ -944,18 +944,18 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(97,115,107,101)
 , bytes2word(108,108,70,117)
 , bytes2word(110,80,116,114)
-,	/* ST_v627: (byte 1) */
+,	/* ST_v632: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,102,117,110)
 , bytes2word(80,116,114,84)
 , bytes2word(111,73,110,116)
-,	/* ST_v605: (byte 1) */
+,	/* ST_v610: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,110,117,108)
 , bytes2word(108,70,117,110)
-,	/* ST_v658: (byte 4) */
+,	/* ST_v663: (byte 4) */
   bytes2word(80,116,114,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -963,7 +963,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
-,	/* ST_v656: (byte 2) */
+,	/* ST_v661: (byte 2) */
   bytes2word(114,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,113)
@@ -971,7 +971,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(46,70,70,73)
 , bytes2word(46,70,117,110)
 , bytes2word(80,116,114,46)
-,	/* ST_v654: (byte 3) */
+,	/* ST_v659: (byte 3) */
   bytes2word(47,61,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,69)
@@ -979,7 +979,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,70,117)
 , bytes2word(110,80,116,114)
-,	/* ST_v660: (byte 4) */
+,	/* ST_v665: (byte 4) */
   bytes2word(46,61,61,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -987,7 +987,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(70,117,110,80)
-,	/* ST_v650: (byte 3) */
+,	/* ST_v655: (byte 3) */
   bytes2word(116,114,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
@@ -995,7 +995,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
-,	/* ST_v652: (byte 4) */
+,	/* ST_v657: (byte 4) */
   bytes2word(114,46,60,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -1004,7 +1004,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,70,73,46)
 , bytes2word(70,117,110,80)
 , bytes2word(116,114,46,60)
-,	/* ST_v646: (byte 2) */
+,	/* ST_v651: (byte 2) */
   bytes2word(61,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,79,114)
@@ -1012,7 +1012,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,70,117)
 , bytes2word(110,80,116,114)
-,	/* ST_v648: (byte 3) */
+,	/* ST_v653: (byte 3) */
   bytes2word(46,62,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
@@ -1021,7 +1021,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
 , bytes2word(114,46,62,61)
-,	/* ST_v640: (byte 1) */
+,	/* ST_v645: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,79,114,100)
@@ -1030,7 +1030,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(46,70,117,110)
 , bytes2word(80,116,114,46)
 , bytes2word(99,111,109,112)
-,	/* ST_v644: (byte 4) */
+,	/* ST_v649: (byte 4) */
   bytes2word(97,114,101,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -1039,7 +1039,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,70,73,46)
 , bytes2word(70,117,110,80)
 , bytes2word(116,114,46,109)
-,	/* ST_v642: (byte 3) */
+,	/* ST_v647: (byte 3) */
   bytes2word(97,120,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,79)
@@ -1048,7 +1048,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
 , bytes2word(114,46,109,105)
-,	/* ST_v662: (byte 2) */
+,	/* ST_v667: (byte 2) */
   bytes2word(110,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,83,104)
@@ -1056,7 +1056,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
-,	/* ST_v634: (byte 2) */
+,	/* ST_v639: (byte 2) */
   bytes2word(114,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,83,104)
@@ -1065,7 +1065,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,73,46,70)
 , bytes2word(117,110,80,116)
 , bytes2word(114,46,115,104)
-,	/* ST_v638: (byte 3) */
+,	/* ST_v643: (byte 3) */
   bytes2word(111,119,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,83)
@@ -1075,7 +1075,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(70,117,110,80)
 , bytes2word(116,114,46,115)
 , bytes2word(104,111,119,76)
-,	/* ST_v629: (byte 4) */
+,	/* ST_v634: (byte 4) */
   bytes2word(105,115,116,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -1086,7 +1086,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(80,116,114,46)
 , bytes2word(115,104,111,119)
 , bytes2word(115,80,114,101)
-,	/* ST_v631: (byte 2) */
+,	/* ST_v636: (byte 2) */
   bytes2word(99,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,83,104)
@@ -1099,7 +1099,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46FunPtr[] = {
 , bytes2word(114,101,99,58)
 , bytes2word(52,55,58,51)
 , bytes2word(48,45,52,55)
-,	/* ST_v636: (byte 4) */
+,	/* ST_v641: (byte 4) */
   bytes2word(58,51,51,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -1122,13 +1122,13 @@ static SInfo pf_NHC_46FFI_46castPtrToFunPtr = {"NHC.FFI","NHC.FFI.castPtrToFunPt
 #endif
 C_HEADER(FR_NHC_46FFI_46castPtrToFunPtr) {
   NodePtr nodeptr;
-  NodePtr(*result)();
+  Node*(*result)();
   void* arg1;
   nodeptr = C_GETARG1(1);
   IND_REMOVE(nodeptr);
   arg1 = (void*)GET_INT_VALUE(nodeptr);
 
-  result = (NodePtr(*)())(arg1);
+  result = (Node*(*)())(arg1);
 
   nodeptr = nhc_mkInt((int)result);
   INIT_PROFINFO(nodeptr,&pf_NHC_46FFI_46castPtrToFunPtr);
@@ -1142,10 +1142,10 @@ static SInfo pf_NHC_46FFI_46castFunPtrToPtr = {"NHC.FFI","NHC.FFI.castFunPtrToPt
 C_HEADER(FR_NHC_46FFI_46castFunPtrToPtr) {
   NodePtr nodeptr;
   void* result;
-  NodePtr(*arg1)();
+  Node*(*arg1)();
   nodeptr = C_GETARG1(1);
   IND_REMOVE(nodeptr);
-  arg1 = (NodePtr(*)())GET_INT_VALUE(nodeptr);
+  arg1 = (Node*(*)())GET_INT_VALUE(nodeptr);
 
   result = (void*)(arg1);
 
@@ -1161,10 +1161,10 @@ static SInfo pf_NHC_46FFI_46funPtrToInt = {"NHC.FFI","NHC.FFI.funPtrToInt","Prel
 C_HEADER(FR_NHC_46FFI_46funPtrToInt) {
   NodePtr nodeptr;
   HsInt result;
-  NodePtr(*arg1)();
+  Node*(*arg1)();
   nodeptr = C_GETARG1(1);
   IND_REMOVE(nodeptr);
-  arg1 = (NodePtr(*)())GET_INT_VALUE(nodeptr);
+  arg1 = (Node*(*)())GET_INT_VALUE(nodeptr);
 
   result = (HsInt)(arg1);
 
