@@ -1,52 +1,52 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v375	((void*)startLabel+36)
-#define CT_v377	((void*)startLabel+92)
-#define CT_v379	((void*)startLabel+152)
-#define CT_v381	((void*)startLabel+208)
-#define FN_LAMBDA372	((void*)startLabel+244)
-#define CT_v383	((void*)startLabel+272)
-#define F0_LAMBDA372	((void*)startLabel+280)
-#define CT_v385	((void*)startLabel+328)
-#define CT_v387	((void*)startLabel+380)
-#define CT_v389	((void*)startLabel+428)
-#define CT_v391	((void*)startLabel+488)
-#define CT_v393	((void*)startLabel+544)
-#define CT_v395	((void*)startLabel+604)
-#define CT_v397	((void*)startLabel+660)
+#define CT_v380	((void*)startLabel+36)
+#define CT_v382	((void*)startLabel+92)
+#define CT_v384	((void*)startLabel+152)
+#define CT_v386	((void*)startLabel+208)
+#define FN_LAMBDA377	((void*)startLabel+244)
+#define CT_v388	((void*)startLabel+272)
+#define F0_LAMBDA377	((void*)startLabel+280)
+#define CT_v390	((void*)startLabel+328)
+#define CT_v392	((void*)startLabel+380)
+#define CT_v394	((void*)startLabel+428)
+#define CT_v396	((void*)startLabel+488)
+#define CT_v398	((void*)startLabel+544)
+#define CT_v400	((void*)startLabel+604)
+#define CT_v402	((void*)startLabel+660)
 #define FN_NHC_46FFI_46freeStablePtr_35	((void*)startLabel+688)
-#define CT_v399	((void*)startLabel+716)
+#define CT_v404	((void*)startLabel+716)
 #define F0_NHC_46FFI_46freeStablePtr_35	((void*)startLabel+724)
-#define CT_v401	((void*)startLabel+760)
+#define CT_v406	((void*)startLabel+760)
 #define FN_NHC_46FFI_46deRefStablePtr_35	((void*)startLabel+788)
-#define CT_v403	((void*)startLabel+816)
+#define CT_v408	((void*)startLabel+816)
 #define F0_NHC_46FFI_46deRefStablePtr_35	((void*)startLabel+824)
-#define CT_v405	((void*)startLabel+860)
+#define CT_v410	((void*)startLabel+860)
 #define FN_NHC_46FFI_46newStablePtr_35	((void*)startLabel+888)
-#define CT_v407	((void*)startLabel+916)
+#define CT_v412	((void*)startLabel+916)
 #define F0_NHC_46FFI_46newStablePtr_35	((void*)startLabel+924)
-#define CT_v409	((void*)startLabel+960)
-#define CT_v411	((void*)startLabel+1032)
-#define ST_v410	((void*)startLabel+1080)
-#define ST_v384	((void*)startLabel+1115)
-#define ST_v388	((void*)startLabel+1160)
-#define ST_v380	((void*)startLabel+1204)
-#define ST_v382	((void*)startLabel+1244)
-#define ST_v392	((void*)startLabel+1296)
-#define ST_v396	((void*)startLabel+1343)
-#define ST_v376	((void*)startLabel+1390)
-#define ST_v390	((void*)startLabel+1430)
-#define ST_v394	((void*)startLabel+1477)
-#define ST_v386	((void*)startLabel+1524)
-#define ST_v378	((void*)startLabel+1566)
-#define ST_v374	((void*)startLabel+1593)
-#define ST_v404	((void*)startLabel+1620)
-#define ST_v402	((void*)startLabel+1643)
-#define ST_v400	((void*)startLabel+1667)
-#define ST_v398	((void*)startLabel+1689)
-#define ST_v408	((void*)startLabel+1712)
-#define ST_v406	((void*)startLabel+1733)
+#define CT_v414	((void*)startLabel+960)
+#define CT_v416	((void*)startLabel+1032)
+#define ST_v415	((void*)startLabel+1080)
+#define ST_v389	((void*)startLabel+1115)
+#define ST_v393	((void*)startLabel+1160)
+#define ST_v385	((void*)startLabel+1204)
+#define ST_v387	((void*)startLabel+1244)
+#define ST_v397	((void*)startLabel+1296)
+#define ST_v401	((void*)startLabel+1343)
+#define ST_v381	((void*)startLabel+1390)
+#define ST_v395	((void*)startLabel+1430)
+#define ST_v399	((void*)startLabel+1477)
+#define ST_v391	((void*)startLabel+1524)
+#define ST_v383	((void*)startLabel+1566)
+#define ST_v379	((void*)startLabel+1593)
+#define ST_v409	((void*)startLabel+1620)
+#define ST_v407	((void*)startLabel+1643)
+#define ST_v405	((void*)startLabel+1667)
+#define ST_v403	((void*)startLabel+1689)
+#define ST_v413	((void*)startLabel+1712)
+#define ST_v411	((void*)startLabel+1733)
 extern Node TM_NHC_46FFI[];
 void FR_NHC_46FFI_46castStablePtrToPtr(void);
 extern Node FN_NHC_46FFI_46castPtr[];
@@ -70,7 +70,7 @@ void FR_NHC_46FFI_46newStablePtr_35(void);
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v375)
+, useLabel(CT_v380)
 ,};
 Node FN_NHC_46FFI_46castStablePtrToPtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -79,8 +79,8 @@ Node FN_NHC_46FFI_46castStablePtrToPtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 190001
-, useLabel(ST_v374)
-,	/* CT_v375: (byte 0) */
+, useLabel(ST_v379)
+,	/* CT_v380: (byte 0) */
   HW(0,1)
 , 0
 ,};
@@ -88,7 +88,7 @@ Node F0_NHC_46FFI_46castStablePtrToPtr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46castStablePtrToPtr),1)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v377)
+, useLabel(CT_v382)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46poke[] = {
   useLabel(TM_NHC_46FFI)
@@ -98,8 +98,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46poke[] = {
 , bytes2word(4,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 260003
-, useLabel(ST_v376)
-,	/* CT_v377: (byte 0) */
+, useLabel(ST_v381)
+,	/* CT_v382: (byte 0) */
   HW(3,2)
 , 0
 ,};
@@ -109,7 +109,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46poke[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46castStablePtrToPtr))
 , VAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46Ptr_46poke))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v379)
+, useLabel(CT_v384)
 ,};
 Node FN_NHC_46FFI_46castPtrToStablePtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -118,15 +118,15 @@ Node FN_NHC_46FFI_46castPtrToStablePtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 200001
-, useLabel(ST_v378)
-,	/* CT_v379: (byte 0) */
+, useLabel(ST_v383)
+,	/* CT_v384: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_NHC_46FFI_46castPtrToStablePtr[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46castPtrToStablePtr),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v381)
+, useLabel(CT_v386)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peek[] = {
   useLabel(TM_NHC_46FFI)
@@ -137,8 +137,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peek[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 250003
-, useLabel(ST_v380)
-,	/* CT_v381: (byte 0) */
+, useLabel(ST_v385)
+,	/* CT_v386: (byte 0) */
   HW(4,1)
 , 0
 ,};
@@ -146,27 +146,27 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peek[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peek),1)
 , VAPTAG(useLabel(FN_NHC_46FFI_46castPtr))
 , VAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46Ptr_46peek))
-, CAPTAG(useLabel(FN_LAMBDA372),1)
+, CAPTAG(useLabel(FN_LAMBDA377),1)
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v383)
-,	/* FN_LAMBDA372: (byte 0) */
+, useLabel(CT_v388)
+,	/* FN_LAMBDA377: (byte 0) */
   useLabel(TMSUB_NHC_46FFI)
 , bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 250023
-, useLabel(ST_v382)
-,	/* CT_v383: (byte 0) */
+, useLabel(ST_v387)
+,	/* CT_v388: (byte 0) */
   HW(2,1)
 , 0
-,	/* F0_LAMBDA372: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA372),1)
+,	/* F0_LAMBDA377: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA377),1)
 , VAPTAG(useLabel(FN_NHC_46FFI_46castPtrToStablePtr))
 , VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v385)
+, useLabel(CT_v390)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46alignment[] = {
   useLabel(TM_NHC_46FFI)
@@ -175,8 +175,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46alignment[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 240003
-, useLabel(ST_v384)
-,	/* CT_v385: (byte 0) */
+, useLabel(ST_v389)
+,	/* CT_v390: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -184,7 +184,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46alignment[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46alignment),1)
 , VAPTAG(useLabel(FN_Prelude_46const))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v387)
+, useLabel(CT_v392)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46sizeOf[] = {
   useLabel(TM_NHC_46FFI)
@@ -193,8 +193,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46sizeOf[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 230003
-, useLabel(ST_v386)
-,	/* CT_v387: (byte 0) */
+, useLabel(ST_v391)
+,	/* CT_v392: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -202,7 +202,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46sizeOf[] = {
   CAPTAG(useLabel(FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46sizeOf),1)
 , VAPTAG(useLabel(FN_Prelude_46const))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v389)
+, useLabel(CT_v394)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46destruct[] = {
   useLabel(TM_NHC_46FFI)
@@ -210,8 +210,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46destruct[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 220010
-, useLabel(ST_v388)
-,	/* CT_v389: (byte 0) */
+, useLabel(ST_v393)
+,	/* CT_v394: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -221,7 +221,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46destruct[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr)
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v391)
+, useLabel(CT_v396)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46pokeByteOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -230,8 +230,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46pokeByteOff[] = {
 , bytes2word(3,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 220010
-, useLabel(ST_v390)
-,	/* CT_v391: (byte 0) */
+, useLabel(ST_v395)
+,	/* CT_v396: (byte 0) */
   HW(2,3)
 , 0
 ,};
@@ -241,7 +241,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46pokeByteOff[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v393)
+, useLabel(CT_v398)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekByteOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -249,8 +249,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekByteOff[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 220010
-, useLabel(ST_v392)
-,	/* CT_v393: (byte 0) */
+, useLabel(ST_v397)
+,	/* CT_v398: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -260,7 +260,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekByteOff[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr)
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v395)
+, useLabel(CT_v400)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46pokeElemOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -269,8 +269,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46pokeElemOff[] = {
 , bytes2word(3,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 220010
-, useLabel(ST_v394)
-,	/* CT_v395: (byte 0) */
+, useLabel(ST_v399)
+,	/* CT_v400: (byte 0) */
   HW(2,3)
 , 0
 ,};
@@ -280,7 +280,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46pokeElemOff[] = {
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v397)
+, useLabel(CT_v402)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekElemOff[] = {
   useLabel(TM_NHC_46FFI)
@@ -288,8 +288,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekElemOff[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 220010
-, useLabel(ST_v396)
-,	/* CT_v397: (byte 0) */
+, useLabel(ST_v401)
+,	/* CT_v402: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -298,7 +298,7 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekElemOff[] = {
 , VAPTAG(useLabel(FN_NHC_46FFI_46_95_46peekElemOff))
 , useLabel(CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v399)
+, useLabel(CT_v404)
 ,	/* FN_NHC_46FFI_46freeStablePtr_35: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
@@ -306,14 +306,14 @@ Node F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peekElemOff[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 170001
-, useLabel(ST_v398)
-,	/* CT_v399: (byte 0) */
+, useLabel(ST_v403)
+,	/* CT_v404: (byte 0) */
   HW(0,1)
 , 0
 ,	/* F0_NHC_46FFI_46freeStablePtr_35: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46freeStablePtr_35),1)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v401)
+, useLabel(CT_v406)
 ,};
 Node FN_NHC_46FFI_46freeStablePtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -321,8 +321,8 @@ Node FN_NHC_46FFI_46freeStablePtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 170001
-, useLabel(ST_v400)
-,	/* CT_v401: (byte 0) */
+, useLabel(ST_v405)
+,	/* CT_v406: (byte 0) */
   HW(2,0)
 , 0
 ,};
@@ -331,7 +331,7 @@ Node CF_NHC_46FFI_46freeStablePtr[] = {
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
 , useLabel(F0_NHC_46FFI_46freeStablePtr_35)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v403)
+, useLabel(CT_v408)
 ,	/* FN_NHC_46FFI_46deRefStablePtr_35: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
@@ -339,14 +339,14 @@ Node CF_NHC_46FFI_46freeStablePtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 160001
-, useLabel(ST_v402)
-,	/* CT_v403: (byte 0) */
+, useLabel(ST_v407)
+,	/* CT_v408: (byte 0) */
   HW(0,1)
 , 0
 ,	/* F0_NHC_46FFI_46deRefStablePtr_35: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46deRefStablePtr_35),1)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v405)
+, useLabel(CT_v410)
 ,};
 Node FN_NHC_46FFI_46deRefStablePtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -354,8 +354,8 @@ Node FN_NHC_46FFI_46deRefStablePtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 160001
-, useLabel(ST_v404)
-,	/* CT_v405: (byte 0) */
+, useLabel(ST_v409)
+,	/* CT_v410: (byte 0) */
   HW(2,0)
 , 0
 ,};
@@ -364,7 +364,7 @@ Node CF_NHC_46FFI_46deRefStablePtr[] = {
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
 , useLabel(F0_NHC_46FFI_46deRefStablePtr_35)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v407)
+, useLabel(CT_v412)
 ,	/* FN_NHC_46FFI_46newStablePtr_35: (byte 0) */
   useLabel(TM_NHC_46FFI)
 , bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
@@ -372,14 +372,14 @@ Node CF_NHC_46FFI_46deRefStablePtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 150001
-, useLabel(ST_v406)
-,	/* CT_v407: (byte 0) */
+, useLabel(ST_v411)
+,	/* CT_v412: (byte 0) */
   HW(0,1)
 , 0
 ,	/* F0_NHC_46FFI_46newStablePtr_35: (byte 0) */
   CAPTAG(useLabel(FN_NHC_46FFI_46newStablePtr_35),1)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v409)
+, useLabel(CT_v414)
 ,};
 Node FN_NHC_46FFI_46newStablePtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -387,8 +387,8 @@ Node FN_NHC_46FFI_46newStablePtr[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 150001
-, useLabel(ST_v408)
-,	/* CT_v409: (byte 0) */
+, useLabel(ST_v413)
+,	/* CT_v414: (byte 0) */
   HW(2,0)
 , 0
 ,};
@@ -397,7 +397,7 @@ Node CF_NHC_46FFI_46newStablePtr[] = {
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
 , useLabel(F0_NHC_46FFI_46newStablePtr_35)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v411)
+, useLabel(CT_v416)
 ,};
 Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
   useLabel(TM_NHC_46FFI)
@@ -410,8 +410,8 @@ Node FN_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , 0
 , CONSTR(0,9,0)
 , 220010
-, useLabel(ST_v410)
-,	/* CT_v411: (byte 0) */
+, useLabel(ST_v415)
+,	/* CT_v416: (byte 0) */
   HW(9,0)
 , 0
 ,};
@@ -426,7 +426,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , useLabel(F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46peek)
 , useLabel(F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46destruct)
 , useLabel(F0_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr_46alignment)
-,	/* ST_v410: (byte 0) */
+,	/* ST_v415: (byte 0) */
   bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(83,116,111,114)
@@ -435,7 +435,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(46,70,70,73)
 , bytes2word(46,83,116,97)
 , bytes2word(98,108,101,80)
-,	/* ST_v384: (byte 3) */
+,	/* ST_v389: (byte 3) */
   bytes2word(116,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,83)
@@ -447,7 +447,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(108,101,80,116)
 , bytes2word(114,46,97,108)
 , bytes2word(105,103,110,109)
-,	/* ST_v388: (byte 4) */
+,	/* ST_v393: (byte 4) */
   bytes2word(101,110,116,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
@@ -459,7 +459,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(98,108,101,80)
 , bytes2word(116,114,46,100)
 , bytes2word(101,115,116,114)
-,	/* ST_v380: (byte 4) */
+,	/* ST_v385: (byte 4) */
   bytes2word(117,99,116,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
@@ -470,7 +470,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(46,83,116,97)
 , bytes2word(98,108,101,80)
 , bytes2word(116,114,46,112)
-,	/* ST_v382: (byte 4) */
+,	/* ST_v387: (byte 4) */
   bytes2word(101,101,107,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
@@ -484,8 +484,8 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(101,101,107,58)
 , bytes2word(50,53,58,50)
 , bytes2word(51,45,50,53)
-,	/* ST_v392: (byte 4) */
-  bytes2word(58,51,55,0)
+,	/* ST_v397: (byte 4) */
+  bytes2word(58,51,56,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(83,116,111,114)
@@ -497,7 +497,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(116,114,46,112)
 , bytes2word(101,101,107,66)
 , bytes2word(121,116,101,79)
-,	/* ST_v396: (byte 3) */
+,	/* ST_v401: (byte 3) */
   bytes2word(102,102,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,83)
@@ -510,7 +510,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(114,46,112,101)
 , bytes2word(101,107,69,108)
 , bytes2word(101,109,79,102)
-,	/* ST_v376: (byte 2) */
+,	/* ST_v381: (byte 2) */
   bytes2word(102,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,83,116)
@@ -521,7 +521,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(116,97,98,108)
 , bytes2word(101,80,116,114)
 , bytes2word(46,112,111,107)
-,	/* ST_v390: (byte 2) */
+,	/* ST_v395: (byte 2) */
   bytes2word(101,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,83,116)
@@ -534,7 +534,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(46,112,111,107)
 , bytes2word(101,66,121,116)
 , bytes2word(101,79,102,102)
-,	/* ST_v394: (byte 1) */
+,	/* ST_v399: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,83,116,111)
@@ -546,7 +546,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(80,116,114,46)
 , bytes2word(112,111,107,101)
 , bytes2word(69,108,101,109)
-,	/* ST_v386: (byte 4) */
+,	/* ST_v391: (byte 4) */
   bytes2word(79,102,102,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
@@ -558,7 +558,7 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(98,108,101,80)
 , bytes2word(116,114,46,115)
 , bytes2word(105,122,101,79)
-,	/* ST_v378: (byte 2) */
+,	/* ST_v383: (byte 2) */
   bytes2word(102,0,78,72)
 , bytes2word(67,46,70,70)
 , bytes2word(73,46,99,97)
@@ -566,48 +566,48 @@ Node CF_NHC_46FFI_46Storable_46NHC_46FFI_46StablePtr[] = {
 , bytes2word(114,84,111,83)
 , bytes2word(116,97,98,108)
 , bytes2word(101,80,116,114)
-,	/* ST_v374: (byte 1) */
+,	/* ST_v379: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,99,97,115)
 , bytes2word(116,83,116,97)
 , bytes2word(98,108,101,80)
 , bytes2word(116,114,84,111)
-,	/* ST_v404: (byte 4) */
+,	/* ST_v409: (byte 4) */
   bytes2word(80,116,114,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(100,101,82,101)
 , bytes2word(102,83,116,97)
 , bytes2word(98,108,101,80)
-,	/* ST_v402: (byte 3) */
+,	/* ST_v407: (byte 3) */
   bytes2word(116,114,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,100)
 , bytes2word(101,82,101,102)
 , bytes2word(83,116,97,98)
 , bytes2word(108,101,80,116)
-,	/* ST_v400: (byte 3) */
+,	/* ST_v405: (byte 3) */
   bytes2word(114,35,0,78)
 , bytes2word(72,67,46,70)
 , bytes2word(70,73,46,102)
 , bytes2word(114,101,101,83)
 , bytes2word(116,97,98,108)
 , bytes2word(101,80,116,114)
-,	/* ST_v398: (byte 1) */
+,	/* ST_v403: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,102,114,101)
 , bytes2word(101,83,116,97)
 , bytes2word(98,108,101,80)
-,	/* ST_v408: (byte 4) */
+,	/* ST_v413: (byte 4) */
   bytes2word(116,114,35,0)
 , bytes2word(78,72,67,46)
 , bytes2word(70,70,73,46)
 , bytes2word(110,101,119,83)
 , bytes2word(116,97,98,108)
 , bytes2word(101,80,116,114)
-,	/* ST_v406: (byte 1) */
+,	/* ST_v411: (byte 1) */
   bytes2word(0,78,72,67)
 , bytes2word(46,70,70,73)
 , bytes2word(46,110,101,119)
@@ -677,13 +677,13 @@ C_HEADER(FR_NHC_46FFI_46freeStablePtr_35) {
 }
 
 /* foreign import ccall "derefStablePtr" NHC.FFI.deRefStablePtr# 1 :: FFI.StablePtr -> 1 */
-extern NodePtr derefStablePtr(StablePtr);
+extern Node* derefStablePtr(StablePtr);
 #ifdef PROFILE
 static SInfo pf_NHC_46FFI_46deRefStablePtr_35 = {"NHC.FFI","NHC.FFI.deRefStablePtr#","1"};
 #endif
 C_HEADER(FR_NHC_46FFI_46deRefStablePtr_35) {
   NodePtr nodeptr;
-  NodePtr result;
+  Node* result;
   StablePtr arg1;
   nodeptr = C_GETARG1(1);
   IND_REMOVE(nodeptr);
@@ -697,17 +697,17 @@ C_HEADER(FR_NHC_46FFI_46deRefStablePtr_35) {
 }
 
 /* foreign import ccall "makeStablePtr" NHC.FFI.newStablePtr# 1 :: 1 -> FFI.StablePtr */
-extern StablePtr makeStablePtr(NodePtr);
+extern StablePtr makeStablePtr(Node*);
 #ifdef PROFILE
 static SInfo pf_NHC_46FFI_46newStablePtr_35 = {"NHC.FFI","NHC.FFI.newStablePtr#","FFI.StablePtr"};
 #endif
 C_HEADER(FR_NHC_46FFI_46newStablePtr_35) {
   NodePtr nodeptr;
   StablePtr result;
-  NodePtr arg1;
+  Node* arg1;
   nodeptr = C_GETARG1(1);
   IND_REMOVE(nodeptr);
-  arg1 = (NodePtr)nodeptr;
+  arg1 = (Node*)nodeptr;
 
   result = makeStablePtr(arg1);
 
