@@ -1,18 +1,15 @@
-{-# OPTIONS_COMPILE -cpp #-}
 module IO (hPutStr) where
 
 import DHandle
 import HPutChar
 
-#if 1
 -- This is the definitely working, but inefficient, version.
 hPutStr               :: Handle -> String -> IO ()
 hPutStr h []           = return ()
 hPutStr h (x:xs)       = hPutChar h x >> hPutStr h xs
 
-#else
-
 
+{-
 -- This version does string-packing in chunks on the
 -- C-side, improving the performance no matter how large
 -- the string is.
@@ -33,5 +30,5 @@ hPutStr h xs@(x:_)     = hPutStrC h xs
 --      hPutStr = hPutStrC
 -- gives an "unevaluated tag in TABLESWITCH" runtime crash.
 
-#endif
+-}
 
