@@ -1,97 +1,97 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v384	((void*)startLabel+92)
-#define FN_LAMBDA366	((void*)startLabel+136)
-#define CT_v388	((void*)startLabel+180)
-#define CF_LAMBDA366	((void*)startLabel+188)
-#define v391	((void*)startLabel+408)
-#define CT_v405	((void*)startLabel+648)
-#define v408	((void*)startLabel+912)
-#define CT_v422	((void*)startLabel+1152)
-#define v426	((void*)startLabel+1462)
-#define v427	((void*)startLabel+1466)
-#define v428	((void*)startLabel+1487)
-#define v430	((void*)startLabel+1648)
-#define v432	((void*)startLabel+1724)
-#define v433	((void*)startLabel+1889)
-#define CT_v456	((void*)startLabel+2392)
-#define CT_v463	((void*)startLabel+2568)
-#define CT_v466	((void*)startLabel+2628)
-#define CT_v469	((void*)startLabel+2684)
-#define CT_v472	((void*)startLabel+2740)
-#define CT_v475	((void*)startLabel+2796)
-#define CT_v478	((void*)startLabel+2852)
-#define CT_v481	((void*)startLabel+2908)
-#define CT_v484	((void*)startLabel+2964)
-#define ST_v387	((void*)startLabel+2992)
-#define ST_v468	((void*)startLabel+3048)
-#define ST_v465	((void*)startLabel+3084)
-#define ST_v411	((void*)startLabel+3116)
-#define ST_v394	((void*)startLabel+3136)
-#define ST_v381	((void*)startLabel+3152)
-#define PP_LAMBDA366	((void*)startLabel+3177)
-#define PC_LAMBDA366	((void*)startLabel+3177)
-#define ST_v386	((void*)startLabel+3177)
-#define ST_v436	((void*)startLabel+3208)
-#define ST_v460	((void*)startLabel+3224)
-#define ST_v477	((void*)startLabel+3244)
-#define ST_v483	((void*)startLabel+3260)
-#define ST_v480	((void*)startLabel+3276)
-#define ST_v471	((void*)startLabel+3300)
-#define ST_v474	((void*)startLabel+3316)
-#define PS_v473	((void*)startLabel+3336)
-#define PS_v470	((void*)startLabel+3348)
-#define PS_v476	((void*)startLabel+3360)
-#define PS_v482	((void*)startLabel+3372)
-#define PS_v479	((void*)startLabel+3384)
-#define PS_v461	((void*)startLabel+3396)
-#define PS_v459	((void*)startLabel+3408)
-#define PS_v446	((void*)startLabel+3420)
-#define PS_v447	((void*)startLabel+3432)
-#define PS_v443	((void*)startLabel+3444)
-#define PS_v452	((void*)startLabel+3456)
-#define PS_v437	((void*)startLabel+3468)
-#define PS_v445	((void*)startLabel+3480)
-#define PS_v450	((void*)startLabel+3492)
-#define PS_v453	((void*)startLabel+3504)
-#define PS_v441	((void*)startLabel+3516)
-#define PS_v455	((void*)startLabel+3528)
-#define PS_v442	((void*)startLabel+3540)
-#define PS_v448	((void*)startLabel+3552)
-#define PS_v435	((void*)startLabel+3564)
-#define PS_v449	((void*)startLabel+3576)
-#define PS_v439	((void*)startLabel+3588)
-#define PS_v440	((void*)startLabel+3600)
-#define PS_v454	((void*)startLabel+3612)
-#define PS_v444	((void*)startLabel+3624)
-#define PS_v417	((void*)startLabel+3636)
-#define PS_v412	((void*)startLabel+3648)
-#define PS_v419	((void*)startLabel+3660)
-#define PS_v421	((void*)startLabel+3672)
-#define PS_v416	((void*)startLabel+3684)
-#define PS_v410	((void*)startLabel+3696)
-#define PS_v418	((void*)startLabel+3708)
-#define PS_v414	((void*)startLabel+3720)
-#define PS_v415	((void*)startLabel+3732)
-#define PS_v420	((void*)startLabel+3744)
-#define PS_v400	((void*)startLabel+3756)
-#define PS_v395	((void*)startLabel+3768)
-#define PS_v402	((void*)startLabel+3780)
-#define PS_v404	((void*)startLabel+3792)
-#define PS_v399	((void*)startLabel+3804)
-#define PS_v393	((void*)startLabel+3816)
-#define PS_v401	((void*)startLabel+3828)
-#define PS_v397	((void*)startLabel+3840)
-#define PS_v398	((void*)startLabel+3852)
-#define PS_v403	((void*)startLabel+3864)
-#define PS_v383	((void*)startLabel+3876)
-#define PS_v380	((void*)startLabel+3888)
-#define PS_v382	((void*)startLabel+3900)
-#define PS_v464	((void*)startLabel+3912)
-#define PS_v467	((void*)startLabel+3924)
-#define PS_v385	((void*)startLabel+3936)
-extern Node FN_Prelude_46error[];
+#define CT_v389	((void*)startLabel+92)
+#define FN_LAMBDA371	((void*)startLabel+136)
+#define CT_v393	((void*)startLabel+180)
+#define CF_LAMBDA371	((void*)startLabel+188)
+#define v396	((void*)startLabel+408)
+#define CT_v410	((void*)startLabel+648)
+#define v413	((void*)startLabel+912)
+#define CT_v427	((void*)startLabel+1152)
+#define v431	((void*)startLabel+1462)
+#define v432	((void*)startLabel+1466)
+#define v433	((void*)startLabel+1487)
+#define v435	((void*)startLabel+1648)
+#define v437	((void*)startLabel+1724)
+#define v438	((void*)startLabel+1889)
+#define CT_v461	((void*)startLabel+2392)
+#define CT_v468	((void*)startLabel+2568)
+#define CT_v471	((void*)startLabel+2628)
+#define CT_v474	((void*)startLabel+2684)
+#define CT_v477	((void*)startLabel+2740)
+#define CT_v480	((void*)startLabel+2796)
+#define CT_v483	((void*)startLabel+2852)
+#define CT_v486	((void*)startLabel+2908)
+#define CT_v489	((void*)startLabel+2964)
+#define ST_v392	((void*)startLabel+2992)
+#define ST_v473	((void*)startLabel+3048)
+#define ST_v470	((void*)startLabel+3084)
+#define ST_v416	((void*)startLabel+3116)
+#define ST_v399	((void*)startLabel+3136)
+#define ST_v386	((void*)startLabel+3152)
+#define PP_LAMBDA371	((void*)startLabel+3177)
+#define PC_LAMBDA371	((void*)startLabel+3177)
+#define ST_v391	((void*)startLabel+3177)
+#define ST_v441	((void*)startLabel+3208)
+#define ST_v465	((void*)startLabel+3224)
+#define ST_v482	((void*)startLabel+3244)
+#define ST_v488	((void*)startLabel+3260)
+#define ST_v485	((void*)startLabel+3276)
+#define ST_v476	((void*)startLabel+3300)
+#define ST_v479	((void*)startLabel+3316)
+#define PS_v478	((void*)startLabel+3336)
+#define PS_v475	((void*)startLabel+3348)
+#define PS_v481	((void*)startLabel+3360)
+#define PS_v487	((void*)startLabel+3372)
+#define PS_v484	((void*)startLabel+3384)
+#define PS_v466	((void*)startLabel+3396)
+#define PS_v464	((void*)startLabel+3408)
+#define PS_v451	((void*)startLabel+3420)
+#define PS_v452	((void*)startLabel+3432)
+#define PS_v448	((void*)startLabel+3444)
+#define PS_v457	((void*)startLabel+3456)
+#define PS_v442	((void*)startLabel+3468)
+#define PS_v450	((void*)startLabel+3480)
+#define PS_v455	((void*)startLabel+3492)
+#define PS_v458	((void*)startLabel+3504)
+#define PS_v446	((void*)startLabel+3516)
+#define PS_v460	((void*)startLabel+3528)
+#define PS_v447	((void*)startLabel+3540)
+#define PS_v453	((void*)startLabel+3552)
+#define PS_v440	((void*)startLabel+3564)
+#define PS_v454	((void*)startLabel+3576)
+#define PS_v444	((void*)startLabel+3588)
+#define PS_v445	((void*)startLabel+3600)
+#define PS_v459	((void*)startLabel+3612)
+#define PS_v449	((void*)startLabel+3624)
+#define PS_v422	((void*)startLabel+3636)
+#define PS_v417	((void*)startLabel+3648)
+#define PS_v424	((void*)startLabel+3660)
+#define PS_v426	((void*)startLabel+3672)
+#define PS_v421	((void*)startLabel+3684)
+#define PS_v415	((void*)startLabel+3696)
+#define PS_v423	((void*)startLabel+3708)
+#define PS_v419	((void*)startLabel+3720)
+#define PS_v420	((void*)startLabel+3732)
+#define PS_v425	((void*)startLabel+3744)
+#define PS_v405	((void*)startLabel+3756)
+#define PS_v400	((void*)startLabel+3768)
+#define PS_v407	((void*)startLabel+3780)
+#define PS_v409	((void*)startLabel+3792)
+#define PS_v404	((void*)startLabel+3804)
+#define PS_v398	((void*)startLabel+3816)
+#define PS_v406	((void*)startLabel+3828)
+#define PS_v402	((void*)startLabel+3840)
+#define PS_v403	((void*)startLabel+3852)
+#define PS_v408	((void*)startLabel+3864)
+#define PS_v388	((void*)startLabel+3876)
+#define PS_v385	((void*)startLabel+3888)
+#define PS_v387	((void*)startLabel+3900)
+#define PS_v469	((void*)startLabel+3912)
+#define PS_v472	((void*)startLabel+3924)
+#define PS_v390	((void*)startLabel+3936)
+extern Node FN_NHC_46Internal_46_95noMethodError[];
 extern Node FN_Prelude_46properFraction[];
 extern Node FN_Prelude_46RealFrac_46Prelude_46Real[];
 extern Node FN_Prelude_46Real_46Prelude_46Num[];
@@ -127,12 +127,12 @@ extern Node PC_Prelude_46Real_46Prelude_46Ord[];
 extern Node PC_Prelude_46Real_46Prelude_46Num[];
 extern Node PC_Prelude_46Integral_46Prelude_46Real[];
 extern Node PC_Prelude_46_62[];
-extern Node PC_Prelude_46error[];
+extern Node PC_NHC_46Internal_46_95noMethodError[];
 
 static Node startLabel[] = {
   bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v384)
+, useLabel(CT_v389)
 ,};
 Node FN_Prelude_46_95_46properFraction[] = {
   bytes2word(ZAP_ARG_I1,ZAP_ARG_I2,NEEDHEAP_I32,PUSH_ARG_I3)
@@ -143,33 +143,33 @@ Node FN_Prelude_46_95_46properFraction[] = {
 , bytes2word(10,ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
 , bytes2word(APPLY,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v383)
+, useLabel(PS_v388)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v382)
+, useLabel(PS_v387)
 , 0
 , 0
 , 0
 , 0
 , 0
-, useLabel(ST_v381)
-,	/* CT_v384: (byte 0) */
+, useLabel(ST_v386)
+,	/* CT_v389: (byte 0) */
   HW(2,3)
 , 0
 ,};
 Node F0_Prelude_46_95_46properFraction[] = {
   CAPTAG(useLabel(FN_Prelude_46_95_46properFraction),3)
-, useLabel(PS_v380)
+, useLabel(PS_v385)
 , 0
 , 0
 , 0
-, VAPTAG(useLabel(FN_LAMBDA366))
-, VAPTAG(useLabel(FN_Prelude_46error))
+, VAPTAG(useLabel(FN_LAMBDA371))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v388)
-,	/* FN_LAMBDA366: (byte 0) */
+, useLabel(CT_v393)
+,	/* FN_LAMBDA371: (byte 0) */
   bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
@@ -178,21 +178,21 @@ Node F0_Prelude_46_95_46properFraction[] = {
 , 0
 , 0
 , 0
-, useLabel(ST_v387)
+, useLabel(ST_v392)
 , 0
-, useLabel(ST_v386)
-,	/* CT_v388: (byte 0) */
+, useLabel(ST_v391)
+,	/* CT_v393: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA366: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA366))
-, useLabel(PS_v385)
+,	/* CF_LAMBDA371: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA371))
+, useLabel(PS_v390)
 , 0
 , 0
 , 0
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v405)
+, useLabel(CT_v410)
 ,};
 Node FN_Prelude_46_95_46floor[] = {
   bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
@@ -241,11 +241,11 @@ Node FN_Prelude_46_95_46floor[] = {
 , bytes2word(15,HEAP_CVAL_N1,58,HEAP_CREATE)
 , bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
 , bytes2word(ZAP_ARG_I2,ZAP_STACK_P1,3,EVAL)
-,	/* v391: (byte 4) */
+,	/* v396: (byte 4) */
   bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
 , bytes2word(PUSH_P1,0,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v404)
+, useLabel(PS_v409)
 , 0
 , 0
 , 0
@@ -256,6 +256,36 @@ Node FN_Prelude_46_95_46floor[] = {
 , 0
 , 0
 , 1
+, useLabel(PS_v408)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v407)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v406)
+, 0
+, 0
+, 0
+, 0
+, CONSTRW(0,0)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v405)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v404)
+, 0
+, 0
+, 0
+, 0
 , useLabel(PS_v403)
 , 0
 , 0
@@ -266,50 +296,20 @@ Node FN_Prelude_46_95_46floor[] = {
 , 0
 , 0
 , 0
-, useLabel(PS_v401)
-, 0
-, 0
-, 0
-, 0
-, CONSTRW(0,0)
-, 0
-, 0
-, 0
-, 0
 , useLabel(PS_v400)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v399)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v398)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v397)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v395)
-, 0
-, 0
-, 0
-, 0
 , 180005
-, useLabel(ST_v394)
-,	/* CT_v405: (byte 0) */
+, useLabel(ST_v399)
+,	/* CT_v410: (byte 0) */
   HW(9,3)
 , 0
 ,};
 Node F0_Prelude_46_95_46floor[] = {
   CAPTAG(useLabel(FN_Prelude_46_95_46floor),3)
-, useLabel(PS_v393)
+, useLabel(PS_v398)
 , 0
 , 0
 , 0
@@ -324,7 +324,7 @@ Node F0_Prelude_46_95_46floor[] = {
 , VAPTAG(useLabel(FN_Prelude_46_45))
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v422)
+, useLabel(CT_v427)
 ,};
 Node FN_Prelude_46_95_46ceiling[] = {
   bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
@@ -373,11 +373,11 @@ Node FN_Prelude_46_95_46ceiling[] = {
 , bytes2word(15,HEAP_CVAL_N1,58,HEAP_CREATE)
 , bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
 , bytes2word(ZAP_ARG_I2,ZAP_STACK_P1,3,EVAL)
-,	/* v408: (byte 4) */
+,	/* v413: (byte 4) */
   bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
 , bytes2word(PUSH_P1,0,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v421)
+, useLabel(PS_v426)
 , 0
 , 0
 , 0
@@ -388,6 +388,36 @@ Node FN_Prelude_46_95_46ceiling[] = {
 , 0
 , 0
 , 1
+, useLabel(PS_v425)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v424)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v423)
+, 0
+, 0
+, 0
+, 0
+, CONSTRW(0,0)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v422)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v421)
+, 0
+, 0
+, 0
+, 0
 , useLabel(PS_v420)
 , 0
 , 0
@@ -398,50 +428,20 @@ Node FN_Prelude_46_95_46ceiling[] = {
 , 0
 , 0
 , 0
-, useLabel(PS_v418)
-, 0
-, 0
-, 0
-, 0
-, CONSTRW(0,0)
-, 0
-, 0
-, 0
-, 0
 , useLabel(PS_v417)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v416)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v415)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v414)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v412)
-, 0
-, 0
-, 0
-, 0
 , 170005
-, useLabel(ST_v411)
-,	/* CT_v422: (byte 0) */
+, useLabel(ST_v416)
+,	/* CT_v427: (byte 0) */
   HW(9,3)
 , 0
 ,};
 Node F0_Prelude_46_95_46ceiling[] = {
   CAPTAG(useLabel(FN_Prelude_46_95_46ceiling),3)
-, useLabel(PS_v410)
+, useLabel(PS_v415)
 , 0
 , 0
 , 0
@@ -456,7 +456,7 @@ Node F0_Prelude_46_95_46ceiling[] = {
 , VAPTAG(useLabel(FN_Prelude_46_43))
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v456)
+, useLabel(CT_v461)
 ,};
 Node FN_Prelude_46_95_46round[] = {
   bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
@@ -517,15 +517,15 @@ Node FN_Prelude_46_95_46round[] = {
 , bytes2word(SLIDE_P1,2,EVAL,NEEDHEAP_P1)
 , bytes2word(43,TABLESWITCH,3,NOP)
 , bytes2word(TOP(6),BOT(6),TOP(10),BOT(10))
-,	/* v426: (byte 2) */
+,	/* v431: (byte 2) */
   bytes2word(TOP(268),BOT(268),POP_I1,PUSH_P1)
-,	/* v427: (byte 2) */
+,	/* v432: (byte 2) */
   bytes2word(0,RETURN_EVAL,POP_I1,PUSH_HEAP)
 , bytes2word(HEAP_CVAL_P1,21,HEAP_CVAL_N1,89)
 , bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
 , bytes2word(2,HEAP_I1,EVAL,NEEDHEAP_P1)
 , bytes2word(43,JUMPFALSE,5,0)
-,	/* v428: (byte 3) */
+,	/* v433: (byte 3) */
   bytes2word(PUSH_P1,0,RETURN_EVAL,HEAP_CVAL_P1)
 , bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
 , bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
@@ -566,7 +566,7 @@ Node FN_Prelude_46_95_46round[] = {
 , bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
 , bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
 , bytes2word(11,ZAP_STACK_P1,3,EVAL)
-,	/* v430: (byte 4) */
+,	/* v435: (byte 4) */
   bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
 , bytes2word(HEAP_CVAL_P1,23,HEAP_CVAL_N1,99)
 , bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
@@ -586,7 +586,7 @@ Node FN_Prelude_46_95_46round[] = {
 , bytes2word(11,PUSH_HEAP,HEAP_CVAL_P1,24)
 , bytes2word(HEAP_CVAL_N1,104,HEAP_CREATE,HEAP_SPACE)
 , bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,EVAL)
-,	/* v432: (byte 4) */
+,	/* v437: (byte 4) */
   bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
 , bytes2word(POP_I1,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
 , bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
@@ -629,7 +629,7 @@ Node FN_Prelude_46_95_46round[] = {
 , bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
 , bytes2word(HEAP_OFF_N1,11,ZAP_STACK_P1,3)
 , bytes2word(EVAL,NEEDHEAP_I32,APPLY,2)
-,	/* v433: (byte 1) */
+,	/* v438: (byte 1) */
   bytes2word(RETURN_EVAL,HEAP_CVAL_P1,23,HEAP_CVAL_N1)
 , bytes2word(99,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
 , bytes2word(HEAP_ARG,2,HEAP_CVAL_P1,9)
@@ -652,6 +652,26 @@ Node FN_Prelude_46_95_46round[] = {
 , bytes2word(3,EVAL,NEEDHEAP_I32,APPLY)
 , bytes2word(2,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
+, useLabel(PS_v460)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v459)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v458)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v457)
+, 0
+, 0
+, 0
+, 0
 , useLabel(PS_v455)
 , 0
 , 0
@@ -662,6 +682,11 @@ Node FN_Prelude_46_95_46round[] = {
 , 0
 , 0
 , 0
+, CONSTRW(0,0)
+, 0
+, 0
+, 0
+, 0
 , useLabel(PS_v453)
 , 0
 , 0
@@ -672,31 +697,6 @@ Node FN_Prelude_46_95_46round[] = {
 , 0
 , 0
 , 0
-, useLabel(PS_v450)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v449)
-, 0
-, 0
-, 0
-, 0
-, CONSTRW(0,0)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v448)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v447)
-, 0
-, 0
-, 0
-, 0
 , CONSTRW(1,0)
 , 0
 , 0
@@ -709,6 +709,31 @@ Node FN_Prelude_46_95_46round[] = {
 , 0
 , 0
 , 1
+, useLabel(PS_v451)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v450)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v449)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v448)
+, 0
+, 0
+, 0
+, 0
+, useLabel(PS_v447)
+, 0
+, 0
+, 0
+, 0
 , useLabel(PS_v446)
 , 0
 , 0
@@ -724,45 +749,20 @@ Node FN_Prelude_46_95_46round[] = {
 , 0
 , 0
 , 0
-, useLabel(PS_v443)
-, 0
-, 0
-, 0
-, 0
 , useLabel(PS_v442)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v441)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v440)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v439)
-, 0
-, 0
-, 0
-, 0
-, useLabel(PS_v437)
-, 0
-, 0
-, 0
-, 0
 , 110005
-, useLabel(ST_v436)
-,	/* CT_v456: (byte 0) */
+, useLabel(ST_v441)
+,	/* CT_v461: (byte 0) */
   HW(18,3)
 , 0
 ,};
 Node F0_Prelude_46_95_46round[] = {
   CAPTAG(useLabel(FN_Prelude_46_95_46round),3)
-, useLabel(PS_v435)
+, useLabel(PS_v440)
 , 0
 , 0
 , 0
@@ -786,7 +786,7 @@ Node F0_Prelude_46_95_46round[] = {
 , VAPTAG(useLabel(FN_Prelude_46_43))
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v463)
+, useLabel(CT_v468)
 ,};
 Node FN_Prelude_46_95_46truncate[] = {
   bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
@@ -798,158 +798,158 @@ Node FN_Prelude_46_95_46truncate[] = {
 , bytes2word(0,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v461)
+, useLabel(PS_v466)
 , 0
 , 0
 , 0
 , 0
 , 100005
-, useLabel(ST_v460)
-,	/* CT_v463: (byte 0) */
+, useLabel(ST_v465)
+,	/* CT_v468: (byte 0) */
   HW(1,3)
 , 0
 ,};
 Node F0_Prelude_46_95_46truncate[] = {
   CAPTAG(useLabel(FN_Prelude_46_95_46truncate),3)
-, useLabel(PS_v459)
+, useLabel(PS_v464)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46properFraction))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v466)
+, useLabel(CT_v471)
 ,};
 Node FN_Prelude_46RealFrac_46Prelude_46Real[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v465)
-,	/* CT_v466: (byte 0) */
+, useLabel(ST_v470)
+,	/* CT_v471: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFrac_46Prelude_46Real[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Real),1)
-, useLabel(PS_v464)
+, useLabel(PS_v469)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v469)
+, useLabel(CT_v474)
 ,};
 Node FN_Prelude_46RealFrac_46Prelude_46Fractional[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v468)
-,	/* CT_v469: (byte 0) */
+, useLabel(ST_v473)
+,	/* CT_v474: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFrac_46Prelude_46Fractional[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Fractional),1)
-, useLabel(PS_v467)
+, useLabel(PS_v472)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v472)
+, useLabel(CT_v477)
 ,};
 Node FN_Prelude_46round[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v471)
-,	/* CT_v472: (byte 0) */
+, useLabel(ST_v476)
+,	/* CT_v477: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46round[] = {
   CAPTAG(useLabel(FN_Prelude_46round),1)
-, useLabel(PS_v470)
+, useLabel(PS_v475)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v475)
+, useLabel(CT_v480)
 ,};
 Node FN_Prelude_46truncate[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,4)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v474)
-,	/* CT_v475: (byte 0) */
+, useLabel(ST_v479)
+,	/* CT_v480: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46truncate[] = {
   CAPTAG(useLabel(FN_Prelude_46truncate),1)
-, useLabel(PS_v473)
+, useLabel(PS_v478)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v478)
+, useLabel(CT_v483)
 ,};
 Node FN_Prelude_46ceiling[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,5)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v477)
-,	/* CT_v478: (byte 0) */
+, useLabel(ST_v482)
+,	/* CT_v483: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46ceiling[] = {
   CAPTAG(useLabel(FN_Prelude_46ceiling),1)
-, useLabel(PS_v476)
+, useLabel(PS_v481)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v481)
+, useLabel(CT_v486)
 ,};
 Node FN_Prelude_46properFraction[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,6)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v480)
-,	/* CT_v481: (byte 0) */
+, useLabel(ST_v485)
+,	/* CT_v486: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46properFraction[] = {
   CAPTAG(useLabel(FN_Prelude_46properFraction),1)
-, useLabel(PS_v479)
+, useLabel(PS_v484)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v484)
+, useLabel(CT_v489)
 ,};
 Node FN_Prelude_46floor[] = {
   bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,7)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 50034
-, useLabel(ST_v483)
-,	/* CT_v484: (byte 0) */
+, useLabel(ST_v488)
+,	/* CT_v489: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46floor[] = {
   CAPTAG(useLabel(FN_Prelude_46floor),1)
-, useLabel(PS_v482)
+, useLabel(PS_v487)
 , 0
 , 0
 , 0
-,	/* ST_v387: (byte 0) */
+,	/* ST_v392: (byte 0) */
   bytes2word(78,111,32,100)
 , bytes2word(101,102,97,117)
 , bytes2word(108,116,32,100)
@@ -968,7 +968,7 @@ Node F0_Prelude_46floor[] = {
 Node PP_Prelude_46RealFrac_46Prelude_46Fractional[] = {
  };
 Node PC_Prelude_46RealFrac_46Prelude_46Fractional[] = {
- 	/* ST_v468: (byte 0) */
+ 	/* ST_v473: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -982,7 +982,7 @@ Node PC_Prelude_46RealFrac_46Prelude_46Fractional[] = {
 Node PP_Prelude_46RealFrac_46Prelude_46Real[] = {
  };
 Node PC_Prelude_46RealFrac_46Prelude_46Real[] = {
- 	/* ST_v465: (byte 0) */
+ 	/* ST_v470: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -995,7 +995,7 @@ Node PC_Prelude_46RealFrac_46Prelude_46Real[] = {
 Node PP_Prelude_46_95_46ceiling[] = {
  };
 Node PC_Prelude_46_95_46ceiling[] = {
- 	/* ST_v411: (byte 0) */
+ 	/* ST_v416: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(95,46,99,101)
@@ -1005,7 +1005,7 @@ Node PC_Prelude_46_95_46ceiling[] = {
 Node PP_Prelude_46_95_46floor[] = {
  };
 Node PC_Prelude_46_95_46floor[] = {
- 	/* ST_v394: (byte 0) */
+ 	/* ST_v399: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(95,46,102,108)
@@ -1014,16 +1014,16 @@ Node PC_Prelude_46_95_46floor[] = {
 Node PP_Prelude_46_95_46properFraction[] = {
  };
 Node PC_Prelude_46_95_46properFraction[] = {
- 	/* ST_v381: (byte 0) */
+ 	/* ST_v386: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(95,46,112,114)
 , bytes2word(111,112,101,114)
 , bytes2word(70,114,97,99)
 , bytes2word(116,105,111,110)
-,	/* PP_LAMBDA366: (byte 1) */
- 	/* PC_LAMBDA366: (byte 1) */
- 	/* ST_v386: (byte 1) */
+,	/* PP_LAMBDA371: (byte 1) */
+ 	/* PC_LAMBDA371: (byte 1) */
+ 	/* ST_v391: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,95,46,112)
@@ -1036,7 +1036,7 @@ Node PC_Prelude_46_95_46properFraction[] = {
 Node PP_Prelude_46_95_46round[] = {
  };
 Node PC_Prelude_46_95_46round[] = {
- 	/* ST_v436: (byte 0) */
+ 	/* ST_v441: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(95,46,114,111)
@@ -1045,7 +1045,7 @@ Node PC_Prelude_46_95_46round[] = {
 Node PP_Prelude_46_95_46truncate[] = {
  };
 Node PC_Prelude_46_95_46truncate[] = {
- 	/* ST_v460: (byte 0) */
+ 	/* ST_v465: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(95,46,116,114)
@@ -1055,7 +1055,7 @@ Node PC_Prelude_46_95_46truncate[] = {
 Node PP_Prelude_46ceiling[] = {
  };
 Node PC_Prelude_46ceiling[] = {
- 	/* ST_v477: (byte 0) */
+ 	/* ST_v482: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(99,101,105,108)
@@ -1064,7 +1064,7 @@ Node PC_Prelude_46ceiling[] = {
 Node PP_Prelude_46floor[] = {
  };
 Node PC_Prelude_46floor[] = {
- 	/* ST_v483: (byte 0) */
+ 	/* ST_v488: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(102,108,111,111)
@@ -1073,7 +1073,7 @@ Node PC_Prelude_46floor[] = {
 Node PP_Prelude_46properFraction[] = {
  };
 Node PC_Prelude_46properFraction[] = {
- 	/* ST_v480: (byte 0) */
+ 	/* ST_v485: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(112,114,111,112)
@@ -1084,7 +1084,7 @@ Node PC_Prelude_46properFraction[] = {
 Node PP_Prelude_46round[] = {
  };
 Node PC_Prelude_46round[] = {
- 	/* ST_v471: (byte 0) */
+ 	/* ST_v476: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(114,111,117,110)
@@ -1093,214 +1093,214 @@ Node PC_Prelude_46round[] = {
 Node PP_Prelude_46truncate[] = {
  };
 Node PC_Prelude_46truncate[] = {
- 	/* ST_v474: (byte 0) */
+ 	/* ST_v479: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(116,114,117,110)
 , bytes2word(99,97,116,101)
 , bytes2word(0,0,0,0)
-,	/* PS_v473: (byte 0) */
+,	/* PS_v478: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46truncate)
 , useLabel(PC_Prelude_46truncate)
-,	/* PS_v470: (byte 0) */
+,	/* PS_v475: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46round)
 , useLabel(PC_Prelude_46round)
-,	/* PS_v476: (byte 0) */
+,	/* PS_v481: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46ceiling)
 , useLabel(PC_Prelude_46ceiling)
-,	/* PS_v482: (byte 0) */
+,	/* PS_v487: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46floor)
 , useLabel(PC_Prelude_46floor)
-,	/* PS_v479: (byte 0) */
+,	/* PS_v484: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46properFraction)
 , useLabel(PC_Prelude_46properFraction)
-,	/* PS_v461: (byte 0) */
+,	/* PS_v466: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46truncate)
 , useLabel(PC_Prelude_46properFraction)
-,	/* PS_v459: (byte 0) */
+,	/* PS_v464: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46truncate)
 , useLabel(PC_Prelude_46_95_46truncate)
-,	/* PS_v446: (byte 0) */
+,	/* PS_v451: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46round)
 , useLabel(PC_Ratio_46_37)
-,	/* PS_v447: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_NHC_46Internal_46_95apply2)
-,	/* PS_v443: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_NHC_46Internal_46_95apply1)
 ,	/* PS_v452: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46even)
-,	/* PS_v437: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46properFraction)
-,	/* PS_v445: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46fromRational)
-,	/* PS_v450: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46compare)
-,	/* PS_v453: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46_60)
-,	/* PS_v441: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46_45)
-,	/* PS_v455: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46_43)
-,	/* PS_v442: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46abs)
+, useLabel(PC_NHC_46Internal_46_95apply2)
 ,	/* PS_v448: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_NHC_46Internal_46_95apply1)
+,	/* PS_v457: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46even)
+,	/* PS_v442: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46properFraction)
+,	/* PS_v450: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46fromRational)
+,	/* PS_v455: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46compare)
+,	/* PS_v458: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46_60)
+,	/* PS_v446: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46_45)
+,	/* PS_v460: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46_43)
+,	/* PS_v447: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46abs)
+,	/* PS_v453: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
 , useLabel(PC_Prelude_46fromInteger)
-,	/* PS_v435: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46_95_46round)
-,	/* PS_v449: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
-,	/* PS_v439: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
 ,	/* PS_v440: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46Real_46Prelude_46Num)
+, useLabel(PC_Prelude_46_95_46round)
 ,	/* PS_v454: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46round)
-, useLabel(PC_Prelude_46Integral_46Prelude_46Real)
+, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
 ,	/* PS_v444: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
+,	/* PS_v445: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46Real_46Prelude_46Num)
+,	/* PS_v459: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
+, useLabel(PC_Prelude_46Integral_46Prelude_46Real)
+,	/* PS_v449: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46round)
 , useLabel(PC_Prelude_46RealFrac_46Prelude_46Fractional)
+,	/* PS_v422: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46ceiling)
+, useLabel(PC_NHC_46Internal_46_95apply1)
 ,	/* PS_v417: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46ceiling)
-, useLabel(PC_NHC_46Internal_46_95apply1)
-,	/* PS_v412: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46ceiling)
 , useLabel(PC_Prelude_46properFraction)
-,	/* PS_v419: (byte 0) */
+,	/* PS_v424: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46ceiling)
 , useLabel(PC_Prelude_46_62)
-,	/* PS_v421: (byte 0) */
+,	/* PS_v426: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46ceiling)
 , useLabel(PC_Prelude_46_43)
-,	/* PS_v416: (byte 0) */
+,	/* PS_v421: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46ceiling)
 , useLabel(PC_Prelude_46fromInteger)
-,	/* PS_v410: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46ceiling)
-, useLabel(PC_Prelude_46_95_46ceiling)
-,	/* PS_v418: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46ceiling)
-, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
-,	/* PS_v414: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46ceiling)
-, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
 ,	/* PS_v415: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46ceiling)
-, useLabel(PC_Prelude_46Real_46Prelude_46Num)
+, useLabel(PC_Prelude_46_95_46ceiling)
+,	/* PS_v423: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46ceiling)
+, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
+,	/* PS_v419: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46ceiling)
+, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
 ,	/* PS_v420: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46ceiling)
+, useLabel(PC_Prelude_46Real_46Prelude_46Num)
+,	/* PS_v425: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46ceiling)
 , useLabel(PC_Prelude_46Integral_46Prelude_46Real)
-,	/* PS_v400: (byte 0) */
+,	/* PS_v405: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
 , useLabel(PC_NHC_46Internal_46_95apply1)
-,	/* PS_v395: (byte 0) */
+,	/* PS_v400: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
 , useLabel(PC_Prelude_46properFraction)
-,	/* PS_v402: (byte 0) */
+,	/* PS_v407: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
 , useLabel(PC_Prelude_46_60)
-,	/* PS_v404: (byte 0) */
+,	/* PS_v409: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
 , useLabel(PC_Prelude_46_45)
-,	/* PS_v399: (byte 0) */
+,	/* PS_v404: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
 , useLabel(PC_Prelude_46fromInteger)
-,	/* PS_v393: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46floor)
-, useLabel(PC_Prelude_46_95_46floor)
-,	/* PS_v401: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46floor)
-, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
-,	/* PS_v397: (byte 0) */
-  useLabel(PM_Prelude)
-, useLabel(PP_Prelude_46_95_46floor)
-, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
 ,	/* PS_v398: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
-, useLabel(PC_Prelude_46Real_46Prelude_46Num)
+, useLabel(PC_Prelude_46_95_46floor)
+,	/* PS_v406: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46floor)
+, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
+,	/* PS_v402: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46floor)
+, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
 ,	/* PS_v403: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46floor)
+, useLabel(PC_Prelude_46Real_46Prelude_46Num)
+,	/* PS_v408: (byte 0) */
+  useLabel(PM_Prelude)
+, useLabel(PP_Prelude_46_95_46floor)
 , useLabel(PC_Prelude_46Integral_46Prelude_46Real)
-,	/* PS_v383: (byte 0) */
+,	/* PS_v388: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46properFraction)
-, useLabel(PC_Prelude_46error)
-,	/* PS_v380: (byte 0) */
+, useLabel(PC_NHC_46Internal_46_95noMethodError)
+,	/* PS_v385: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46properFraction)
 , useLabel(PC_Prelude_46_95_46properFraction)
-,	/* PS_v382: (byte 0) */
+,	/* PS_v387: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46_95_46properFraction)
-, useLabel(PC_LAMBDA366)
-,	/* PS_v464: (byte 0) */
+, useLabel(PC_LAMBDA371)
+,	/* PS_v469: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFrac_46Prelude_46Real)
 , useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
-,	/* PS_v467: (byte 0) */
+,	/* PS_v472: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46RealFrac_46Prelude_46Fractional)
 , useLabel(PC_Prelude_46RealFrac_46Prelude_46Fractional)
-,	/* PS_v385: (byte 0) */
+,	/* PS_v390: (byte 0) */
   useLabel(PM_Prelude)
-, useLabel(PP_LAMBDA366)
-, useLabel(PC_LAMBDA366)
+, useLabel(PP_LAMBDA371)
+, useLabel(PC_LAMBDA371)
 ,};
