@@ -1,40 +1,40 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define v377	((void*)startLabel+60)
-#define v379	((void*)startLabel+87)
-#define v381	((void*)startLabel+122)
-#define v383	((void*)startLabel+155)
-#define CT_v386	((void*)startLabel+208)
-#define FN_LAMBDA374	((void*)startLabel+284)
-#define CT_v389	((void*)startLabel+316)
-#define CF_LAMBDA374	((void*)startLabel+324)
-#define CT_v391	((void*)startLabel+376)
-#define v392	((void*)startLabel+445)
-#define v394	((void*)startLabel+478)
-#define CT_v397	((void*)startLabel+532)
-#define FN_LAMBDA375	((void*)startLabel+592)
-#define CT_v400	((void*)startLabel+624)
-#define CF_LAMBDA375	((void*)startLabel+632)
-#define CT_v402	((void*)startLabel+692)
-#define CT_v404	((void*)startLabel+760)
-#define CT_v406	((void*)startLabel+828)
-#define CT_v408	((void*)startLabel+904)
-#define CT_v410	((void*)startLabel+968)
-#define CT_v412	((void*)startLabel+1032)
-#define ST_v411	((void*)startLabel+1076)
-#define ST_v401	((void*)startLabel+1104)
-#define ST_v390	((void*)startLabel+1141)
-#define ST_v385	((void*)startLabel+1182)
-#define ST_v387	((void*)startLabel+1225)
-#define ST_v396	((void*)startLabel+1279)
-#define ST_v398	((void*)startLabel+1318)
-#define ST_v403	((void*)startLabel+1368)
-#define ST_v407	((void*)startLabel+1405)
-#define ST_v409	((void*)startLabel+1438)
-#define ST_v405	((void*)startLabel+1471)
-#define ST_v399	((void*)startLabel+1506)
-#define ST_v388	((void*)startLabel+1581)
+#define v382	((void*)startLabel+60)
+#define v384	((void*)startLabel+87)
+#define v386	((void*)startLabel+122)
+#define v388	((void*)startLabel+155)
+#define CT_v391	((void*)startLabel+208)
+#define FN_LAMBDA379	((void*)startLabel+284)
+#define CT_v394	((void*)startLabel+316)
+#define CF_LAMBDA379	((void*)startLabel+324)
+#define CT_v396	((void*)startLabel+376)
+#define v397	((void*)startLabel+445)
+#define v399	((void*)startLabel+478)
+#define CT_v402	((void*)startLabel+532)
+#define FN_LAMBDA380	((void*)startLabel+592)
+#define CT_v405	((void*)startLabel+624)
+#define CF_LAMBDA380	((void*)startLabel+632)
+#define CT_v407	((void*)startLabel+692)
+#define CT_v409	((void*)startLabel+760)
+#define CT_v411	((void*)startLabel+828)
+#define CT_v413	((void*)startLabel+904)
+#define CT_v415	((void*)startLabel+968)
+#define CT_v417	((void*)startLabel+1032)
+#define ST_v416	((void*)startLabel+1076)
+#define ST_v406	((void*)startLabel+1104)
+#define ST_v395	((void*)startLabel+1141)
+#define ST_v390	((void*)startLabel+1182)
+#define ST_v392	((void*)startLabel+1225)
+#define ST_v401	((void*)startLabel+1279)
+#define ST_v403	((void*)startLabel+1318)
+#define ST_v408	((void*)startLabel+1368)
+#define ST_v412	((void*)startLabel+1405)
+#define ST_v414	((void*)startLabel+1438)
+#define ST_v410	((void*)startLabel+1471)
+#define ST_v404	((void*)startLabel+1506)
+#define ST_v393	((void*)startLabel+1581)
 extern Node TM_Prelude[];
 extern Node FN_Prelude_46Num_46Prelude_46Double_46_45[];
 extern Node FN_Prelude_46Fractional_46Prelude_46Double_46_47[];
@@ -48,7 +48,7 @@ extern Node F0_Prelude_46Num_46Prelude_46Double_46_43[];
 extern Node FN_Prelude_46iterate[];
 extern Node FN_Prelude_46takeWhile[];
 extern Node F0_Prelude_46Ord_46Prelude_46Double_46_62[];
-extern Node FN_Prelude_46error[];
+extern Node FN_NHC_46Internal_46_95patternMatchFail[];
 extern Node TMSUB_Prelude[];
 extern Node CF_Prelude_46otherwise[];
 extern Node FN_Prelude_46RealFrac_46Prelude_46Double_46truncate[];
@@ -62,7 +62,7 @@ extern Node CF_Prelude_46Num_46Prelude_46Double[];
 static Node startLabel[] = {
   bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v386)
+, useLabel(CT_v391)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
   useLabel(TM_Prelude)
@@ -76,7 +76,7 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
 , bytes2word(HEAP_CVAL_P1,8,HEAP_OFF_N1,7)
 , bytes2word(HEAP_OFF_N1,5,ZAP_ARG_I2,EVAL)
 , bytes2word(NEEDHEAP_I32,JUMPFALSE,6,0)
-,	/* v377: (byte 4) */
+,	/* v382: (byte 4) */
   bytes2word(PUSH_HEAP,HEAP_CVAL_N1,10,RETURN)
 , bytes2word(HEAP_CVAL_P1,7,HEAP_I1,HEAP_CADR_N1)
 , bytes2word(9,HEAP_CVAL_P1,6,HEAP_ARG_ARG)
@@ -84,7 +84,7 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
 , bytes2word(8,HEAP_OFF_N1,7,HEAP_OFF_N1)
 , bytes2word(5,ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
 , bytes2word(JUMPFALSE,6,0,PUSH_HEAP)
-,	/* v379: (byte 3) */
+,	/* v384: (byte 3) */
   bytes2word(HEAP_CVAL_N1,10,RETURN,PUSH_CADR_N1)
 , bytes2word(9,PUSH_P1,2,EVAL)
 , bytes2word(NEEDHEAP_I32,GE_D,JUMPFALSE,27)
@@ -94,7 +94,7 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
 , bytes2word(HEAP_CVAL_P1,12,HEAP_OFF_N1,4)
 , bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
 , bytes2word(13,HEAP_OFF_N1,10,HEAP_OFF_N1)
-,	/* v381: (byte 2) */
+,	/* v386: (byte 2) */
   bytes2word(5,RETURN_EVAL,PUSH_CADR_N1,9)
 , bytes2word(PUSH_P1,2,LT_D,JUMPFALSE)
 , bytes2word(27,0,HEAP_CVAL_P1,9)
@@ -103,7 +103,7 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
 , bytes2word(HEAP_I1,HEAP_CVAL_P1,12,HEAP_OFF_N1)
 , bytes2word(4,HEAP_ARG,1,PUSH_HEAP)
 , bytes2word(HEAP_CVAL_P1,13,HEAP_OFF_N1,10)
-,	/* v383: (byte 3) */
+,	/* v388: (byte 3) */
   bytes2word(HEAP_OFF_N1,5,RETURN_EVAL,HEAP_CVAL_P1)
 , bytes2word(15,PUSH_HEAP,HEAP_CVAL_P1,16)
 , bytes2word(HEAP_OFF_N1,2,RETURN_EVAL,ENDCODE)
@@ -114,11 +114,11 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
 , 0
 , 0
 , CONSTRW(2,0)
-, 0
 , 1073741824
+, 0
 , 170003
-, useLabel(ST_v385)
-,	/* CT_v386: (byte 0) */
+, useLabel(ST_v390)
+,	/* CT_v391: (byte 0) */
   HW(14,3)
 , 0
 ,};
@@ -136,27 +136,27 @@ Node F0_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo[] = {
 , VAPTAG(useLabel(FN_Prelude_46iterate))
 , VAPTAG(useLabel(FN_Prelude_46takeWhile))
 , useLabel(F0_Prelude_46Ord_46Prelude_46Double_46_62)
-, VAPTAG(useLabel(FN_LAMBDA374))
-, VAPTAG(useLabel(FN_Prelude_46error))
+, VAPTAG(useLabel(FN_LAMBDA379))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v389)
-,	/* FN_LAMBDA374: (byte 0) */
+, useLabel(CT_v394)
+,	/* FN_LAMBDA379: (byte 0) */
   useLabel(TMSUB_Prelude)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v388)
+, useLabel(ST_v393)
 , 170003
-, useLabel(ST_v387)
-,	/* CT_v389: (byte 0) */
+, useLabel(ST_v392)
+,	/* CT_v394: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA374: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA374))
+,	/* CF_LAMBDA379: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA379))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v391)
+, useLabel(CT_v396)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThen[] = {
   useLabel(TM_Prelude)
@@ -167,8 +167,8 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromThen[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 150003
-, useLabel(ST_v390)
-,	/* CT_v391: (byte 0) */
+, useLabel(ST_v395)
+,	/* CT_v396: (byte 0) */
   HW(4,2)
 , 0
 ,};
@@ -180,7 +180,7 @@ Node F0_Prelude_46Enum_46Prelude_46Double_46enumFromThen[] = {
 , VAPTAG(useLabel(FN_Prelude_46iterate))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v397)
+, useLabel(CT_v402)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromTo[] = {
   useLabel(TM_Prelude)
@@ -190,7 +190,7 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromTo[] = {
 , bytes2word(PUSH_ARG_I1,EVAL,PUSH_ZAP_ARG_I2,EVAL)
 , bytes2word(NEEDHEAP_I32,LT_D,JUMPFALSE,6)
 , bytes2word(0,PUSH_HEAP,HEAP_CVAL_N1,10)
-,	/* v392: (byte 1) */
+,	/* v397: (byte 1) */
   bytes2word(RETURN,PUSH_CVAL_P1,5,EVAL)
 , bytes2word(NEEDHEAP_I32,JUMPFALSE,28,0)
 , bytes2word(HEAP_CVAL_P1,6,HEAP_CVAL_P1,7)
@@ -199,22 +199,22 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFromTo[] = {
 , bytes2word(HEAP_CVAL_P1,9,HEAP_OFF_N1,4)
 , bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
 , bytes2word(10,HEAP_OFF_N1,10,HEAP_OFF_N1)
-,	/* v394: (byte 2) */
+,	/* v399: (byte 2) */
   bytes2word(5,RETURN_EVAL,HEAP_CVAL_P1,11)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_P1,12,HEAP_OFF_N1)
 , bytes2word(2,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , CONSTR(0,0,0)
 , CONSTRW(2,0)
-, 0
 , 1073741824
 , 0
-, CONSTRW(2,0)
 , 0
+, CONSTRW(2,0)
 , 1072693248
+, 0
 , 110003
-, useLabel(ST_v396)
-,	/* CT_v397: (byte 0) */
+, useLabel(ST_v401)
+,	/* CT_v402: (byte 0) */
   HW(10,2)
 , 0
 ,};
@@ -228,26 +228,26 @@ Node F0_Prelude_46Enum_46Prelude_46Double_46enumFromTo[] = {
 , useLabel(F0_Prelude_46Num_46Prelude_46Double_46_43)
 , VAPTAG(useLabel(FN_Prelude_46iterate))
 , VAPTAG(useLabel(FN_Prelude_46takeWhile))
-, VAPTAG(useLabel(FN_LAMBDA375))
-, VAPTAG(useLabel(FN_Prelude_46error))
+, VAPTAG(useLabel(FN_LAMBDA380))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v400)
-,	/* FN_LAMBDA375: (byte 0) */
+, useLabel(CT_v405)
+,	/* FN_LAMBDA380: (byte 0) */
   useLabel(TMSUB_Prelude)
 , bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , CONSTRW(1,0)
-, useLabel(ST_v399)
+, useLabel(ST_v404)
 , 110003
-, useLabel(ST_v398)
-,	/* CT_v400: (byte 0) */
+, useLabel(ST_v403)
+,	/* CT_v405: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA375: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA375))
+,	/* CF_LAMBDA380: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA380))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v402)
+, useLabel(CT_v407)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46enumFrom[] = {
   useLabel(TM_Prelude)
@@ -258,11 +258,11 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46enumFrom[] = {
 , bytes2word(0,0,0,0)
 , 0
 , CONSTRW(2,0)
-, 0
 , 1072693248
+, 0
 , 100003
-, useLabel(ST_v401)
-,	/* CT_v402: (byte 0) */
+, useLabel(ST_v406)
+,	/* CT_v407: (byte 0) */
   HW(3,1)
 , 0
 ,};
@@ -272,7 +272,7 @@ Node F0_Prelude_46Enum_46Prelude_46Double_46enumFrom[] = {
 , useLabel(F0_Prelude_46Num_46Prelude_46Double_46_43)
 , VAPTAG(useLabel(FN_Prelude_46iterate))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v404)
+, useLabel(CT_v409)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46fromEnum[] = {
   useLabel(TM_Prelude)
@@ -283,8 +283,8 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46fromEnum[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 80003
-, useLabel(ST_v403)
-,	/* CT_v404: (byte 0) */
+, useLabel(ST_v408)
+,	/* CT_v409: (byte 0) */
   HW(4,1)
 , 0
 ,};
@@ -295,7 +295,7 @@ Node F0_Prelude_46Enum_46Prelude_46Double_46fromEnum[] = {
 , VAPTAG(useLabel(FN_Prelude_46_46))
 , useLabel(F0_Prelude_46Num_46Prelude_46Int_46fromInteger)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v406)
+, useLabel(CT_v411)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46toEnum[] = {
   useLabel(TM_Prelude)
@@ -305,8 +305,8 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46toEnum[] = {
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 70003
-, useLabel(ST_v405)
-,	/* CT_v406: (byte 0) */
+, useLabel(ST_v410)
+,	/* CT_v411: (byte 0) */
   HW(3,1)
 , 0
 ,};
@@ -316,7 +316,7 @@ Node F0_Prelude_46Enum_46Prelude_46Double_46toEnum[] = {
 , useLabel(CF_Prelude_46Integral_46Prelude_46Int)
 , useLabel(CF_Prelude_46Num_46Prelude_46Double)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v408)
+, useLabel(CT_v413)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46pred[] = {
   useLabel(TM_Prelude)
@@ -326,18 +326,18 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46pred[] = {
 , bytes2word(0,0,0,0)
 , 0
 , CONSTRW(2,0)
-, 0
 , 1072693248
+, 0
 , 50003
-, useLabel(ST_v407)
-,	/* CT_v408: (byte 0) */
+, useLabel(ST_v412)
+,	/* CT_v413: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Double_46pred[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Double_46pred),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v410)
+, useLabel(CT_v415)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double_46succ[] = {
   useLabel(TM_Prelude)
@@ -347,18 +347,18 @@ Node FN_Prelude_46Enum_46Prelude_46Double_46succ[] = {
 , bytes2word(0,0,0,0)
 , 0
 , CONSTRW(2,0)
-, 0
 , 1072693248
+, 0
 , 40003
-, useLabel(ST_v409)
-,	/* CT_v410: (byte 0) */
+, useLabel(ST_v414)
+,	/* CT_v415: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Double_46succ[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Double_46succ),1)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v412)
+, useLabel(CT_v417)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Double[] = {
   useLabel(TM_Prelude)
@@ -371,8 +371,8 @@ Node FN_Prelude_46Enum_46Prelude_46Double[] = {
 , 0
 , CONSTR(0,8,0)
 , 30010
-, useLabel(ST_v411)
-,	/* CT_v412: (byte 0) */
+, useLabel(ST_v416)
+,	/* CT_v417: (byte 0) */
   HW(8,0)
 , 0
 ,};
@@ -386,14 +386,14 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , useLabel(F0_Prelude_46Enum_46Prelude_46Double_46enumFromThen)
 , useLabel(F0_Prelude_46Enum_46Prelude_46Double_46enumFromTo)
 , useLabel(F0_Prelude_46Enum_46Prelude_46Double_46enumFromThenTo)
-,	/* ST_v411: (byte 0) */
+,	/* ST_v416: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
 , bytes2word(46,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,68,111,117)
-,	/* ST_v401: (byte 4) */
+,	/* ST_v406: (byte 4) */
   bytes2word(98,108,101,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -404,7 +404,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(98,108,101,46)
 , bytes2word(101,110,117,109)
 , bytes2word(70,114,111,109)
-,	/* ST_v390: (byte 1) */
+,	/* ST_v395: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
@@ -415,7 +415,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(46,101,110,117)
 , bytes2word(109,70,114,111)
 , bytes2word(109,84,104,101)
-,	/* ST_v385: (byte 2) */
+,	/* ST_v390: (byte 2) */
   bytes2word(110,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,110)
@@ -427,7 +427,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(117,109,70,114)
 , bytes2word(111,109,84,104)
 , bytes2word(101,110,84,111)
-,	/* ST_v387: (byte 1) */
+,	/* ST_v392: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
@@ -441,7 +441,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(110,84,111,58)
 , bytes2word(49,55,58,51)
 , bytes2word(45,50,51,58)
-,	/* ST_v396: (byte 3) */
+,	/* ST_v401: (byte 3) */
   bytes2word(51,50,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,69)
@@ -452,7 +452,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(108,101,46,101)
 , bytes2word(110,117,109,70)
 , bytes2word(114,111,109,84)
-,	/* ST_v398: (byte 2) */
+,	/* ST_v403: (byte 2) */
   bytes2word(111,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,110)
@@ -465,7 +465,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(111,109,84,111)
 , bytes2word(58,49,49,58)
 , bytes2word(51,45,49,52)
-,	/* ST_v403: (byte 4) */
+,	/* ST_v408: (byte 4) */
   bytes2word(58,50,53,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -476,7 +476,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(98,108,101,46)
 , bytes2word(102,114,111,109)
 , bytes2word(69,110,117,109)
-,	/* ST_v407: (byte 1) */
+,	/* ST_v412: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
@@ -485,7 +485,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(101,46,68,111)
 , bytes2word(117,98,108,101)
 , bytes2word(46,112,114,101)
-,	/* ST_v409: (byte 2) */
+,	/* ST_v414: (byte 2) */
   bytes2word(100,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,69,110)
@@ -494,7 +494,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(100,101,46,68)
 , bytes2word(111,117,98,108)
 , bytes2word(101,46,115,117)
-,	/* ST_v405: (byte 3) */
+,	/* ST_v410: (byte 3) */
   bytes2word(99,99,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,69)
@@ -504,7 +504,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(68,111,117,98)
 , bytes2word(108,101,46,116)
 , bytes2word(111,69,110,117)
-,	/* ST_v399: (byte 2) */
+,	/* ST_v404: (byte 2) */
   bytes2word(109,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,58,46,47)
@@ -524,7 +524,7 @@ Node CF_Prelude_46Enum_46Prelude_46Double[] = {
 , bytes2word(32,49,49,58)
 , bytes2word(51,45,49,52)
 , bytes2word(58,50,53,46)
-,	/* ST_v388: (byte 1) */
+,	/* ST_v393: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(58,46,47,69)
