@@ -1,71 +1,71 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v257	((void*)startLabel+64)
-#define CT_v261	((void*)startLabel+156)
-#define v270	((void*)startLabel+216)
-#define v265	((void*)startLabel+220)
-#define v266	((void*)startLabel+230)
-#define v267	((void*)startLabel+240)
-#define v262	((void*)startLabel+250)
-#define CT_v276	((void*)startLabel+444)
-#define FN_LAMBDA252	((void*)startLabel+488)
-#define CT_v280	((void*)startLabel+532)
-#define CF_LAMBDA252	((void*)startLabel+540)
-#define v282	((void*)startLabel+580)
-#define v283	((void*)startLabel+584)
-#define v284	((void*)startLabel+588)
-#define CT_v288	((void*)startLabel+608)
-#define CT_v292	((void*)startLabel+704)
-#define CT_v296	((void*)startLabel+804)
-#define CT_v300	((void*)startLabel+900)
-#define CT_v304	((void*)startLabel+996)
-#define CT_v308	((void*)startLabel+1120)
-#define ST_v306	((void*)startLabel+1180)
-#define ST_v259	((void*)startLabel+1212)
-#define ST_v255	((void*)startLabel+1252)
-#define ST_v290	((void*)startLabel+1296)
-#define ST_v294	((void*)startLabel+1344)
-#define ST_v286	((void*)startLabel+1388)
-#define ST_v302	((void*)startLabel+1428)
-#define ST_v298	((void*)startLabel+1464)
-#define ST_v269	((void*)startLabel+1500)
-#define PP_LAMBDA252	((void*)startLabel+1537)
-#define PC_LAMBDA252	((void*)startLabel+1537)
-#define ST_v278	((void*)startLabel+1537)
-#define ST_v279	((void*)startLabel+1585)
-#define PS_v285	((void*)startLabel+1664)
-#define PS_v275	((void*)startLabel+1676)
-#define PS_v271	((void*)startLabel+1688)
-#define PS_v272	((void*)startLabel+1700)
-#define PS_v273	((void*)startLabel+1712)
-#define PS_v268	((void*)startLabel+1724)
-#define PS_v274	((void*)startLabel+1736)
-#define PS_v260	((void*)startLabel+1748)
-#define PS_v258	((void*)startLabel+1760)
-#define PS_v256	((void*)startLabel+1772)
-#define PS_v254	((void*)startLabel+1784)
-#define PS_v303	((void*)startLabel+1796)
-#define PS_v301	((void*)startLabel+1808)
-#define PS_v299	((void*)startLabel+1820)
-#define PS_v297	((void*)startLabel+1832)
-#define PS_v295	((void*)startLabel+1844)
-#define PS_v293	((void*)startLabel+1856)
-#define PS_v291	((void*)startLabel+1868)
-#define PS_v289	((void*)startLabel+1880)
-#define PS_v305	((void*)startLabel+1892)
-#define PS_v307	((void*)startLabel+1904)
-#define PS_v277	((void*)startLabel+1916)
+#define CT_v262	((void*)startLabel+64)
+#define CT_v266	((void*)startLabel+156)
+#define v275	((void*)startLabel+216)
+#define v270	((void*)startLabel+220)
+#define v271	((void*)startLabel+230)
+#define v272	((void*)startLabel+240)
+#define v267	((void*)startLabel+250)
+#define CT_v281	((void*)startLabel+444)
+#define FN_LAMBDA257	((void*)startLabel+488)
+#define CT_v285	((void*)startLabel+532)
+#define CF_LAMBDA257	((void*)startLabel+540)
+#define v287	((void*)startLabel+580)
+#define v288	((void*)startLabel+584)
+#define v289	((void*)startLabel+588)
+#define CT_v293	((void*)startLabel+608)
+#define CT_v297	((void*)startLabel+704)
+#define CT_v301	((void*)startLabel+804)
+#define CT_v305	((void*)startLabel+900)
+#define CT_v309	((void*)startLabel+996)
+#define CT_v313	((void*)startLabel+1120)
+#define ST_v311	((void*)startLabel+1180)
+#define ST_v264	((void*)startLabel+1212)
+#define ST_v260	((void*)startLabel+1252)
+#define ST_v295	((void*)startLabel+1296)
+#define ST_v299	((void*)startLabel+1344)
+#define ST_v291	((void*)startLabel+1388)
+#define ST_v307	((void*)startLabel+1428)
+#define ST_v303	((void*)startLabel+1464)
+#define ST_v274	((void*)startLabel+1500)
+#define PP_LAMBDA257	((void*)startLabel+1537)
+#define PC_LAMBDA257	((void*)startLabel+1537)
+#define ST_v283	((void*)startLabel+1537)
+#define ST_v284	((void*)startLabel+1585)
+#define PS_v290	((void*)startLabel+1664)
+#define PS_v280	((void*)startLabel+1676)
+#define PS_v276	((void*)startLabel+1688)
+#define PS_v277	((void*)startLabel+1700)
+#define PS_v278	((void*)startLabel+1712)
+#define PS_v273	((void*)startLabel+1724)
+#define PS_v279	((void*)startLabel+1736)
+#define PS_v265	((void*)startLabel+1748)
+#define PS_v263	((void*)startLabel+1760)
+#define PS_v261	((void*)startLabel+1772)
+#define PS_v259	((void*)startLabel+1784)
+#define PS_v308	((void*)startLabel+1796)
+#define PS_v306	((void*)startLabel+1808)
+#define PS_v304	((void*)startLabel+1820)
+#define PS_v302	((void*)startLabel+1832)
+#define PS_v300	((void*)startLabel+1844)
+#define PS_v298	((void*)startLabel+1856)
+#define PS_v296	((void*)startLabel+1868)
+#define PS_v294	((void*)startLabel+1880)
+#define PS_v310	((void*)startLabel+1892)
+#define PS_v312	((void*)startLabel+1904)
+#define PS_v282	((void*)startLabel+1916)
 extern Node FN_Prelude_46_95enumFromThen[];
 extern Node FN_Prelude_46_95enumFromTo[];
-extern Node FN_Prelude_46error[];
+extern Node FN_NHC_46Internal_46_95patternMatchFail[];
 extern Node FN_Prelude_46_95_46enumFromThenTo[];
 extern Node CF_Prelude_46Enum_46Prelude_46Ordering[];
 extern Node FN_Prelude_46_95_46enumFromTo[];
 extern Node FN_Prelude_46_95_46succ[];
 extern Node FN_Prelude_46_95_46pred[];
 extern Node PM_Prelude[];
-extern Node PC_Prelude_46error[];
+extern Node PC_NHC_46Internal_46_95patternMatchFail[];
 extern Node PC_Prelude_46LT[];
 extern Node PC_Prelude_46EQ[];
 extern Node PC_Prelude_46GT[];
@@ -80,7 +80,7 @@ extern Node PC_Prelude_468[];
 static Node startLabel[] = {
   bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v257)
+, useLabel(CT_v262)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -89,26 +89,26 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen[] = {
 , bytes2word(HEAP_INT_P1,2,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v256)
+, useLabel(PS_v261)
 , 0
 , 0
 , 0
 , 0
 , 160005
-, useLabel(ST_v255)
-,	/* CT_v257: (byte 0) */
+, useLabel(ST_v260)
+,	/* CT_v262: (byte 0) */
   HW(1,2)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen),2)
-, useLabel(PS_v254)
+, useLabel(PS_v259)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95enumFromThen))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v261)
+, useLabel(CT_v266)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFrom[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -117,46 +117,46 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFrom[] = {
 , bytes2word(2,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v260)
+, useLabel(PS_v265)
 , 0
 , 0
 , 0
 , 0
 , 150005
-, useLabel(ST_v259)
-,	/* CT_v261: (byte 0) */
+, useLabel(ST_v264)
+,	/* CT_v266: (byte 0) */
   HW(1,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46enumFrom[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46enumFrom),1)
-, useLabel(PS_v258)
+, useLabel(PS_v263)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95enumFromTo))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v276)
+, useLabel(CT_v281)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
   bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
 , bytes2word(LOOKUPSWITCH,3,TOP(0),BOT(0))
 , bytes2word(TOP(18),BOT(18),TOP(1),BOT(1))
 , bytes2word(TOP(28),BOT(28),TOP(2),BOT(2))
-,	/* v270: (byte 4) */
+,	/* v275: (byte 4) */
   bytes2word(TOP(38),BOT(38),TOP(14),BOT(14))
-,	/* v265: (byte 4) */
+,	/* v270: (byte 4) */
   bytes2word(POP_I1,JUMP,32,0)
 , bytes2word(POP_I1,PUSH_HEAP,HEAP_CVAL_N1,7)
 , bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
-,	/* v266: (byte 2) */
+,	/* v271: (byte 2) */
   bytes2word(HEAP_SPACE,RETURN,POP_I1,PUSH_HEAP)
 , bytes2word(HEAP_CVAL_N1,17,HEAP_CVAL_N1,22)
-,	/* v267: (byte 4) */
+,	/* v272: (byte 4) */
   bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,RETURN)
 , bytes2word(POP_I1,PUSH_HEAP,HEAP_CVAL_N1,27)
 , bytes2word(HEAP_CVAL_N1,32,HEAP_CREATE,HEAP_SPACE)
-,	/* v262: (byte 2) */
+,	/* v267: (byte 2) */
   bytes2word(HEAP_SPACE,RETURN,HEAP_CVAL_P1,7)
 , bytes2word(HEAP_CVAL_N1,37,HEAP_CREATE,HEAP_SPACE)
 , bytes2word(HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1,8)
@@ -164,17 +164,17 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , bytes2word(HEAP_SPACE,HEAP_OFF_N1,10,RETURN_EVAL)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v275)
+, useLabel(PS_v280)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v274)
+, useLabel(PS_v279)
 , 0
 , 0
 , 0
 , 0
-, useLabel(PS_v273)
+, useLabel(PS_v278)
 , 0
 , 0
 , 0
@@ -184,7 +184,7 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , 0
 , 0
 , 0
-, useLabel(PS_v272)
+, useLabel(PS_v277)
 , 0
 , 0
 , 0
@@ -194,7 +194,7 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , 0
 , 0
 , 0
-, useLabel(PS_v271)
+, useLabel(PS_v276)
 , 0
 , 0
 , 0
@@ -205,22 +205,22 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , 0
 , 0
 , 110005
-, useLabel(ST_v269)
-,	/* CT_v276: (byte 0) */
+, useLabel(ST_v274)
+,	/* CT_v281: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46toEnum),1)
-, useLabel(PS_v268)
+, useLabel(PS_v273)
 , 0
 , 0
 , 0
-, VAPTAG(useLabel(FN_LAMBDA252))
-, VAPTAG(useLabel(FN_Prelude_46error))
+, VAPTAG(useLabel(FN_LAMBDA257))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
 , bytes2word(0,0,0,0)
-, useLabel(CT_v280)
-,	/* FN_LAMBDA252: (byte 0) */
+, useLabel(CT_v285)
+,	/* FN_LAMBDA257: (byte 0) */
   bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
@@ -229,48 +229,48 @@ Node F0_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , 0
 , 0
 , 0
-, useLabel(ST_v279)
+, useLabel(ST_v284)
 , 110005
-, useLabel(ST_v278)
-,	/* CT_v280: (byte 0) */
+, useLabel(ST_v283)
+,	/* CT_v285: (byte 0) */
   HW(0,0)
 , 0
-,	/* CF_LAMBDA252: (byte 0) */
-  VAPTAG(useLabel(FN_LAMBDA252))
-, useLabel(PS_v277)
+,	/* CF_LAMBDA257: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA257))
+, useLabel(PS_v282)
 , 0
 , 0
 , 0
 , bytes2word(1,0,0,1)
-, useLabel(CT_v288)
+, useLabel(CT_v293)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[] = {
   bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,TABLESWITCH)
 , bytes2word(3,NOP,TOP(6),BOT(6))
-,	/* v282: (byte 4) */
+,	/* v287: (byte 4) */
   bytes2word(TOP(10),BOT(10),TOP(14),BOT(14))
-,	/* v283: (byte 4) */
+,	/* v288: (byte 4) */
   bytes2word(POP_I1,PUSH_INT_P1,0,RETURN)
-,	/* v284: (byte 4) */
+,	/* v289: (byte 4) */
   bytes2word(POP_I1,PUSH_INT_P1,1,RETURN)
 , bytes2word(POP_I1,PUSH_INT_P1,2,RETURN)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 70005
-, useLabel(ST_v286)
-,	/* CT_v288: (byte 0) */
+, useLabel(ST_v291)
+,	/* CT_v293: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46fromEnum),1)
-, useLabel(PS_v285)
+, useLabel(PS_v290)
 , 0
 , 0
 , 0
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v292)
+, useLabel(CT_v297)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -280,20 +280,20 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
 , bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v291)
+, useLabel(PS_v296)
 , 0
 , 0
 , 0
 , 0
 , 60010
-, useLabel(ST_v290)
-,	/* CT_v292: (byte 0) */
+, useLabel(ST_v295)
+,	/* CT_v297: (byte 0) */
   HW(2,3)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo),3)
-, useLabel(PS_v289)
+, useLabel(PS_v294)
 , 0
 , 0
 , 0
@@ -301,7 +301,7 @@ Node F0_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
 , useLabel(CF_Prelude_46Enum_46Prelude_46Ordering)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v296)
+, useLabel(CT_v301)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -310,27 +310,27 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[] = {
 , bytes2word(1,2,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v295)
+, useLabel(PS_v300)
 , 0
 , 0
 , 0
 , 0
 , 60010
-, useLabel(ST_v294)
-,	/* CT_v296: (byte 0) */
+, useLabel(ST_v299)
+,	/* CT_v301: (byte 0) */
   HW(2,2)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo),2)
-, useLabel(PS_v293)
+, useLabel(PS_v298)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95_46enumFromTo))
 , useLabel(CF_Prelude_46Enum_46Prelude_46Ordering)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v300)
+, useLabel(CT_v305)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46succ[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -339,27 +339,27 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46succ[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v299)
+, useLabel(PS_v304)
 , 0
 , 0
 , 0
 , 0
 , 60010
-, useLabel(ST_v298)
-,	/* CT_v300: (byte 0) */
+, useLabel(ST_v303)
+,	/* CT_v305: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46succ[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46succ),1)
-, useLabel(PS_v297)
+, useLabel(PS_v302)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95_46succ))
 , useLabel(CF_Prelude_46Enum_46Prelude_46Ordering)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v304)
+, useLabel(CT_v309)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering_46pred[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
@@ -368,27 +368,27 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering_46pred[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 0
-, useLabel(PS_v303)
+, useLabel(PS_v308)
 , 0
 , 0
 , 0
 , 0
 , 60010
-, useLabel(ST_v302)
-,	/* CT_v304: (byte 0) */
+, useLabel(ST_v307)
+,	/* CT_v309: (byte 0) */
   HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46Enum_46Prelude_46Ordering_46pred[] = {
   CAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering_46pred),1)
-, useLabel(PS_v301)
+, useLabel(PS_v306)
 , 0
 , 0
 , 0
 , VAPTAG(useLabel(FN_Prelude_46_95_46pred))
 , useLabel(CF_Prelude_46Enum_46Prelude_46Ordering)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v308)
+, useLabel(CT_v313)
 ,};
 Node FN_Prelude_46Enum_46Prelude_46Ordering[] = {
   bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_N1,7)
@@ -399,7 +399,7 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering[] = {
 , bytes2word(12,HEAP_CVAL_P1,13,HEAP_CVAL_P1)
 , bytes2word(14,RETURN,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, useLabel(PS_v307)
+, useLabel(PS_v312)
 , 0
 , 0
 , 0
@@ -410,14 +410,14 @@ Node FN_Prelude_46Enum_46Prelude_46Ordering[] = {
 , 0
 , 0
 , 60010
-, useLabel(ST_v306)
-,	/* CT_v308: (byte 0) */
+, useLabel(ST_v311)
+,	/* CT_v313: (byte 0) */
   HW(8,0)
 , 0
 ,};
 Node CF_Prelude_46Enum_46Prelude_46Ordering[] = {
   VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Ordering))
-, useLabel(PS_v305)
+, useLabel(PS_v310)
 , 0
 , 0
 , 0
@@ -433,7 +433,7 @@ Node CF_Prelude_46Enum_46Prelude_46Ordering[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering[] = {
- 	/* ST_v306: (byte 0) */
+ 	/* ST_v311: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -446,7 +446,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46enumFrom[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFrom[] = {
- 	/* ST_v259: (byte 0) */
+ 	/* ST_v264: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -461,7 +461,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFrom[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen[] = {
- 	/* ST_v255: (byte 0) */
+ 	/* ST_v260: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -477,7 +477,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
- 	/* ST_v290: (byte 0) */
+ 	/* ST_v295: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -494,7 +494,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[] = {
- 	/* ST_v294: (byte 0) */
+ 	/* ST_v299: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -510,7 +510,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[] = {
- 	/* ST_v286: (byte 0) */
+ 	/* ST_v291: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -525,7 +525,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46fromEnum[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46pred[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46pred[] = {
- 	/* ST_v302: (byte 0) */
+ 	/* ST_v307: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -539,7 +539,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46pred[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46succ[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46succ[] = {
- 	/* ST_v298: (byte 0) */
+ 	/* ST_v303: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -553,7 +553,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46succ[] = {
 Node PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
  };
 Node PC_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
- 	/* ST_v269: (byte 0) */
+ 	/* ST_v274: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(69,110,117,109)
@@ -563,9 +563,9 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , bytes2word(101,114,105,110)
 , bytes2word(103,46,116,111)
 , bytes2word(69,110,117,109)
-,	/* PP_LAMBDA252: (byte 1) */
- 	/* PC_LAMBDA252: (byte 1) */
- 	/* ST_v278: (byte 1) */
+,	/* PP_LAMBDA257: (byte 1) */
+ 	/* PC_LAMBDA257: (byte 1) */
+ 	/* ST_v283: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,69,110,117)
@@ -578,7 +578,7 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , bytes2word(109,58,49,49)
 , bytes2word(58,53,45,49)
 , bytes2word(51,58,49,57)
-,	/* ST_v279: (byte 1) */
+,	/* ST_v284: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(58,46,47,69)
@@ -599,92 +599,92 @@ Node PC_Prelude_46Enum_46Prelude_46Ordering_46toEnum[] = {
 , bytes2word(58,53,45,49)
 , bytes2word(51,58,49,57)
 , bytes2word(46,0,0,0)
-,	/* PS_v285: (byte 0) */
+,	/* PS_v290: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46fromEnum)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46fromEnum)
-,	/* PS_v275: (byte 0) */
+,	/* PS_v280: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
-, useLabel(PC_Prelude_46error)
-,	/* PS_v271: (byte 0) */
+, useLabel(PC_NHC_46Internal_46_95patternMatchFail)
+,	/* PS_v276: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
 , useLabel(PC_Prelude_46LT)
-,	/* PS_v272: (byte 0) */
+,	/* PS_v277: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
 , useLabel(PC_Prelude_46EQ)
-,	/* PS_v273: (byte 0) */
+,	/* PS_v278: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
 , useLabel(PC_Prelude_46GT)
-,	/* PS_v268: (byte 0) */
+,	/* PS_v273: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
-,	/* PS_v274: (byte 0) */
+,	/* PS_v279: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46toEnum)
-, useLabel(PC_LAMBDA252)
-,	/* PS_v260: (byte 0) */
+, useLabel(PC_LAMBDA257)
+,	/* PS_v265: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFrom)
 , useLabel(PC_Prelude_46_95enumFromTo)
-,	/* PS_v258: (byte 0) */
+,	/* PS_v263: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFrom)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46enumFrom)
-,	/* PS_v256: (byte 0) */
+,	/* PS_v261: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen)
 , useLabel(PC_Prelude_46_95enumFromThen)
-,	/* PS_v254: (byte 0) */
+,	/* PS_v259: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromThen)
-,	/* PS_v303: (byte 0) */
+,	/* PS_v308: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46pred)
 , useLabel(PC_Prelude_46_95_46pred)
-,	/* PS_v301: (byte 0) */
+,	/* PS_v306: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46pred)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46pred)
-,	/* PS_v299: (byte 0) */
+,	/* PS_v304: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46succ)
 , useLabel(PC_Prelude_46_95_46succ)
-,	/* PS_v297: (byte 0) */
+,	/* PS_v302: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46succ)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46succ)
-,	/* PS_v295: (byte 0) */
+,	/* PS_v300: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo)
 , useLabel(PC_Prelude_46_95_46enumFromTo)
-,	/* PS_v293: (byte 0) */
+,	/* PS_v298: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromTo)
-,	/* PS_v291: (byte 0) */
+,	/* PS_v296: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo)
 , useLabel(PC_Prelude_46_95_46enumFromThenTo)
-,	/* PS_v289: (byte 0) */
+,	/* PS_v294: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering_46enumFromThenTo)
-,	/* PS_v305: (byte 0) */
+,	/* PS_v310: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering)
 , useLabel(PC_Prelude_46Enum_46Prelude_46Ordering)
-,	/* PS_v307: (byte 0) */
+,	/* PS_v312: (byte 0) */
   useLabel(PM_Prelude)
 , useLabel(PP_Prelude_46Enum_46Prelude_46Ordering)
 , useLabel(PC_Prelude_468)
-,	/* PS_v277: (byte 0) */
+,	/* PS_v282: (byte 0) */
   useLabel(PM_Prelude)
-, useLabel(PP_LAMBDA252)
-, useLabel(PC_LAMBDA252)
+, useLabel(PP_LAMBDA257)
+, useLabel(PC_LAMBDA257)
 ,};
