@@ -1,37 +1,60 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v296	((void*)startLabel+40)
-#define CT_v298	((void*)startLabel+92)
-#define CT_v300	((void*)startLabel+144)
-#define CT_v302	((void*)startLabel+196)
-#define CT_v304	((void*)startLabel+248)
-#define CT_v306	((void*)startLabel+296)
-#define CT_v308	((void*)startLabel+344)
-#define CT_v310	((void*)startLabel+412)
-#define CT_v312	((void*)startLabel+456)
-#define CT_v314	((void*)startLabel+508)
-#define CT_v316	((void*)startLabel+556)
-#define CT_v318	((void*)startLabel+612)
-#define CT_v320	((void*)startLabel+664)
-#define CT_v322	((void*)startLabel+716)
-#define CT_v324	((void*)startLabel+804)
-#define ST_v323	((void*)startLabel+880)
-#define ST_v315	((void*)startLabel+912)
-#define ST_v307	((void*)startLabel+950)
-#define ST_v305	((void*)startLabel+994)
-#define ST_v321	((void*)startLabel+1038)
-#define ST_v311	((void*)startLabel+1079)
-#define ST_v313	((void*)startLabel+1123)
-#define ST_v309	((void*)startLabel+1166)
-#define ST_v299	((void*)startLabel+1209)
-#define ST_v295	((void*)startLabel+1256)
-#define ST_v301	((void*)startLabel+1295)
-#define ST_v303	((void*)startLabel+1338)
-#define ST_v297	((void*)startLabel+1376)
-#define ST_v317	((void*)startLabel+1423)
-#define ST_v319	((void*)startLabel+1466)
+#define FN_Prelude_46cFIsNeg	((void*)startLabel+8)
+#define CT_v330	((void*)startLabel+36)
+#define F0_Prelude_46cFIsNeg	((void*)startLabel+44)
+#define FN_Prelude_46cFIsNormal	((void*)startLabel+56)
+#define CT_v332	((void*)startLabel+84)
+#define F0_Prelude_46cFIsNormal	((void*)startLabel+92)
+#define FN_Prelude_46cFIsFinite	((void*)startLabel+104)
+#define CT_v334	((void*)startLabel+132)
+#define F0_Prelude_46cFIsFinite	((void*)startLabel+140)
+#define FN_Prelude_46cFIsNaN	((void*)startLabel+152)
+#define CT_v336	((void*)startLabel+180)
+#define F0_Prelude_46cFIsNaN	((void*)startLabel+188)
+#define CT_v338	((void*)startLabel+232)
+#define CT_v340	((void*)startLabel+296)
+#define CT_v342	((void*)startLabel+356)
+#define CT_v344	((void*)startLabel+412)
+#define CT_v346	((void*)startLabel+464)
+#define CT_v348	((void*)startLabel+516)
+#define CT_v350	((void*)startLabel+564)
+#define CT_v352	((void*)startLabel+632)
+#define CT_v354	((void*)startLabel+676)
+#define CT_v356	((void*)startLabel+728)
+#define CT_v358	((void*)startLabel+776)
+#define CT_v360	((void*)startLabel+832)
+#define CT_v362	((void*)startLabel+884)
+#define CT_v364	((void*)startLabel+936)
+#define CT_v366	((void*)startLabel+1024)
+#define ST_v365	((void*)startLabel+1100)
+#define ST_v357	((void*)startLabel+1132)
+#define ST_v349	((void*)startLabel+1170)
+#define ST_v347	((void*)startLabel+1214)
+#define ST_v363	((void*)startLabel+1258)
+#define ST_v353	((void*)startLabel+1299)
+#define ST_v355	((void*)startLabel+1343)
+#define ST_v351	((void*)startLabel+1386)
+#define ST_v341	((void*)startLabel+1429)
+#define ST_v337	((void*)startLabel+1476)
+#define ST_v343	((void*)startLabel+1515)
+#define ST_v345	((void*)startLabel+1558)
+#define ST_v339	((void*)startLabel+1596)
+#define ST_v359	((void*)startLabel+1643)
+#define ST_v361	((void*)startLabel+1686)
+#define ST_v333	((void*)startLabel+1730)
+#define ST_v335	((void*)startLabel+1749)
+#define ST_v329	((void*)startLabel+1765)
+#define ST_v331	((void*)startLabel+1781)
 extern Node TM_Prelude[];
+void FR_Prelude_46cFIsNeg(void);
+void FR_Prelude_46cFIsNormal(void);
+void FR_Prelude_46cFIsFinite(void);
+void FR_Prelude_46cFIsNaN(void);
+extern Node FN_Prelude_46Eq_46Prelude_46Float_46_61_61[];
+extern Node FN_Prelude_46_38_38[];
+extern Node FN_Prelude_46not[];
 extern Node FN_Prelude_46primEncodeFloat[];
 extern Node FN_Prelude_46primDecodeFloat[];
 extern Node FN_Prelude_46_95_46atan2[];
@@ -44,7 +67,67 @@ extern Node CF_Prelude_46Floating_46Prelude_46Float[];
 
 static Node startLabel[] = {
   bytes2word(1,0,0,1)
-, useLabel(CT_v296)
+, useLabel(CT_v330)
+,	/* FN_Prelude_46cFIsNeg: (byte 0) */
+  useLabel(TM_Prelude)
+, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
+, useLabel(FR_Prelude_46cFIsNeg)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, 260001
+, useLabel(ST_v329)
+,	/* CT_v330: (byte 0) */
+  HW(0,1)
+, 0
+,	/* F0_Prelude_46cFIsNeg: (byte 0) */
+  CAPTAG(useLabel(FN_Prelude_46cFIsNeg),1)
+, bytes2word(1,0,0,1)
+, useLabel(CT_v332)
+,	/* FN_Prelude_46cFIsNormal: (byte 0) */
+  useLabel(TM_Prelude)
+, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
+, useLabel(FR_Prelude_46cFIsNormal)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, 250001
+, useLabel(ST_v331)
+,	/* CT_v332: (byte 0) */
+  HW(0,1)
+, 0
+,	/* F0_Prelude_46cFIsNormal: (byte 0) */
+  CAPTAG(useLabel(FN_Prelude_46cFIsNormal),1)
+, bytes2word(1,0,0,1)
+, useLabel(CT_v334)
+,	/* FN_Prelude_46cFIsFinite: (byte 0) */
+  useLabel(TM_Prelude)
+, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
+, useLabel(FR_Prelude_46cFIsFinite)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, 240001
+, useLabel(ST_v333)
+,	/* CT_v334: (byte 0) */
+  HW(0,1)
+, 0
+,	/* F0_Prelude_46cFIsFinite: (byte 0) */
+  CAPTAG(useLabel(FN_Prelude_46cFIsFinite),1)
+, bytes2word(1,0,0,1)
+, useLabel(CT_v336)
+,	/* FN_Prelude_46cFIsNaN: (byte 0) */
+  useLabel(TM_Prelude)
+, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
+, useLabel(FR_Prelude_46cFIsNaN)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, 230001
+, useLabel(ST_v335)
+,	/* CT_v336: (byte 0) */
+  HW(0,1)
+, 0
+,	/* F0_Prelude_46cFIsNaN: (byte 0) */
+  CAPTAG(useLabel(FN_Prelude_46cFIsNaN),1)
+, bytes2word(1,0,0,1)
+, useLabel(CT_v338)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46isIEEE[] = {
   useLabel(TM_Prelude)
@@ -52,90 +135,97 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46isIEEE[] = {
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 0
-, CONSTR(0,0,0)
+, CONSTR(1,0,0)
 , 210005
-, useLabel(ST_v295)
-,	/* CT_v296: (byte 0) */
+, useLabel(ST_v337)
+,	/* CT_v338: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46isIEEE[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46isIEEE),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v298)
+, useLabel(CT_v340)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46isNegativeZero[] = {
   useLabel(TM_Prelude)
-, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
-, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
+, bytes2word(HEAP_CVAL_I4,HEAP_ARG,1,HEAP_CADR_N1)
+, bytes2word(4,PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1)
+, bytes2word(6,HEAP_OFF_N1,5,RETURN_EVAL)
+, bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
+, CONSTRW(1,0)
 , 0
-, CONSTR(0,0,0)
 , 200005
-, useLabel(ST_v297)
-,	/* CT_v298: (byte 0) */
-  HW(0,1)
+, useLabel(ST_v339)
+,	/* CT_v340: (byte 0) */
+  HW(3,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46isNegativeZero[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46isNegativeZero),1)
+, VAPTAG(useLabel(FN_Prelude_46cFIsNeg))
+, VAPTAG(useLabel(FN_Prelude_46Eq_46Prelude_46Float_46_61_61))
+, VAPTAG(useLabel(FN_Prelude_46_38_38))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v300)
+, useLabel(CT_v342)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46isDenormalized[] = {
   useLabel(TM_Prelude)
-, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
-, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
+, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 0
-, CONSTR(0,0,0)
 , 190005
-, useLabel(ST_v299)
-,	/* CT_v300: (byte 0) */
-  HW(0,1)
+, useLabel(ST_v341)
+,	/* CT_v342: (byte 0) */
+  HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46isDenormalized[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46isDenormalized),1)
+, VAPTAG(useLabel(FN_Prelude_46cFIsNormal))
+, VAPTAG(useLabel(FN_Prelude_46not))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v302)
+, useLabel(CT_v344)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46isInfinite[] = {
   useLabel(TM_Prelude)
-, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
-, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
+, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,3)
+, bytes2word(RETURN_EVAL,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
-, 0
-, CONSTR(0,0,0)
 , 180005
-, useLabel(ST_v301)
-,	/* CT_v302: (byte 0) */
-  HW(0,1)
+, useLabel(ST_v343)
+,	/* CT_v344: (byte 0) */
+  HW(2,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46isInfinite[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46isInfinite),1)
+, VAPTAG(useLabel(FN_Prelude_46cFIsFinite))
+, VAPTAG(useLabel(FN_Prelude_46not))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v304)
+, useLabel(CT_v346)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46isNaN[] = {
   useLabel(TM_Prelude)
-, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3)
-, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
+, bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
-, 0
-, CONSTR(0,0,0)
 , 170005
-, useLabel(ST_v303)
-,	/* CT_v304: (byte 0) */
-  HW(0,1)
+, useLabel(ST_v345)
+,	/* CT_v346: (byte 0) */
+  HW(1,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46isNaN[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46isNaN),1)
+, VAPTAG(useLabel(FN_Prelude_46cFIsNaN))
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v306)
+, useLabel(CT_v348)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46encodeFloat[] = {
   useLabel(TM_Prelude)
@@ -143,8 +233,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46encodeFloat[] = {
 , bytes2word(1,2,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 140005
-, useLabel(ST_v305)
-,	/* CT_v306: (byte 0) */
+, useLabel(ST_v347)
+,	/* CT_v348: (byte 0) */
   HW(1,2)
 , 0
 ,};
@@ -152,7 +242,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46encodeFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46encodeFloat),2)
 , VAPTAG(useLabel(FN_Prelude_46primEncodeFloat))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v308)
+, useLabel(CT_v350)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46decodeFloat[] = {
   useLabel(TM_Prelude)
@@ -160,8 +250,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46decodeFloat[] = {
 , bytes2word(1,RETURN_EVAL,ENDCODE,0)
 , bytes2word(0,0,0,0)
 , 130005
-, useLabel(ST_v307)
-,	/* CT_v308: (byte 0) */
+, useLabel(ST_v349)
+,	/* CT_v350: (byte 0) */
   HW(1,1)
 , 0
 ,};
@@ -169,7 +259,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46decodeFloat[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46decodeFloat),1)
 , VAPTAG(useLabel(FN_Prelude_46primDecodeFloat))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v310)
+, useLabel(CT_v352)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46floatRange[] = {
   useLabel(TM_Prelude)
@@ -182,15 +272,15 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46floatRange[] = {
 , -148
 , CONSTR(0,2,0)
 , 120005
-, useLabel(ST_v309)
-,	/* CT_v310: (byte 0) */
+, useLabel(ST_v351)
+,	/* CT_v352: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46floatRange[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46floatRange),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v312)
+, useLabel(CT_v354)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46floatDigits[] = {
   useLabel(TM_Prelude)
@@ -198,15 +288,15 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46floatDigits[] = {
 , bytes2word(RETURN,ENDCODE,0,0)
 , bytes2word(0,0,0,0)
 , 110005
-, useLabel(ST_v311)
-,	/* CT_v312: (byte 0) */
+, useLabel(ST_v353)
+,	/* CT_v354: (byte 0) */
   HW(0,1)
 , 0
 ,};
 Node F0_Prelude_46RealFloat_46Prelude_46Float_46floatDigits[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46floatDigits),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v314)
+, useLabel(CT_v356)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46floatRadix[] = {
   useLabel(TM_Prelude)
@@ -216,8 +306,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46floatRadix[] = {
 , CONSTRW(1,0)
 , 2
 , 100005
-, useLabel(ST_v313)
-,	/* CT_v314: (byte 0) */
+, useLabel(ST_v355)
+,	/* CT_v356: (byte 0) */
   HW(0,1)
 , 0
 ,};
@@ -225,7 +315,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46floatRadix[] = {
   CAPTAG(useLabel(FN_Prelude_46RealFloat_46Prelude_46Float_46floatRadix),1)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v316)
+, useLabel(CT_v358)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46atan2[] = {
   useLabel(TM_Prelude)
@@ -233,8 +323,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46atan2[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 90011
-, useLabel(ST_v315)
-,	/* CT_v316: (byte 0) */
+, useLabel(ST_v357)
+,	/* CT_v358: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -244,7 +334,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46atan2[] = {
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Float)
 , bytes2word(0,0,2,0)
 , bytes2word(1,1,0,2)
-, useLabel(CT_v318)
+, useLabel(CT_v360)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46scaleFloat[] = {
   useLabel(TM_Prelude)
@@ -252,8 +342,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46scaleFloat[] = {
 , bytes2word(HEAP_ARG_ARG_RET_EVAL,1,2,ENDCODE)
 , bytes2word(0,0,0,0)
 , 90011
-, useLabel(ST_v317)
-,	/* CT_v318: (byte 0) */
+, useLabel(ST_v359)
+,	/* CT_v360: (byte 0) */
   HW(2,2)
 , 0
 ,};
@@ -262,7 +352,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46scaleFloat[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46scaleFloat))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Float)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v320)
+, useLabel(CT_v362)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46significand[] = {
   useLabel(TM_Prelude)
@@ -270,8 +360,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46significand[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 90011
-, useLabel(ST_v319)
-,	/* CT_v320: (byte 0) */
+, useLabel(ST_v361)
+,	/* CT_v362: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -280,7 +370,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46significand[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46significand))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Float)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v322)
+, useLabel(CT_v364)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float_46exponent[] = {
   useLabel(TM_Prelude)
@@ -288,8 +378,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float_46exponent[] = {
 , bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 90011
-, useLabel(ST_v321)
-,	/* CT_v322: (byte 0) */
+, useLabel(ST_v363)
+,	/* CT_v364: (byte 0) */
   HW(2,1)
 , 0
 ,};
@@ -298,7 +388,7 @@ Node F0_Prelude_46RealFloat_46Prelude_46Float_46exponent[] = {
 , VAPTAG(useLabel(FN_Prelude_46_95_46exponent))
 , useLabel(CF_Prelude_46RealFloat_46Prelude_46Float)
 , bytes2word(0,0,0,0)
-, useLabel(CT_v324)
+, useLabel(CT_v366)
 ,};
 Node FN_Prelude_46RealFloat_46Prelude_46Float[] = {
   useLabel(TM_Prelude)
@@ -315,8 +405,8 @@ Node FN_Prelude_46RealFloat_46Prelude_46Float[] = {
 , 0
 , CONSTR(0,16,0)
 , 90011
-, useLabel(ST_v323)
-,	/* CT_v324: (byte 0) */
+, useLabel(ST_v365)
+,	/* CT_v366: (byte 0) */
   HW(16,0)
 , 0
 ,};
@@ -338,7 +428,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , useLabel(F0_Prelude_46RealFloat_46Prelude_46Float_46scaleFloat)
 , useLabel(F0_Prelude_46RealFloat_46Prelude_46Float_46exponent)
 , useLabel(F0_Prelude_46RealFloat_46Prelude_46Float_46floatRadix)
-,	/* ST_v323: (byte 0) */
+,	/* ST_v365: (byte 0) */
   bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
 , bytes2word(82,101,97,108)
@@ -346,7 +436,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(116,46,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,70,108)
-,	/* ST_v315: (byte 4) */
+,	/* ST_v357: (byte 4) */
   bytes2word(111,97,116,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -357,7 +447,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(101,46,70,108)
 , bytes2word(111,97,116,46)
 , bytes2word(97,116,97,110)
-,	/* ST_v307: (byte 2) */
+,	/* ST_v349: (byte 2) */
   bytes2word(50,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -369,7 +459,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(116,46,100,101)
 , bytes2word(99,111,100,101)
 , bytes2word(70,108,111,97)
-,	/* ST_v305: (byte 2) */
+,	/* ST_v347: (byte 2) */
   bytes2word(116,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -381,7 +471,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(116,46,101,110)
 , bytes2word(99,111,100,101)
 , bytes2word(70,108,111,97)
-,	/* ST_v321: (byte 2) */
+,	/* ST_v363: (byte 2) */
   bytes2word(116,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -392,7 +482,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(70,108,111,97)
 , bytes2word(116,46,101,120)
 , bytes2word(112,111,110,101)
-,	/* ST_v311: (byte 3) */
+,	/* ST_v353: (byte 3) */
   bytes2word(110,116,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,82)
@@ -404,7 +494,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(97,116,46,102)
 , bytes2word(108,111,97,116)
 , bytes2word(68,105,103,105)
-,	/* ST_v313: (byte 3) */
+,	/* ST_v355: (byte 3) */
   bytes2word(116,115,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,82)
@@ -416,7 +506,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(97,116,46,102)
 , bytes2word(108,111,97,116)
 , bytes2word(82,97,100,105)
-,	/* ST_v309: (byte 2) */
+,	/* ST_v351: (byte 2) */
   bytes2word(120,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -428,7 +518,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(116,46,102,108)
 , bytes2word(111,97,116,82)
 , bytes2word(97,110,103,101)
-,	/* ST_v299: (byte 1) */
+,	/* ST_v341: (byte 1) */
   bytes2word(0,80,114,101)
 , bytes2word(108,117,100,101)
 , bytes2word(46,82,101,97)
@@ -440,7 +530,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(46,105,115,68)
 , bytes2word(101,110,111,114)
 , bytes2word(109,97,108,105)
-,	/* ST_v295: (byte 4) */
+,	/* ST_v337: (byte 4) */
   bytes2word(122,101,100,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -451,7 +541,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(101,46,70,108)
 , bytes2word(111,97,116,46)
 , bytes2word(105,115,73,69)
-,	/* ST_v301: (byte 3) */
+,	/* ST_v343: (byte 3) */
   bytes2word(69,69,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,82)
@@ -463,7 +553,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(97,116,46,105)
 , bytes2word(115,73,110,102)
 , bytes2word(105,110,105,116)
-,	/* ST_v303: (byte 2) */
+,	/* ST_v345: (byte 2) */
   bytes2word(101,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -473,7 +563,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(117,100,101,46)
 , bytes2word(70,108,111,97)
 , bytes2word(116,46,105,115)
-,	/* ST_v297: (byte 4) */
+,	/* ST_v339: (byte 4) */
   bytes2word(78,97,78,0)
 , bytes2word(80,114,101,108)
 , bytes2word(117,100,101,46)
@@ -486,7 +576,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(105,115,78,101)
 , bytes2word(103,97,116,105)
 , bytes2word(118,101,90,101)
-,	/* ST_v317: (byte 3) */
+,	/* ST_v359: (byte 3) */
   bytes2word(114,111,0,80)
 , bytes2word(114,101,108,117)
 , bytes2word(100,101,46,82)
@@ -498,7 +588,7 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(97,116,46,115)
 , bytes2word(99,97,108,101)
 , bytes2word(70,108,111,97)
-,	/* ST_v319: (byte 2) */
+,	/* ST_v361: (byte 2) */
   bytes2word(116,0,80,114)
 , bytes2word(101,108,117,100)
 , bytes2word(101,46,82,101)
@@ -510,5 +600,109 @@ Node CF_Prelude_46RealFloat_46Prelude_46Float[] = {
 , bytes2word(116,46,115,105)
 , bytes2word(103,110,105,102)
 , bytes2word(105,99,97,110)
-, bytes2word(100,0,0,0)
+,	/* ST_v333: (byte 2) */
+  bytes2word(100,0,80,114)
+, bytes2word(101,108,117,100)
+, bytes2word(101,46,99,70)
+, bytes2word(73,115,70,105)
+, bytes2word(110,105,116,101)
+,	/* ST_v335: (byte 1) */
+  bytes2word(0,80,114,101)
+, bytes2word(108,117,100,101)
+, bytes2word(46,99,70,73)
+, bytes2word(115,78,97,78)
+,	/* ST_v329: (byte 1) */
+  bytes2word(0,80,114,101)
+, bytes2word(108,117,100,101)
+, bytes2word(46,99,70,73)
+, bytes2word(115,78,101,103)
+,	/* ST_v331: (byte 1) */
+  bytes2word(0,80,114,101)
+, bytes2word(108,117,100,101)
+, bytes2word(46,99,70,73)
+, bytes2word(115,78,111,114)
+, bytes2word(109,97,108,0)
 ,};
+
+#include <haskell2c.h>
+#include <HsFFI.h>
+
+/* foreign import ccall "math.h signbit" Prelude.cFIsNeg 1 :: Prelude.Float -> Prelude.Bool */
+#include "math.h"
+#ifdef PROFILE
+static SInfo pf_Prelude_46cFIsNeg = {"Prelude","Prelude.cFIsNeg","Prelude.Bool"};
+#endif
+C_HEADER(FR_Prelude_46cFIsNeg) {
+  NodePtr nodeptr;
+  HsBool result;
+  float arg1;
+  nodeptr = C_GETARG1(1);
+  IND_REMOVE(nodeptr);
+  arg1 = (float)get_float_value(nodeptr);
+
+  result = signbit(arg1);
+
+  nodeptr = nhc_mkBool(result);
+  INIT_PROFINFO(nodeptr,&pf_Prelude_46cFIsNeg);
+  C_RETURN(nodeptr);
+}
+
+/* foreign import ccall "math.h isnormal" Prelude.cFIsNormal 1 :: Prelude.Float -> Prelude.Bool */
+#include "math.h"
+#ifdef PROFILE
+static SInfo pf_Prelude_46cFIsNormal = {"Prelude","Prelude.cFIsNormal","Prelude.Bool"};
+#endif
+C_HEADER(FR_Prelude_46cFIsNormal) {
+  NodePtr nodeptr;
+  HsBool result;
+  float arg1;
+  nodeptr = C_GETARG1(1);
+  IND_REMOVE(nodeptr);
+  arg1 = (float)get_float_value(nodeptr);
+
+  result = isnormal(arg1);
+
+  nodeptr = nhc_mkBool(result);
+  INIT_PROFINFO(nodeptr,&pf_Prelude_46cFIsNormal);
+  C_RETURN(nodeptr);
+}
+
+/* foreign import ccall "math.h isfinite" Prelude.cFIsFinite 1 :: Prelude.Float -> Prelude.Bool */
+#include "math.h"
+#ifdef PROFILE
+static SInfo pf_Prelude_46cFIsFinite = {"Prelude","Prelude.cFIsFinite","Prelude.Bool"};
+#endif
+C_HEADER(FR_Prelude_46cFIsFinite) {
+  NodePtr nodeptr;
+  HsBool result;
+  float arg1;
+  nodeptr = C_GETARG1(1);
+  IND_REMOVE(nodeptr);
+  arg1 = (float)get_float_value(nodeptr);
+
+  result = isfinite(arg1);
+
+  nodeptr = nhc_mkBool(result);
+  INIT_PROFINFO(nodeptr,&pf_Prelude_46cFIsFinite);
+  C_RETURN(nodeptr);
+}
+
+/* foreign import ccall "math.h isnan" Prelude.cFIsNaN 1 :: Prelude.Float -> Prelude.Bool */
+#include "math.h"
+#ifdef PROFILE
+static SInfo pf_Prelude_46cFIsNaN = {"Prelude","Prelude.cFIsNaN","Prelude.Bool"};
+#endif
+C_HEADER(FR_Prelude_46cFIsNaN) {
+  NodePtr nodeptr;
+  HsBool result;
+  float arg1;
+  nodeptr = C_GETARG1(1);
+  IND_REMOVE(nodeptr);
+  arg1 = (float)get_float_value(nodeptr);
+
+  result = isnan(arg1);
+
+  nodeptr = nhc_mkBool(result);
+  INIT_PROFINFO(nodeptr,&pf_Prelude_46cFIsNaN);
+  C_RETURN(nodeptr);
+}
