@@ -1,62 +1,72 @@
 #include "newmacros.h"
 #include "runtime.h"
 
-#define CT_v349	((void*)startLabel+76)
-#define FN_Ratio_46Prelude_46154_46simplest	((void*)startLabel+124)
-#define v350	((void*)startLabel+213)
-#define v352	((void*)startLabel+240)
-#define v354	((void*)startLabel+292)
-#define v356	((void*)startLabel+365)
-#define CT_v359	((void*)startLabel+404)
-#define F0_Ratio_46Prelude_46154_46simplest	((void*)startLabel+412)
-#define FN_LAMBDA339	((void*)startLabel+504)
-#define CT_v361	((void*)startLabel+528)
-#define F0_LAMBDA339	((void*)startLabel+536)
-#define FN_LAMBDA338	((void*)startLabel+548)
-#define CT_v363	((void*)startLabel+572)
-#define F0_LAMBDA338	((void*)startLabel+580)
-#define FN_LAMBDA337	((void*)startLabel+592)
-#define CT_v365	((void*)startLabel+616)
-#define F0_LAMBDA337	((void*)startLabel+624)
-#define FN_LAMBDA336	((void*)startLabel+636)
-#define CT_v367	((void*)startLabel+660)
-#define F0_LAMBDA336	((void*)startLabel+668)
-#define FN_Ratio_46Prelude_46155_46simplest_39	((void*)startLabel+688)
-#define v368	((void*)startLabel+879)
-#define v370	((void*)startLabel+982)
-#define CT_v373	((void*)startLabel+1072)
-#define F0_Ratio_46Prelude_46155_46simplest_39	((void*)startLabel+1080)
-#define FN_LAMBDA335	((void*)startLabel+1168)
-#define CT_v375	((void*)startLabel+1192)
-#define F0_LAMBDA335	((void*)startLabel+1200)
-#define FN_LAMBDA334	((void*)startLabel+1212)
-#define CT_v377	((void*)startLabel+1236)
-#define F0_LAMBDA334	((void*)startLabel+1244)
-#define FN_LAMBDA333	((void*)startLabel+1256)
-#define CT_v379	((void*)startLabel+1280)
-#define F0_LAMBDA333	((void*)startLabel+1288)
-#define FN_LAMBDA332	((void*)startLabel+1300)
-#define CT_v381	((void*)startLabel+1324)
-#define F0_LAMBDA332	((void*)startLabel+1332)
-#define FN_LAMBDA331	((void*)startLabel+1344)
-#define CT_v383	((void*)startLabel+1368)
-#define F0_LAMBDA331	((void*)startLabel+1376)
-#define FN_LAMBDA330	((void*)startLabel+1388)
-#define CT_v385	((void*)startLabel+1412)
-#define F0_LAMBDA330	((void*)startLabel+1420)
-#define ST_v348	((void*)startLabel+1424)
-#define ST_v358	((void*)startLabel+1445)
-#define ST_v362	((void*)startLabel+1478)
-#define ST_v360	((void*)startLabel+1505)
-#define ST_v366	((void*)startLabel+1532)
-#define ST_v364	((void*)startLabel+1565)
-#define ST_v372	((void*)startLabel+1598)
-#define ST_v380	((void*)startLabel+1631)
-#define ST_v378	((void*)startLabel+1658)
-#define ST_v384	((void*)startLabel+1685)
-#define ST_v382	((void*)startLabel+1718)
-#define ST_v376	((void*)startLabel+1751)
-#define ST_v374	((void*)startLabel+1784)
+#define CT_v356	((void*)startLabel+76)
+#define FN_Ratio_46Prelude_46159_46simplest	((void*)startLabel+124)
+#define v357	((void*)startLabel+213)
+#define v359	((void*)startLabel+240)
+#define v361	((void*)startLabel+292)
+#define v363	((void*)startLabel+365)
+#define v365	((void*)startLabel+379)
+#define CT_v368	((void*)startLabel+424)
+#define F0_Ratio_46Prelude_46159_46simplest	((void*)startLabel+432)
+#define FN_LAMBDA346	((void*)startLabel+532)
+#define CT_v370	((void*)startLabel+564)
+#define CF_LAMBDA346	((void*)startLabel+572)
+#define FN_LAMBDA345	((void*)startLabel+584)
+#define CT_v372	((void*)startLabel+608)
+#define F0_LAMBDA345	((void*)startLabel+616)
+#define FN_LAMBDA344	((void*)startLabel+628)
+#define CT_v374	((void*)startLabel+652)
+#define F0_LAMBDA344	((void*)startLabel+660)
+#define FN_LAMBDA343	((void*)startLabel+672)
+#define CT_v376	((void*)startLabel+696)
+#define F0_LAMBDA343	((void*)startLabel+704)
+#define FN_LAMBDA342	((void*)startLabel+716)
+#define CT_v378	((void*)startLabel+740)
+#define F0_LAMBDA342	((void*)startLabel+748)
+#define FN_Ratio_46Prelude_46160_46simplest_39	((void*)startLabel+768)
+#define v379	((void*)startLabel+959)
+#define v381	((void*)startLabel+1062)
+#define v383	((void*)startLabel+1124)
+#define CT_v386	((void*)startLabel+1172)
+#define F0_Ratio_46Prelude_46160_46simplest_39	((void*)startLabel+1180)
+#define FN_LAMBDA341	((void*)startLabel+1276)
+#define CT_v388	((void*)startLabel+1308)
+#define CF_LAMBDA341	((void*)startLabel+1316)
+#define FN_LAMBDA340	((void*)startLabel+1328)
+#define CT_v390	((void*)startLabel+1352)
+#define F0_LAMBDA340	((void*)startLabel+1360)
+#define FN_LAMBDA339	((void*)startLabel+1372)
+#define CT_v392	((void*)startLabel+1396)
+#define F0_LAMBDA339	((void*)startLabel+1404)
+#define FN_LAMBDA338	((void*)startLabel+1416)
+#define CT_v394	((void*)startLabel+1440)
+#define F0_LAMBDA338	((void*)startLabel+1448)
+#define FN_LAMBDA337	((void*)startLabel+1460)
+#define CT_v396	((void*)startLabel+1484)
+#define F0_LAMBDA337	((void*)startLabel+1492)
+#define FN_LAMBDA336	((void*)startLabel+1504)
+#define CT_v398	((void*)startLabel+1528)
+#define F0_LAMBDA336	((void*)startLabel+1536)
+#define FN_LAMBDA335	((void*)startLabel+1548)
+#define CT_v400	((void*)startLabel+1572)
+#define F0_LAMBDA335	((void*)startLabel+1580)
+#define ST_v355	((void*)startLabel+1584)
+#define ST_v367	((void*)startLabel+1605)
+#define ST_v373	((void*)startLabel+1638)
+#define ST_v371	((void*)startLabel+1665)
+#define ST_v377	((void*)startLabel+1692)
+#define ST_v375	((void*)startLabel+1725)
+#define ST_v385	((void*)startLabel+1758)
+#define ST_v395	((void*)startLabel+1791)
+#define ST_v393	((void*)startLabel+1818)
+#define ST_v399	((void*)startLabel+1845)
+#define ST_v397	((void*)startLabel+1878)
+#define ST_v391	((void*)startLabel+1911)
+#define ST_v389	((void*)startLabel+1944)
+#define ST_v369	((void*)startLabel+1977)
+#define ST_v387	((void*)startLabel+2034)
 extern Node TM_Ratio[];
 extern Node FN_Prelude_46RealFrac_46Prelude_46Real[];
 extern Node FN_Prelude_46Real_46Prelude_46Num[];
@@ -76,6 +86,7 @@ extern Node CF_Prelude_46Integral_46Prelude_46Integer[];
 extern Node FN_Prelude_46Num_46Prelude_46Integer_46negate[];
 extern Node FN_NHC_46Internal_46_95apply4[];
 extern Node FN_Prelude_46Num_46Ratio_46Ratio_46negate[];
+extern Node FN_NHC_46Internal_46_95patternMatchFail[];
 extern Node FN_Prelude_46quotRem[];
 extern Node FN_Prelude_46Integral_46Prelude_46Real[];
 extern Node FN_Prelude_46_47_61[];
@@ -84,7 +95,7 @@ extern Node FN_Prelude_46_42[];
 static Node startLabel[] = {
   bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v349)
+, useLabel(CT_v356)
 ,};
 Node FN_Ratio_46approxRational[] = {
   useLabel(TM_Ratio)
@@ -102,8 +113,8 @@ Node FN_Ratio_46approxRational[] = {
 , bytes2word(HEAP_OFF_N1,7,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
 , 190001
-, useLabel(ST_v348)
-,	/* CT_v349: (byte 0) */
+, useLabel(ST_v355)
+,	/* CT_v356: (byte 0) */
   HW(6,3)
 , 0
 ,};
@@ -114,11 +125,11 @@ Node F0_Ratio_46approxRational[] = {
 , VAPTAG(useLabel(FN_Prelude_46_45))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
 , VAPTAG(useLabel(FN_Prelude_46_43))
-, VAPTAG(useLabel(FN_Ratio_46Prelude_46154_46simplest))
+, VAPTAG(useLabel(FN_Ratio_46Prelude_46159_46simplest))
 , bytes2word(3,0,2,1)
 , bytes2word(1,2,0,3)
-, useLabel(CT_v359)
-,	/* FN_Ratio_46Prelude_46154_46simplest: (byte 0) */
+, useLabel(CT_v368)
+,	/* FN_Ratio_46Prelude_46159_46simplest: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDHEAP_P1,38,PUSH_HEAP,HEAP_ARG)
 , bytes2word(1,HEAP_CVAL_I3,HEAP_P1,0)
@@ -141,14 +152,14 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(NEEDHEAP_I32,JUMPFALSE,11,0)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_P1,11,HEAP_ARG_ARG)
 , bytes2word(1,3,HEAP_ARG,2)
-,	/* v350: (byte 1) */
+,	/* v357: (byte 1) */
   bytes2word(RETURN_EVAL,PUSH_ARG_I3,PUSH_ARG_I2,HEAP_CVAL_P1)
 , bytes2word(12,HEAP_ARG,1,HEAP_CVAL_P1)
 , bytes2word(13,HEAP_OFF_N1,3,PUSH_HEAP)
 , bytes2word(HEAP_CVAL_P1,14,HEAP_OFF_N1,3)
 , bytes2word(EVAL,NEEDHEAP_I32,APPLY,2)
 , bytes2word(EVAL,NEEDHEAP_I32,JUMPFALSE,5)
-,	/* v352: (byte 4) */
+,	/* v359: (byte 4) */
   bytes2word(0,PUSH_P1,3,RETURN_EVAL)
 , bytes2word(HEAP_CVAL_P1,12,HEAP_ARG,1)
 , bytes2word(HEAP_CVAL_P1,15,HEAP_OFF_N1,3)
@@ -162,7 +173,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(NEEDHEAP_I32,JUMPFALSE,14,0)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_P1,17,HEAP_CVAL_P1)
 , bytes2word(18,HEAP_I2,HEAP_I1,HEAP_P1)
-,	/* v354: (byte 4) */
+,	/* v361: (byte 4) */
   bytes2word(7,HEAP_P1,6,RETURN_EVAL)
 , bytes2word(HEAP_CVAL_P1,12,HEAP_ARG,1)
 , bytes2word(HEAP_CVAL_P1,15,HEAP_OFF_N1,3)
@@ -182,103 +193,127 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,7,HEAP_P1)
 , bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,22)
 , bytes2word(HEAP_CVAL_P1,18,HEAP_OFF_N1,5)
-,	/* v356: (byte 1) */
+,	/* v363: (byte 1) */
   bytes2word(RETURN_EVAL,PUSH_HEAP,HEAP_CVAL_N1,4)
-, bytes2word(HEAP_CADR_N1,3,HEAP_CADR_N1,6)
-, bytes2word(RETURN_EVAL,ENDCODE,0,0)
+, bytes2word(JUMPFALSE,10,0,PUSH_HEAP)
+, bytes2word(HEAP_CVAL_N1,5,HEAP_CADR_N1,3)
+,	/* v365: (byte 3) */
+  bytes2word(HEAP_CADR_N1,7,RETURN,HEAP_CVAL_P1)
+, bytes2word(23,PUSH_HEAP,HEAP_CVAL_P1,24)
+, bytes2word(HEAP_OFF_N1,2,RETURN_EVAL,ENDCODE)
 , bytes2word(0,0,0,0)
+, 0
 , CONSTRW(1,0)
 , 1
 , CONSTR(0,2,0)
+, CONSTR(1,0,0)
 , CONSTRW(0,0)
 , 200015
-, useLabel(ST_v358)
-,	/* CT_v359: (byte 0) */
-  HW(20,3)
+, useLabel(ST_v367)
+,	/* CT_v368: (byte 0) */
+  HW(22,3)
 , 0
-,	/* F0_Ratio_46Prelude_46154_46simplest: (byte 0) */
-  CAPTAG(useLabel(FN_Ratio_46Prelude_46154_46simplest),3)
+,	/* F0_Ratio_46Prelude_46159_46simplest: (byte 0) */
+  CAPTAG(useLabel(FN_Ratio_46Prelude_46159_46simplest),3)
 , VAPTAG(useLabel(FN_Prelude_46toRational))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
-, VAPTAG(useLabel(FN_LAMBDA336))
-, VAPTAG(useLabel(FN_LAMBDA337))
-, VAPTAG(useLabel(FN_LAMBDA338))
-, VAPTAG(useLabel(FN_LAMBDA339))
+, VAPTAG(useLabel(FN_LAMBDA342))
+, VAPTAG(useLabel(FN_LAMBDA343))
+, VAPTAG(useLabel(FN_LAMBDA344))
+, VAPTAG(useLabel(FN_LAMBDA345))
 , VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Ord))
 , VAPTAG(useLabel(FN_Prelude_46_60))
-, VAPTAG(useLabel(FN_Ratio_46Prelude_46154_46simplest))
+, VAPTAG(useLabel(FN_Ratio_46Prelude_46159_46simplest))
 , VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num))
 , VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Eq))
 , VAPTAG(useLabel(FN_Prelude_46_61_61))
 , VAPTAG(useLabel(FN_Prelude_46fromInteger))
 , VAPTAG(useLabel(FN_Prelude_46_62))
-, VAPTAG(useLabel(FN_Ratio_46Prelude_46155_46simplest_39))
+, VAPTAG(useLabel(FN_Ratio_46Prelude_46160_46simplest_39))
 , useLabel(CF_Prelude_46Integral_46Prelude_46Integer)
-, CAPTAG(useLabel(FN_Ratio_46Prelude_46155_46simplest_39),5)
+, CAPTAG(useLabel(FN_Ratio_46Prelude_46160_46simplest_39),5)
 , VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Integer_46negate))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply4))
 , VAPTAG(useLabel(FN_Prelude_46Num_46Ratio_46Ratio_46negate))
+, VAPTAG(useLabel(FN_LAMBDA346))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
+, bytes2word(0,0,0,0)
+, useLabel(CT_v370)
+,	/* FN_LAMBDA346: (byte 0) */
+  useLabel(TMSUB_Ratio)
+, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
+, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, CONSTRW(1,0)
+, useLabel(ST_v369)
+, 200015
+, useLabel(ST_v367)
+,	/* CT_v370: (byte 0) */
+  HW(0,0)
+, 0
+,	/* CF_LAMBDA346: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA346))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v361)
-,	/* FN_LAMBDA339: (byte 0) */
+, useLabel(CT_v372)
+,	/* FN_LAMBDA345: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 250056
-, useLabel(ST_v360)
-,	/* CT_v361: (byte 0) */
+, useLabel(ST_v371)
+,	/* CT_v372: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA339: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA339),1)
+,	/* F0_LAMBDA345: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA345),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v363)
-,	/* FN_LAMBDA338: (byte 0) */
+, useLabel(CT_v374)
+,	/* FN_LAMBDA344: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 250051
-, useLabel(ST_v362)
-,	/* CT_v363: (byte 0) */
+, useLabel(ST_v373)
+,	/* CT_v374: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA338: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA338),1)
+,	/* F0_LAMBDA344: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA344),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v365)
-,	/* FN_LAMBDA337: (byte 0) */
+, useLabel(CT_v376)
+,	/* FN_LAMBDA343: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 260054
-, useLabel(ST_v364)
-,	/* CT_v365: (byte 0) */
+, useLabel(ST_v375)
+,	/* CT_v376: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA337: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA337),1)
+,	/* F0_LAMBDA343: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA343),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v367)
-,	/* FN_LAMBDA336: (byte 0) */
+, useLabel(CT_v378)
+,	/* FN_LAMBDA342: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 260048
-, useLabel(ST_v366)
-,	/* CT_v367: (byte 0) */
+, useLabel(ST_v377)
+,	/* CT_v378: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA336: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA336),1)
+,	/* F0_LAMBDA342: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA342),1)
 , bytes2word(5,0,4,1)
 , bytes2word(3,2,2,3)
 , bytes2word(1,4,0,5)
-, useLabel(CT_v373)
-,	/* FN_Ratio_46Prelude_46155_46simplest_39: (byte 0) */
+, useLabel(CT_v386)
+,	/* FN_Ratio_46Prelude_46160_46simplest_39: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDHEAP_P1,70,PUSH_HEAP,HEAP_ARG)
 , bytes2word(1,HEAP_CVAL_I3,HEAP_P1,0)
@@ -326,7 +361,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(6,EVAL,POP_I1,PUSH_P1)
 , bytes2word(0,EVAL,NEEDHEAP_I32,POP_I1)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_N1,6,HEAP_P1)
-,	/* v368: (byte 3) */
+,	/* v379: (byte 3) */
   bytes2word(7,HEAP_I1,RETURN,PUSH_P1)
 , bytes2word(9,PUSH_P1,6,HEAP_CVAL_P1)
 , bytes2word(14,HEAP_ARG,1,HEAP_CVAL_P1)
@@ -353,46 +388,52 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(PUSH_I1,EVAL,POP_I1,PUSH_P1)
 , bytes2word(0,EVAL,NEEDHEAP_I32,POP_I1)
 , bytes2word(PUSH_HEAP,HEAP_CVAL_N1,6,HEAP_I2)
-,	/* v370: (byte 2) */
-  bytes2word(HEAP_I1,RETURN,HEAP_CVAL_P1,14)
-, bytes2word(HEAP_ARG,1,HEAP_CVAL_P1,15)
-, bytes2word(HEAP_OFF_N1,3,HEAP_CVAL_P1,20)
-, bytes2word(HEAP_OFF_N1,3,HEAP_CVAL_P1,14)
-, bytes2word(HEAP_ARG,1,HEAP_CVAL_P1,15)
-, bytes2word(HEAP_OFF_N1,3,HEAP_CVAL_P1,21)
-, bytes2word(HEAP_OFF_N1,3,HEAP_CVAL_I4,HEAP_OFF_N1)
-, bytes2word(3,HEAP_P1,5,HEAP_I1)
-, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,13)
-, bytes2word(HEAP_OFF_N1,6,HEAP_I1,PUSH_P1)
-, bytes2word(0,ZAP_ARG_I1,ZAP_STACK_P1,7)
-, bytes2word(ZAP_STACK_P1,2,EVAL,POP_I1)
+,	/* v381: (byte 2) */
+  bytes2word(HEAP_I1,RETURN,PUSH_HEAP,HEAP_CVAL_N1)
+, bytes2word(7,JUMPFALSE,58,0)
+, bytes2word(HEAP_CVAL_P1,14,HEAP_ARG,1)
+, bytes2word(HEAP_CVAL_P1,15,HEAP_OFF_N1,3)
+, bytes2word(HEAP_CVAL_P1,20,HEAP_OFF_N1,3)
+, bytes2word(HEAP_CVAL_P1,14,HEAP_ARG,1)
+, bytes2word(HEAP_CVAL_P1,15,HEAP_OFF_N1,3)
+, bytes2word(HEAP_CVAL_P1,21,HEAP_OFF_N1,3)
+, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,3,HEAP_P1)
+, bytes2word(5,HEAP_I1,PUSH_HEAP,HEAP_CVAL_I4)
+, bytes2word(HEAP_OFF_N1,13,HEAP_OFF_N1,6)
+, bytes2word(HEAP_I1,PUSH_P1,0,ZAP_ARG_I1)
+, bytes2word(ZAP_STACK_P1,7,EVAL,POP_I1)
 , bytes2word(PUSH_P1,2,EVAL,NEEDHEAP_I32)
 , bytes2word(POP_I1,PUSH_HEAP,HEAP_CVAL_N1,6)
-, bytes2word(HEAP_I1,HEAP_P1,3,RETURN)
+,	/* v383: (byte 4) */
+  bytes2word(HEAP_I1,HEAP_P1,3,RETURN)
+, bytes2word(HEAP_CVAL_P1,22,PUSH_HEAP,HEAP_CVAL_P1)
+, bytes2word(23,HEAP_OFF_N1,2,RETURN_EVAL)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
+, 0
+, CONSTR(1,0,0)
 , CONSTR(0,2,0)
 , CONSTRW(1,0)
 , 1
 , CONSTRW(0,0)
 , 280015
-, useLabel(ST_v372)
-,	/* CT_v373: (byte 0) */
-  HW(19,5)
+, useLabel(ST_v385)
+,	/* CT_v386: (byte 0) */
+  HW(21,5)
 , 0
-,	/* F0_Ratio_46Prelude_46155_46simplest_39: (byte 0) */
-  CAPTAG(useLabel(FN_Ratio_46Prelude_46155_46simplest_39),5)
+,	/* F0_Ratio_46Prelude_46160_46simplest_39: (byte 0) */
+  CAPTAG(useLabel(FN_Ratio_46Prelude_46160_46simplest_39),5)
 , VAPTAG(useLabel(FN_Prelude_46quotRem))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
-, VAPTAG(useLabel(FN_LAMBDA330))
-, VAPTAG(useLabel(FN_LAMBDA331))
-, VAPTAG(useLabel(FN_LAMBDA332))
-, VAPTAG(useLabel(FN_LAMBDA333))
-, CAPTAG(useLabel(FN_Ratio_46Prelude_46155_46simplest_39),5)
+, VAPTAG(useLabel(FN_LAMBDA335))
+, VAPTAG(useLabel(FN_LAMBDA336))
+, VAPTAG(useLabel(FN_LAMBDA337))
+, VAPTAG(useLabel(FN_LAMBDA338))
+, CAPTAG(useLabel(FN_Ratio_46Prelude_46160_46simplest_39),5)
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply4))
 , VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
-, VAPTAG(useLabel(FN_LAMBDA334))
-, VAPTAG(useLabel(FN_LAMBDA335))
+, VAPTAG(useLabel(FN_LAMBDA339))
+, VAPTAG(useLabel(FN_LAMBDA340))
 , VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Real))
 , VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num))
 , VAPTAG(useLabel(FN_Prelude_46fromInteger))
@@ -401,97 +442,115 @@ Node F0_Ratio_46approxRational[] = {
 , VAPTAG(useLabel(FN_Prelude_46_47_61))
 , VAPTAG(useLabel(FN_Prelude_46_43))
 , VAPTAG(useLabel(FN_Prelude_46_42))
+, VAPTAG(useLabel(FN_LAMBDA341))
+, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
+, bytes2word(0,0,0,0)
+, useLabel(CT_v388)
+,	/* FN_LAMBDA341: (byte 0) */
+  useLabel(TMSUB_Ratio)
+, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
+, bytes2word(RETURN,ENDCODE,0,0)
+, bytes2word(0,0,0,0)
+, CONSTRW(1,0)
+, useLabel(ST_v387)
+, 280015
+, useLabel(ST_v385)
+,	/* CT_v388: (byte 0) */
+  HW(0,0)
+, 0
+,	/* CF_LAMBDA341: (byte 0) */
+  VAPTAG(useLabel(FN_LAMBDA341))
 , bytes2word(1,0,0,1)
-, useLabel(CT_v375)
-,	/* FN_LAMBDA335: (byte 0) */
+, useLabel(CT_v390)
+,	/* FN_LAMBDA340: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 340052
-, useLabel(ST_v374)
-,	/* CT_v375: (byte 0) */
+, useLabel(ST_v389)
+,	/* CT_v390: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA335: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA335),1)
+,	/* F0_LAMBDA340: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA340),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v377)
-,	/* FN_LAMBDA334: (byte 0) */
+, useLabel(CT_v392)
+,	/* FN_LAMBDA339: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 340045
-, useLabel(ST_v376)
-,	/* CT_v377: (byte 0) */
+, useLabel(ST_v391)
+,	/* CT_v392: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA334: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA334),1)
+,	/* F0_LAMBDA339: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA339),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v379)
-,	/* FN_LAMBDA333: (byte 0) */
+, useLabel(CT_v394)
+,	/* FN_LAMBDA338: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 320047
-, useLabel(ST_v378)
-,	/* CT_v379: (byte 0) */
+, useLabel(ST_v393)
+,	/* CT_v394: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA333: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA333),1)
+,	/* F0_LAMBDA338: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA338),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v381)
-,	/* FN_LAMBDA332: (byte 0) */
+, useLabel(CT_v396)
+,	/* FN_LAMBDA337: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 320045
-, useLabel(ST_v380)
-,	/* CT_v381: (byte 0) */
+, useLabel(ST_v395)
+,	/* CT_v396: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA332: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA332),1)
+,	/* F0_LAMBDA337: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA337),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v383)
-,	/* FN_LAMBDA331: (byte 0) */
+, useLabel(CT_v398)
+,	/* FN_LAMBDA336: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 330048
-, useLabel(ST_v382)
-,	/* CT_v383: (byte 0) */
+, useLabel(ST_v397)
+,	/* CT_v398: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA331: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA331),1)
+,	/* F0_LAMBDA336: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA336),1)
 , bytes2word(1,0,0,1)
-, useLabel(CT_v385)
-,	/* FN_LAMBDA330: (byte 0) */
+, useLabel(CT_v400)
+,	/* FN_LAMBDA335: (byte 0) */
   useLabel(TMSUB_Ratio)
 , bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
 , bytes2word(ENDCODE,0,0,0)
 , bytes2word(0,0,0,0)
 , 330045
-, useLabel(ST_v384)
-,	/* CT_v385: (byte 0) */
+, useLabel(ST_v399)
+,	/* CT_v400: (byte 0) */
   HW(0,1)
 , 0
-,	/* F0_LAMBDA330: (byte 0) */
-  CAPTAG(useLabel(FN_LAMBDA330),1)
-,	/* ST_v348: (byte 0) */
+,	/* F0_LAMBDA335: (byte 0) */
+  CAPTAG(useLabel(FN_LAMBDA335),1)
+,	/* ST_v355: (byte 0) */
   bytes2word(82,97,116,105)
 , bytes2word(111,46,97,112)
 , bytes2word(112,114,111,120)
 , bytes2word(82,97,116,105)
 , bytes2word(111,110,97,108)
-,	/* ST_v358: (byte 1) */
+,	/* ST_v367: (byte 1) */
   bytes2word(0,82,97,116)
 , bytes2word(105,111,46,97)
 , bytes2word(112,112,114,111)
@@ -500,7 +559,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(108,58,50,48)
 , bytes2word(58,49,53,45)
 , bytes2word(50,54,58,55)
-,	/* ST_v362: (byte 2) */
+,	/* ST_v373: (byte 2) */
   bytes2word(50,0,82,97)
 , bytes2word(116,105,111,46)
 , bytes2word(97,112,112,114)
@@ -508,14 +567,14 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(116,105,111,110)
 , bytes2word(97,108,58,50)
 , bytes2word(53,58,53,49)
-,	/* ST_v360: (byte 1) */
+,	/* ST_v371: (byte 1) */
   bytes2word(0,82,97,116)
 , bytes2word(105,111,46,97)
 , bytes2word(112,112,114,111)
 , bytes2word(120,82,97,116)
 , bytes2word(105,111,110,97)
 , bytes2word(108,58,50,53)
-,	/* ST_v366: (byte 4) */
+,	/* ST_v377: (byte 4) */
   bytes2word(58,53,54,0)
 , bytes2word(82,97,116,105)
 , bytes2word(111,46,97,112)
@@ -525,7 +584,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(58,50,54,58)
 , bytes2word(52,56,45,50)
 , bytes2word(54,58,52,57)
-,	/* ST_v364: (byte 1) */
+,	/* ST_v375: (byte 1) */
   bytes2word(0,82,97,116)
 , bytes2word(105,111,46,97)
 , bytes2word(112,112,114,111)
@@ -534,7 +593,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(108,58,50,54)
 , bytes2word(58,53,52,45)
 , bytes2word(50,54,58,53)
-,	/* ST_v372: (byte 2) */
+,	/* ST_v385: (byte 2) */
   bytes2word(53,0,82,97)
 , bytes2word(116,105,111,46)
 , bytes2word(97,112,112,114)
@@ -543,7 +602,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(97,108,58,50)
 , bytes2word(56,58,49,53)
 , bytes2word(45,51,52,58)
-,	/* ST_v380: (byte 3) */
+,	/* ST_v395: (byte 3) */
   bytes2word(55,55,0,82)
 , bytes2word(97,116,105,111)
 , bytes2word(46,97,112,112)
@@ -551,7 +610,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(97,116,105,111)
 , bytes2word(110,97,108,58)
 , bytes2word(51,50,58,52)
-,	/* ST_v378: (byte 2) */
+,	/* ST_v393: (byte 2) */
   bytes2word(53,0,82,97)
 , bytes2word(116,105,111,46)
 , bytes2word(97,112,112,114)
@@ -559,7 +618,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(116,105,111,110)
 , bytes2word(97,108,58,51)
 , bytes2word(50,58,52,55)
-,	/* ST_v384: (byte 1) */
+,	/* ST_v399: (byte 1) */
   bytes2word(0,82,97,116)
 , bytes2word(105,111,46,97)
 , bytes2word(112,112,114,111)
@@ -568,7 +627,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(108,58,51,51)
 , bytes2word(58,52,53,45)
 , bytes2word(51,51,58,52)
-,	/* ST_v382: (byte 2) */
+,	/* ST_v397: (byte 2) */
   bytes2word(54,0,82,97)
 , bytes2word(116,105,111,46)
 , bytes2word(97,112,112,114)
@@ -577,7 +636,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(97,108,58,51)
 , bytes2word(51,58,52,56)
 , bytes2word(45,51,51,58)
-,	/* ST_v376: (byte 3) */
+,	/* ST_v391: (byte 3) */
   bytes2word(52,57,0,82)
 , bytes2word(97,116,105,111)
 , bytes2word(46,97,112,112)
@@ -586,7 +645,7 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(110,97,108,58)
 , bytes2word(51,52,58,52)
 , bytes2word(53,45,51,52)
-,	/* ST_v374: (byte 4) */
+,	/* ST_v389: (byte 4) */
   bytes2word(58,52,55,0)
 , bytes2word(82,97,116,105)
 , bytes2word(111,46,97,112)
@@ -596,5 +655,35 @@ Node F0_Ratio_46approxRational[] = {
 , bytes2word(58,51,52,58)
 , bytes2word(53,50,45,51)
 , bytes2word(52,58,53,52)
-, bytes2word(0,0,0,0)
+,	/* ST_v369: (byte 1) */
+  bytes2word(0,82,97,116)
+, bytes2word(105,111,58,32)
+, bytes2word(80,97,116,116)
+, bytes2word(101,114,110,32)
+, bytes2word(109,97,116,99)
+, bytes2word(104,32,102,97)
+, bytes2word(105,108,117,114)
+, bytes2word(101,32,105,110)
+, bytes2word(32,102,117,110)
+, bytes2word(99,116,105,111)
+, bytes2word(110,32,97,116)
+, bytes2word(32,50,48,58)
+, bytes2word(49,53,45,50)
+, bytes2word(54,58,55,50)
+,	/* ST_v387: (byte 2) */
+  bytes2word(46,0,82,97)
+, bytes2word(116,105,111,58)
+, bytes2word(32,80,97,116)
+, bytes2word(116,101,114,110)
+, bytes2word(32,109,97,116)
+, bytes2word(99,104,32,102)
+, bytes2word(97,105,108,117)
+, bytes2word(114,101,32,105)
+, bytes2word(110,32,102,117)
+, bytes2word(110,99,116,105)
+, bytes2word(111,110,32,97)
+, bytes2word(116,32,50,56)
+, bytes2word(58,49,53,45)
+, bytes2word(51,52,58,55)
+, bytes2word(55,46,0,0)
 ,};
